# 五谷磨房会员商城

## 正式号与测试号切换说明
1. `project.config.json` 文件里的`appid`切换
  正式 `wx29d1ac1fcd50aeb6` / 测试 `wx6d33fa16e7a26c3a`
2. `app.json` 文件里的`plugins`的直播插件`live-player-plugin`
  正式需要加上直播插件 / 测试需删除直播插件（因为测试号没有直播插件权限，不删除会编译报错）
  ```
    "live-player-plugin": {
      "version": "1.3.0",
      "provider": "wx2b03c6e691cd7370"
    }
  ```
3. `utils/env1.js` 文件里的环境切换
  正式使用`'PROD'` / 测试使用`'TEST'`

## 插件与分包说明
1. 插件 
  app.json的plugins里用到一些插件，如果开发者工具控制台提示插件版本更新，记得酌情更新
2. 分包
  分包是为了分担主包大小，让小程序下载大小速度更快，遇到一些不常用的模块可做分包处理   
  现有分包：
    * 直播间 LivePlay   
    * MallPromotion 商城促销活动相关   
    * MemberPlan 会员挑战计划   
    * ProductTrial 新品试用   
    * Svip 超级会员 
  注意分包的语法：新增一个分包需要在 `app.json` 里的 `subpackages` 里增加配置项  
  分包使用文档：[参考文档](https://developers.weixin.qq.com/miniprogram/dev/framework/subpackages.html)

## 重要的组件 HomeModules 说明
/components/HomeModules
利用好HomeModules组件，可以让小程序页面里的任何区域变成后台可配置项，（在精准后台首页配置里进行配置）


## 商城模块
商城主要由以下几大模块构成：
  1. 产品
  2. 优惠券（又称活动）：满减、满赠、换购、……
  3. 购物金
  4. 积分
  6. 订单
  7. 超级会员
  8. 促销活动（限时折扣、团购、拼团、秒杀、……）

## 项目结构
```
├── api         // 统一的api管理
├── assets      // 静态资源文件夹，存放图片/json/style/wxs等公共静态资源
  ├── images  // 除了tabbar icon，其余图片最好放在七牛云上，避免因图片导致代码包体积过大
  ├── json
	├── style
	├── wxs
├── components   // 组件
├── lib          // 第三方库
├── modules      // 分包项目，有明显割离的商城项目最好使用分包，避免放在主包内导致主包体积过大
  ├── FanCommunity 谷粉说
	├── LivePlay 直播间
  ├── MallPromotion 促销活动相关
  ├── MemberPlan 会员计划
  ├── ProductTrial 新品试用
├── pages        // 页面
├── router       // 路由
├── store        // user的公共方法操作
├── template     // 模板
├── utils        // 工具函数
├── wgUtils      // 五谷公用的工具类
├── 版本记录.txt
├── 各类状态注释.txt
├── 直播代码.txt
├── app.js
├── app.json
├── app.wxss
├── project.config.json
├── README.md
├── sitemap.json
├── xhr.js
```

-------------------------
## 正式号小程序账号信息
| key | value  |
| ------------ | ------------ |
| APPID     |   wx29d1ac1fcd50aeb6 |
| 原始id     |  gh_9dbf111bbaf0    |
| 邮箱  | daihx@szwgmf.com  |
| 密码  | wgmf@123  |
| 管理员  | 戴海翔  |
| 最低基础库  |  2.1.3 |
| 服务类目  | 见下方  |
| 主体信息  | 深圳市香雅食品有限公司  |
正式环境 https://wx.wgmf.com
* 服务类目：
	+ 商家自营 > 食品
	+ 商家自营 > 百货
	+ 商家自营 > 保健品
	+ 商家自营 > 初级食用农产品
	+ 社交 > 社区/论坛
* request合法域名
  +  https://app.wgmf.com
  +  https://pingtas.qq.com
  +  https://test.wgmf.com
  +  https://wx.wgmf.com
  +  https://zhls.qq.com
  +  https://zj.tencentcloudapi.com
  +  https://zjmpa.cloud.tencent.com
* socket合法域名
  +  wss://test.wgmf.com
  +  wss://wx.wgmf.com
* uploadFile合法域名
  + https://test.wgmf.com
  +  https://up.qbox.me
  +  https://wx.wgmf.com
* downloadFile合法域名
  +  https://img.wgmf.com
  +  https://test.wgmf.com
  +  https://wx.wgmf.com
* 业务域名
  +  https://wx.wgmf.com
* gitlab代码仓库
  +  http://192.168.5.168/front-end/ma-shop
* SSH
  +  git@192.168.5.168:front-end/ma-shop.git
  
----------------------------------------------

## 测试号小程序账号信息
| key | value  |
| ------------ | ------------ |
| APPID     |   wx6d33fa16e7a26c3a |
| 原始id     |  gh_47162c343927    |
| 邮箱  | liman01@szwgmf.com  |
| 密码  | wgmf1108  |
| 管理员  | 吴纯玲  |
| 最低基础库  |  1.0.0 |
| 服务类目  | 商家自营 > 食品  |
| 主体信息  | 深圳市香雅食品有限公司  |
测试环境 https://test.wgmf.com

----------------------------------------------

## 有数埋点
   * `appid: 'wx29d1ac1fcd50aeb6'`, // 微信小程序appID，以wx开头
   * `token: 'bi50fbec6d1cc84ce5'`, // token是唯一必须配置的参数，请联系有数数据服务sr_data_service@tencent.com提供
  [参考文档](http://192.168.5.168/front-end/wg-mp-template/blob/dev/%E8%85%BE%E8%AE%AF%E6%9C%89%E6%95%B0%E5%9F%8B%E7%82%B9%E8%AF%B4%E6%98%8E%E6%96%87%E6%A1%A3.md)

## 事件上报
  上报记录说明wiki：[wiki说明链接](https://www.tapd.cn/42739501/markdown_wikis/show/#1142739501001000252)  
  五谷磨房会员商城埋点上报记录表： [埋点表](https://docs.qq.com/sheet/DUE1yeXl4Y094ZXBz)  
  每上报一个事件， 例如 `WGTRACK.logCustomEvent('share_mall')`记得在上报记录表里面增加一条记录。方便数据部门和运营部门后期取数需求  

## 商城优惠券概念说明
1. 根据优惠券的使用范围分为 **全场优惠券** & **专享优惠券**
  * 全场优惠券：比如全场满258减20，特点：不需要进行发券，每个人满足条件均可以使用这个券
  * 专享优惠券：比如满100减10，特点：需要进行发券和核销等相关操作，用户才能拥有并使用这张券

2. 根据优惠券的使用人群分为 **超会专享券** & **普通券**
  * 普通券：不区分人群，只要满足条件即可使用这张券。
  * 超会专享券：用户的身份必须是超会才能使用这张券。如果是非超会，哪怕券是全场券或用户券包有这张券，也无法使用。

3. 根据超会券的叠加使用规则分为 **同享券** & **不同享券**
  * 同享券：优惠券可与其他券叠加使用
  * 不同享券：优惠券不可以与其他券叠加使用

4. 根据优惠券的类型分为 **满减券** & **赠品券** & **积分券** & **换购券** 四大类
  * 满减券：满足条件即减订单金额
  * 赠品券：满足条件即送赠品
  * 积分券：满足条件即送积分（一般是积分翻n倍）
  * 换购券：满足条件即可以增加x元加购一款产品

5. 优惠券与产品的关系
  * 购买关系： 买 xxx产品或xxx产品组合内的产品，可以使用这张券
  * 排除关系： 排除xxx产品或xxx产品组合内的产品，即买了这些排除产品，无法使用这张券

## 购物车现行的基本逻辑
1. 用户加购时保存产品相关信息：
  * 产品图
  * pid
  * 产品名称
  * skuid
  * sku名称
  * 库存     （用于数量加减的上限判断）
  * 限购数量 （用于数量加减的上限判断）
  * 产品类型 （主要为了区分自营商品/非自营商品---用于积分商品的运费凑单提示判断）
  * 是否是积分兑换产品  （积分商品跟其他商品的展示不同）
  * 购买数量
  * 选中状态
  * 仓库
  * 原价    （产品有配置原价取原价，没有则取虚标价）
  * 现价    （现价，又称活动价，是该产品现阶段正在售卖的价格）  
  * 用户购买所需价 （非超会=现价；超会=现价*0.95）
  * 积分兑换价格
  * 该款产品参与活动的文字标签 （如特价/限时折扣/积分兑换）
  * 活动的结束时间  （用于显示距离活动结束仅剩xx天xx小时xx分钟）
2. 凑单提示
  * 获取用户的券包列表
  * 排除购物车里的 积分产品 & 没有选中的产品
  * 根据券的活动配置里的排除产品组合 排除掉一部分券
  * 循环获得凑单提示的最大最小券
3. 活动优惠计算：调用柯俊接口获得 全场优惠 & 专享优惠
4. 前端计算：获得 95折优惠 & 产品活动优惠
5. 运费的凑单提示计算：当积分商品数量大于0 且 非积分自营商品数量小于等于0，则显示 “积分商品凑单免运费” 提醒 
现行逻辑，问题在于第二步，凑单提示的获取通过前端的简单优惠力度比较得到，无法处理优惠券的同享互斥排除等等复杂关系，显示的优惠券不一定与结算页完全一致
已满足的最大力度优惠券有标准答案  
但是下一梯度将满足的优惠券无标准答案，例如，计算得下一梯度将满足的是再凑20可以减10，用户此时加购一款产品，而恰好这款产品在这个再凑20可以减10的排除产品组合里，
那无法达成下一梯度  

## 促销活动说明结束
（这个概念基本上与订单类型挂钩）
只有普通产品和限时折扣产品才能加入购物车，所以配置了促销活动的产品只能立即购买，其订单类型跟普通单不一样
1. 秒杀：秒杀活动产品不能使用任何优惠券，且需要用单独的秒杀下单接口
2. 拼团：满x人即成团活动
3. 团购：满x份即返y元购物金
4. 预售
5. 套餐搭配
6. 分期发货
7. 购买线上优惠券
8. 购买线下优惠券
8. 积分兑换
