/**
 * 所有的接口均统一在这个文件进行维护
 */
import http from '../utils/http'
import baseUrl from '../utils/env'

const API = {
  seckill: { // 秒杀
    /** 获取秒杀库存 */
    stock: data => http.post('wechat-shop-back/buyNow/getStock', data),
    /** 查询秒杀信息详情 { buyNowId } */
    detail: id => http.get('wechat-shop-back/buyNow/info/' + id),
    /** 预约秒杀 */
    order: data => {
      let url = `wechat-shop-back/buyNow/reserve?buyNowId=${data.buyNowId}&openId=${data.openId}&cusId=${data.cusId}&productTemplateId=${data.productTemplateId}&source=${data.source}`
      return new Promise((resolve, reject) => {
        wx.request({
          url: `${baseUrl}${url}`,
          header: getHeader(),
          method: 'POST',
          data: data,
          success: function (res) {
            if (res.data.status === 0) {
              resolve(res.data.data)
            } else {
              if (res.data.msg == '抱歉！此秒杀仅限超级会员参与') {
                resolve('novip')
              } else {
                reject(res.data.msg)
              }
            }
          },
          fail: function (err) {
            reject(err)
          }
        })
      }).catch(function (e) {
        showErrToast(e)
      })
    },
  },
  installment: { // 分期发货
    /** 根据订单id查下子订单 */
    list: id => http.post('wechat-shop-back/installment/search/' + id), 
    /** 查询分期子订单信息 */
    detail: id => http.get('wechat-shop-back/installment/info/' + id),
    /** 更新订单的收货人信息 */
    updateAddress: (id, data) => http.put('wechat-shop-back/installment/address/' + id, data),
    /** 更新子订单的发货日期 */
    updateDate: (id, data) => http.get('wechat-shop-back/installment/preShippingDate/' + id, data), 
  },
  package: { // 套餐
    /** 获取套餐详情 */
    list: id => http.get('promotion-online/online/package?proId=' + id, { proId: id }),
  },
  product: { // 商品
    /** 商品列表 */
    list: ids => http.post('wechat-shop-back/product/info/list', ids),
    /** 商品详情 */
    detail: id => http.get('wechat-shop-back/product/info/template/' + id),
    /** 预约到货提醒  */
    reserve: (openId, productId,source, luckyDrawId, cusId) => http.post('wechat-shop-back/product/reserve', {
      openId: openId,
      productId: productId,
      source: 2,
      luckyDrawId,
      cusId
    }, 'formdata'),
    /** 预约降价提醒 */
    priceReduction: data => http.post(`wechat-shop-back/product/priceReduction?openId=${data.openId}&cusId=${data.cusId}&productId=${data.productId}&productTemplateId=${data.productTemplateId}&price=${data.price}&source=${data.source}`, data),
    /** 获取产品分类信息 */
    productSeries: () => http.get('wechat-shop-back/product/list/productSeries'), 
    productsBySeriesId: (id) => http.get(`wechat-shop-back/product/list/productSeries/3/${id}/${wx.getStorageSync('custChannel')|| 0}?isSvipFlag=${wx.getStorageSync('vipCusStatus')|| 0}`),  //未登录，默认商城会员
    /** 根据订单id获取产品评价 */
    productSeriesSpecial: (id) => http.get(`wechat-shop-back/product/list/productSeriesSpecial/3/${id}/${wx.getStorageSync('custChannel') || 0}?isSvipFlag=${wx.getStorageSync('vipCusStatus')|| 0}`), //未登录，默认商城会员
    productCommentByOrderId: id => http.get(`wechat-shop-back/evaluation/getByOrderId?orderId=${id}`),
    validActivityNew: data => http.post('promotion-online/online/validActivityNew', data),
    svipProduct: presetFlag => http.get('wechat-shop-back/product/getProductPresent?presetFlag=' + presetFlag),
    banner: () => http.get('wechat-shop-back/product/info/notice'),
    recommend: data => http.post(`wechat-shop-back/product/info/productPushList/3?channel=${wx.getStorageSync('custChannel') || 0}&isSvipFlag=${wx.getStorageSync('vipCusStatus')|| 0}`, data),
    /** 用户可兑换的积分产品 */
    productRedeemList: cusId => http.post(`wechat-shop-back/product/info/productRedeemList?cusId=${cusId}&isSvipFlag=${wx.getStorageSync('vipCusStatus')|| 0}`),
    /** 查询用户是否购买过权益卡 */
    hadVoucherCards: cusId => http.get(`app/CostomerSubject/hadVoucherCards?cusId=${cusId}`)
  },
  clickId: { // 广告
    /** 广告行为转化，上传广告click_id */
    upload: (data) => {
      let url = `wechat-behavior-advert/userAction4minipro/uploadH5ActionData?actionType=${data.actionType}&clickId=${data.clickId}&actionUrl=${encodeURIComponent(data.actionUrl)}`
      wx.request({
        url: `${baseUrl}${url}`,
        header: getHeader(),
        method: 'POST',
        data: data,
        success: function (res) {
          console.log('广告转化率clickid上传', res.data)
        },
        fail: function (err) {
          console.log('广告转化率clickid上传', err)
        }
      })
    },
  },
  modules: { // 首页模块
    /** 获取首页的页面数据 */
    get: () => http.post(`wechat-shop-back/miniApp/getByHomePage?label=${wx.getStorageSync('custChannel')|| 0}&isSvipFlag=${wx.getStorageSync('vipCusStatus')|| 0}&cusId=${wx.getStorageSync('cusId')|| ''}`),
    // 瀑布流分类
    getClassify: (pageId) => http.get(`/wechat-shop-back/pinterestClassifyInfo/getClassify?pageId=${pageId}`),
    // 首页商品推荐瀑布流分页
    queryProductByClassId: (params) => http.post(`/wechat-shop-back/pinterestClassifyInfo/queryProductByClassId`, {...params, pageSize: 10}),
    /** 根据页面id获取小程序二级页面 */
    getById:(id) => http.post('wechat-shop-back/miniApp/getHomePageById?id=' + id + '&cusId='+wx.getStorageSync('cusId')|| ''),
    /** 获得首页的图片外框 */
    imgBorder: () => http.get('wechat-shop-back/album/activityFrames'),
    /** 首页弹窗 */
    validDialogListByCusId: (cusId, pId) => http.get('wechat-miniprogram-back/validDialogListByCusId?cusId='+cusId+'&pId='+pId),
    /** 根据id获取h5的二级页面数据 */
    exchange: id => http.get('jz-shoppingmall-operations-management/act/selfBuiltMallIndexModel/getMallPageData?id=' + id),
    /** 根据url获取h5二级活动页面数据 */
    getActivityPageId: url => http.get('jz-shoppingmall-operations-management/act/selfBuiltMallIndexModel/getMallPageData?url=' + url),
  },
  promotion: { // 活动
    /** 获取团购详情 */
    groupB: code => http.get('wechat-shop-back/groupPurchase/groupInfo/cashBack/' + code),
    /** 获取团购的轮播信息 */
    groupBSwiper: id => http.get('wechat-shop-back/groupPurchase/productTemplate/groupNum/' + id),
    /** 获取拼团的轮播信息 */
    groupASwiper: id => http.get('wechat-shop-back/groupPurchase/productTemplate/' + id),
    /**  获取秒杀活动产品的库存 */
    getStock: (buyNowId, productTemplateId) => http.post(`wechat-shop-back/buyNow/getStock?buyNowId=${buyNowId}&productTemplateId=${productTemplateId}`),
    /** 获取不同享的满赠券 */
    getUnShareActivity: params => http.post('promotion-online/online/getUnShareActivity', params),
    /** 获取梯度满赠券 */
    getGradientActivity: params => http.post('promotion-online/online/getGradientActivity', params),
    /** 预约活动 */
    remindPromotion: data => { 
      let query = '?'
      for(let key in data) {
        query += `${key}=${data[key]}&`
      }
      return http.get(`wechat-miniprogram-back/appointment${query}`)
    },
    /** 年货节集卡-获取卡片详情 */
    getCardDetail: (pId, cusId) => http.get(`/wechat-shop-back/cardCollection/getCardDetail?pId=${pId}&cusId=${cusId}`, null, 'json', 0),
    /** 年货借记卡-合成卡片 */
    confirmCardDetail: (cusId, pId, miniOpenId, cardId) => http.get(`/wechat-shop-back/cardCollection/confirmCardDetail?cusId=${cusId}&pId=${pId}&miniOpenId=${miniOpenId}&cardId=${cardId}`),
    isBuyCard: cusId => http.get(`wechat-shop-back/discountCard/isBuyCard?cusId=${cusId}`),
  },
  coupons: { // 优惠券
    /** 优惠券活动详情 */
    detail: id => http.get('wechat-game-back/coupon/getTakeCouponSetting?tkcpSettingId=' + id, null),
    /** 领取优惠券 */
    receive: (cusId, id, limit, configToast) => {
      return new Promise((resolve, reject) => {
        wx.request({
          url: `${baseUrl}wechat-game-back/coupon/takeCoupon`,
          header: {
            'content-type': 'application/x-www-form-urlencoded',
          },
          method: 'POST',
          data: {
            tkcpSettingId: id,
            cusId: cusId.toString()
          },
          success(res) {
            // status: 10021 msg: "抱歉，此券已经领完了！"
            let icon = 'none'
            let title = res.data.msg
            if (res.data.msg == '领券成功！') icon = 'success'
            if (res.data.msg == '你已经达到参加次数上限') {
              title = '抱歉，每人限领' + limit + '张，您不可再领了！'
            }
            if(res.data.status == 10021) {
              title = res.data.msg
            }
            if(!configToast) {
              wx.showToast({
                icon: icon,
                title: title,
                duration: 2000
              })
            }
            resolve(res)
          },
          fail(err) {
            console.log(err)
            reject(err)
          }
        })
      })
    },
    /** 我的优惠券列表 */
    list: () => http.get(`promotion-online/activity/getSpecialAct?cusid=${wx.getStorageSync('cusId')}&vipCusStatus=${wx.getStorageSync('vipCusStatus')}`),
    /** 我是否有这张优惠券呢 */
    doIHasThisCoupon: (phone, activityGroup) => http.get(`promotion-online/wechat/getCodeStatus?phone=${phone}&activityGroup=${activityGroup}`),
    /** 权益卡 */
    postVoucherInfo:() => http.post(`app/information/queryVoucherInfo?cusId=${wx.getStorageSync('cusId')}`),
    /** 权益卡 */
    postVoucherCards:() => http.post(`app/information/queryVoucherCards?cusId=${wx.getStorageSync('cusId')}`),
    /** 全场活动优惠券 */
    validCoupon: (cusId, vipCusStatus) => http.get(`promotion-online/online/vipActivity?cusId=${cusId}&vipCusStatus=${vipCusStatus}`),
    /** 获取用于的专享优惠券 */
    queryValidTicketActivitys: cusId => http.post(`promotion-online/online4cart/queryValidTicketActivitys?cusid=${cusId}`),
    /** 用于结算页发放50元无门槛优惠券 */
    sendFirstTicketByVip: cusId => http.post(`app/customer/sendFirstTicketByVip?cusId=${cusId}`, { cusId: cusId }, 'json', 1, 0),
    /** 查询线上超级会员月度大礼包数据---当月 */
    querySVipMonthPackage: cusId => http.post(`app/information/querySVipMonthPackage?cusId=${cusId}&onlyCurMonth=1`, null, null, false, false),
    /** 超会卡券包页面领取当月卡券的接口 */
    receiveCurMonthTicket: (cusId, ticketDetailId) => http.post(`app/customer/receiveCurMonthTicket?cusId=${cusId}&ticketDetailId=${ticketDetailId}`),
    /** 领取添加红包的优惠券 */
    receiveRedPacket: cusId => http.post(`app/customer/receiveRedPacket?cusId=${cusId}`, null, 'json', false),
    /** 初始化积分延期卡 */
    pointsDelayCard: (cusId) => http.post(`app/customer/queryPointsDelayCard?cusId=${cusId}`),
  },
  user: { // 用户
    info: cusId => http.get(`sygj-ewx/customerInformation/getCustomerInfo?cusId=${(cusId?cusId:wx.getStorageSync('cusId'))}&unionId=${wx.getStorageSync('unionId')}`),
    getUserIdByQy: code => http.get(`wechat-miniprogram-service/qyMiniAppOAuth/microMallJscode2session?jsCode=${code}`),
    judgeCustomerBuyType: cusId => http.get('wechat-immunity-miniprogram/customerOrder/judgeCustomerBuyType?cusId=' + cusId),
    gwj: data => http.get('wechat-propagate-back/gwjAccount/info', data),
    level: data => http.get('app/customer/getCustBaseInfo', data),
    integralGrade: () => http.get('wechat-shop-back/integral/integral/grade'),
    /** 获取超级会员信息：等级/过期/有效期 */
    getVipCusStatus: cusId => http.post('app/information/querySVipOnlineCusInfo', { cusId: cusId }, 'formdata'),
    /** 我的超会是否一月内快过期 */
    isWillOverdue: cusId => { // 我的超会是否一月内快过期
      return http.post(`sygj-ewx/SuperVip/isWillOverdue?cusId=${cusId}`)
    },
    /** 我的生日 */
    myBirth: cusId => http.post(`sygj-ewx/customerInformation/getBrithDay?cusId=${cusId}`),
    /** 更新我的生日 */
    updateMyBirth: (cusId, brithday) => http.post(`sygj-ewx/customerInformation/updateBrithDay?cusId=${cusId}&brithday=${brithday}`),
    /** 我的超会推荐信息 */
    myReferrer: cusId => http.post('wechat-shop-back/svipOrder/referrer/' + cusId),
    /** 我的超会节省信息 */
    economize: cusId => http.post('wechat-shop-back/svipOrder/economize/' + cusId),
    /** 查询我的超会状态 */
    querySVipOnlineCusInfo: cusId => http.post('app/information/querySVipOnlineCusInfo', { cusId: cusId }, 'formdata'),
    /** 获取用户的有效积分 */
    getValidPoints: cusId => http.post('app/custpts/brief', { cusId: cusId }, 'formdata', 0, 0),
    getQyQrcode: (cusId, openId, unionId, stateType) => {
      let str = ''
      if(cusId) { str += `cusId=${cusId}&` }
      if(openId) { str += `miniOpenId=${openId}&` }
      if(unionId) { str += `unionId=${unionId}&` }
      str += `stateType=${stateType}`
      return http.get(`wechat-immunity-miniprogram/customerOrder/findCorporateConsultantByOpenId?${str}`)
    },
    /** 等级升级提示 */
    getCustomerGradeInfo: cusId => http.get(`app/information/getCustomerGradeInfo?cusId=${cusId}`, { cusId: cusId }, 'json', false,false),
    /** 是否显示线下专柜订单评价弹窗 */
    showCommentCheck: cusId => http.get(`app/CostomerSubject/showCommentCheck?cusId=${cusId}`),
    showCommentByMiniApp: comment => http.post('app/CostomerSubject/saveCommentByMiniApp', comment),
  },
  address: { // 地址
    /** 获取收货地址列表 */
    list: data => http.get('wechat-shop-back/address/listAdd', data, 'json', 1, 0),
    /** 根据收货地址获取运费 */
    deliveFee: data => http.post(`wechat-shop-back/region/getRegionLogisticsByAddressId?provinceId=${data.provinceId}&cityId=${data.cityId}&distId=${data.distId}`, data),
  },
  order: { // 订单
    /** 订单详情 */
    detail: orderId => http.get('wechat-shop-back/order/orderDetail/' + orderId),
    /** 该订单获的的积分 */
    integral: orderCode => http.post('sygj-ewx/customerInformation/queryAllPointsByConsId?consId=' + orderCode),
    /** 下单页面计算本单可获得积分 */
    integralBack: params => http.post('wechat-shop-back/order/getOrderPoints', params),
    getPayGift: (customerId,orderId) => http.post('wechat-shop-back/order/getPayGift?orderId=' + orderId + '&customerId=' + customerId),
  },
  cart: { // 购物车
    refresh: ids => http.post('wechat-shop-back/product/info/list', ids),
    getCouponSave: data => http.post('promotion-online/online4cart/getValidActivity', data, 'json', 0, 0), // 计算购物车的优惠明细
  },
  svip: { // 超级会员
    /** 超级会员获取节省金额 */
    getEconomicFee: (cusId, vipCusStatus, vipBuyTime) => http.get(`wechat-shop-back/svipOrder/getEconomicFee?customerId=${cusId}&overdueStatus=${vipCusStatus == 1?1:0}${vipCusStatus == 0?'':'&svipDate='+vipBuyTime}`),
    /** 初始化翻牌游戏 */
    initFlop: () => http.get(`wechat-miniprogram-back/flop/get`, null, 'json', true, false),
    /** 查看当前用户是否有翻牌机会 */
    flopCheck: cusId => http.get(`wechat-miniprogram-back/flop/check?cusId=${cusId}`, null, 'json', true, false),
    /**  新版根据cusId获取预计节省金额 */
    getNewEconomicFee: () => http.get('wechat-shop-back/svipOrder/getNewEconomicFee'),
    /**  新版根据customerId获取超级会员节省信息 */
    economizeNew: cusId => http.post(`wechat-shop-back/svipOrder/economizeNew/${cusId}`)
  },
  /** 获取服务器时间 */
  getTime: () => http.get('wechat-shop-back/preSell/info/getTime'),
}

function getHeader() {
  if (wx.getStorageSync('cusId')) {
    return {
      'content-type': 'application/json',
      'Cookie': 'customerId=' + wx.getStorageSync('cusId')
    }
  }
  return {
    'content-type': 'application/json'
  }
}

function showErrToast(e) {
  if (e) {
    wx.showToast({
      title: e,
      icon: 'none',
      duration: 1500
    })
  }
}
export default API