import {
  REQUEST,
  API,
  TOAST,
  UTIL
} from '../../utils/index'
import api from '../../api/index'
import { WGCOMMON } from '../../wgUtils/index';
let index = [0, 0, 0]
let normalRegion = require('../../utils/normalRegion.js').regions
let regionInfo = {
  province: {
    id: null,
    label: '省',
    index: null
  },
  city: {
    id: null,
    label: '',
    index: null
  },
  district: {
    id: null,
    label: '',
    index: null
  }
}
const app = getApp()
const editInfoRegExp = {
  receiverName: /^.{1,6}$/,
  receiverPhone: /^[1]{1}[2345678]{1}\d{9}$/,
  region: /^\S+$/,
  additional: /^.{1, 30}$/
}
const addressDef = '街道、门牌号、小区等详细地址'
const data = {
  region: [],
  customItem: '',
  addressInfo: {},
  pickShow: false,
  orderTips: {
    receiverName: '请填写收货人',
    receiverPhone: '请填写手机号',
    region: '请选择省市区',
    additional: '请填写详细地址'
  },
  editModule: {
    receiverName: '',
    receiverPhone: '',
    additional: ''
  },
  ssqPlaceholder: '请选择省市区',
  addressDef: addressDef,
  addressAbled: false,
  regionInfo: {
    province: {
      label: '省',
      id: null,
      index: null
    },
    city: {
      label: '',
      id: null,
      index: null
    },
    district: {
      label: '',
      id: null,
      index: null
    }
  },
  regionIdShow: {
    provinceId: null,
    cityId: null,
    districtId: null
  },
  regionLabel: {
    province: '省',
    city: '',
    district: ''
  },
  regionModule: {
    provinceModule: [],
    cityModule: [],
    districtModule: []
  },
  selectType: 0, //默认选择省 0-省, 1-市, 2-区县
  edit: 0,
  scrollTop: 0
}
const methods = {
  importAddress () {
    let that = this
    wx.getSetting({
      success: (res) => {
        if (!res.authSetting['scope.address']) {
          wx.authorize({
            scope: 'scope.address',
            success: () => {
              that.importAddress1() // 同意授权
            },
            fail: (res) => {
              WGCOMMON.showModal('申请授权', '使用导入功能，需要授权微信通讯地址权限').then(() => {
                wx.openSetting({
                  success () {}
                })
              }).catch(() => {})
            }
          })
        } else { // 已经授权了地址权限
          that.importAddress1()
        }
      },
      fail: (res) => {
      }
    })
  },
  importAddress1() {
    let that = this
    wx.chooseAddress({
      success (res) {
        that.setData({
          'editModule.receiverPhone': res.telNumber,
          'editModule.receiverName': res.userName,
          'editModule.additional': res.detailInfo,
          ssqPlaceholder: '请手动选择省市区',
          region: [],
        })
      },
      fail (err) {

      }
    })
  },
  fnVerifyForm(fieldList = []) {
    let _self = this
    for (let i = 0; i < fieldList.length; i++) {
      let item = fieldList[i]
      let val = _self.data.editModule[item]
      let tips = _self.data.orderTips[item]
      if (!editInfoRegExp[item].test(val)) {
        TOAST.success({
          title: tips
        })
        return false
      }
    }
    return true
  },
  save(e) {
    if (!this.data.editModule.receiverName || this.data.editModule.receiverName.trim().length == 0) {
      TOAST.warning({
        title: '请填写收货人',
        duration: 1000
      })
      return
    }
    if (this.data.editModule.receiverName && this.data.editModule.receiverName.trim().length > 6) {
      TOAST.warning({
        title: '收货人姓名不能超过6个字'
      })
      return
    }
    if (!this.data.editModule.receiverPhone) {
      TOAST.warning({
        title: '请输入手机号',
        duration: 1000
      })
      return
    }
    // 8香港手机号码不加区号  11内地手机号码  13香港手机号码加区号
    let phone = this.data.editModule.receiverPhone.trim()
    let phoneLen = phone.length
    if (phoneLen == 8 || phoneLen == 11 || phoneLen == 13) {
      let reg = /^0?1[3|4|5|6|7|8|9][0-9]\d{8}$/
      let reg1 = /^([5|6|8|9])\d{7}$/
      if (phoneLen == 11 && !reg.test(this.data.editModule.receiverPhone)) {  // 内地手机号码
        TOAST.warning({
          title: '请输入正确的手机号'
        })
        return
      }
      if (phoneLen == 8 && !reg1.test(this.data.editModule.receiverPhone)) { // 香港手机号码不加区号
        TOAST.warning({
          title: '请输入正确的手机号'
        })
        return
      }
      if (phoneLen == 13) { // 香港号码加区号 00852
        var qu = phone.substr(0, 5)
        var number = phone.substr(5, 8)
        if (qu != '00852' || !reg1.test(number)) {
          TOAST.warning({
            title: '请输入正确的手机号'
          })
          return
        }
      }
    } else {
      TOAST.warning({
        title: '请输入正确的手机号'
      })
      return
    }
    if (this.data.region.length != 3) {
      TOAST.warning({
        title: '请选择省市区'
      })
      return
    }
    if (!this.data.editModule.additional) {
      TOAST.warning({
        title: '请填写详细地址',
        duration: 1000
      })
      return
    }
    if (this.data.editModule.additional.trim().length > 30) {
      TOAST.warning({
        title: '详细地址不能超过30个字',
        duration: 1000
      })
      return
    }
    let params = {
      receiverName: this.data.editModule.receiverName,
      receiverPhone: this.data.editModule.receiverPhone,
      additional: this.data.editModule.additional,
      provinceId: this.data.regionInfo.province.id, // 河北省
      cityId: this.data.regionInfo.city.id, //  石家庄市
      districtId: this.data.regionInfo.district.id, // 长安区
      customerId: UTIL.getInfo('cusId'),
      openId: ''
    }
    if (this.data.editModule.id) {
      params.id = this.data.editModule.id
    }
    if (this.data.actType == 5) {  // 分期发货子订单修改收货地址
      params = {
        receiverName: this.data.editModule.receiverName,
        receiverPhone: this.data.editModule.receiverPhone,
        additional: this.data.editModule.additional,
        city: {
          id: this.data.regionInfo.city.id,
          regionName: this.data.regionInfo.city.label,
          subRegions: [{}]
        },
        district: {
          id: this.data.regionInfo.district.id,
          regionName: this.data.regionInfo.district.label,
          subRegions: [{}]
        },
        province: {
          id: this.data.regionInfo.province.id,
          regionName: this.data.regionInfo.province.label,
          subRegions: [{}]
        },
      }
      this.updateAddress(params)
    } else {
      REQUEST.post(API.save_adress, {
        data: params,
        header: {
          'content-type': 'application/json'
        }
      }).then((res) => {
        const {
          status,
          data
        } = res.data
        if (status == 0) {
          var pages = getCurrentPages();
          this.setData({
            ssqPlaceholder: '请选择省市区',
          })
          var currPage = pages[pages.length - 1]
          var prevPage = pages[pages.length - 2] // 上个页面
          var forwardPage = pages[pages.length - 3] // 上上个页面
          if (wx.getStorageSync('add') == '1') { // 订单新增
            app.globalData.adIndex = data.id
            prevPage.setData({
              actType: this.data.actType,
              source: 1
            })
            wx.navigateBack({
              delta: 1
            })
          } else if (wx.getStorageSync('add') == '2') { // 地址列表编辑
            app.globalData.adIndex = this.data.editModule.id
            wx.navigateBack({
              delta: 2
            })
          } else if (wx.getStorageSync('add') == '3') { // 地址列表新增
            app.globalData.adIndex = data.id
            wx.navigateBack({
              delta: 2
            })
          } else if (wx.getStorageSync('add') == '4') { // 
            this.triggerEvent('editShow', true)
          }
        }
      })
    }
  },
  updateAddress(params) {
    api.installment.updateAddress(this.data.installmentId, params).then(res => {
      if (res) {
        wx.showToast({
          title: '修改成功',
          icon: 'success',
          duration: 1500,
          complete: () => {
            setTimeout(function () {
              wx.navigateBack({})
            }, 1500)
          }
        });
      }
    }).catch(e => {
      console.error(e);
    })
  },
  bindRegionChange(e) {
    let val = e.detail.value.join(' ')
    this.setData({
      region: val
    })
  },
  onInputNumberBlur(e) {
    this.setData({
      'editModule.receiverPhone': e.detail.value
    })
  },
  onInputNameBlur(e) {
    this.setData({
      'editModule.receiverName': e.detail.value
    })
  },
  onInputAdditionalBlur(e) {
    this.setData({
      'editModule.additional': e.detail.value
    })
  },
  selectAdress() { // 选择省市区
    if (!this.data.editModule.additional) {
      this.setData({
        addressDef: ''
      })
    }
    this.setData({
      pickShow: true,
      addressAbled: true,
      selectType: 0,
      'regionLabel.province': '省',
      'regionLabel.city': '',
      'regionLabel.district': '',
      scrollTop: 0
    })
    if (!this.data.edit) {
      if (this.data.regionInfo.city.id) {
        this.initCitys()
      }
      if (this.data.regionInfo.district.id) {
        this.initDistricts()
      }
    } else {

    }
  },
  closeSku() {
    if (!this.data.editModule.additional) {
      this.setData({
        addressDef: addressDef
      })
    }
    regionInfo = this.data.regionInfo
    this.setData({
      'regionLabel.province': this.data.regionInfo.province.label,
      'regionLabel.city': this.data.regionInfo.city.label,
      'regionLabel.district': this.data.regionInfo.district.label,
      'regionIdShow.provinceId': this.data.regionInfo.province.id,
      'regionIdShow.cityId': this.data.regionInfo.city.id,
      'regionIdShow.districtId': this.data.regionInfo.district.id,
      pickShow: false,
      addressAbled: false
    })
  },
  initRegions() {
    return new Promise((resolve, reject) => {
      let url = 'https://wx.wgmf.com/shop-web/static/json/normalRegion.json'
      normalRegion =
        REQUEST.get(url).then((res) => {
          normalRegion = res.data
          resolve(res.data)
        }).catch((e) => {
          reject()
        })
    })
  },
  switchLabel(e) { // 新版联动选择器 0-省, 1-市, 2-区县
    this.setData({
      selectType: e.currentTarget.dataset.type,
      scrollTop: 0
    })
  },
  initProvince() {
    let provinces = []
    let region = normalRegion
    for (let i = 0; i < region.length; i++) {
      let item = {
        regionName: region[i].regionName,
        id: region[i].id
      }
      provinces.push(item)
    }
    if (provinces.length != 0) {
      this.setData({
        'regionModule.provinceModule': provinces,
        selectType: 0
      })
    }
  },
  selectProvince(e) {
    this.setData({})
    let region = normalRegion
    let subRegions = region[e.currentTarget.dataset.index].subRegions
    let citys = []
    for (let i = 0; i < subRegions.length; i++) {
      let item = {
        regionName: subRegions[i].regionName,
        id: subRegions[i].id
      }
      citys.push(item)
    }
    if (citys.length > 0) {
      regionInfo = {
        province: {
          id: e.currentTarget.dataset.id,
          label: e.currentTarget.dataset.label,
          index: e.currentTarget.dataset.index
        },
        city: {
          id: null,
          label: '市',
          index: null
        },
        district: {
          id: null,
          label: '',
          index: null
        }
      }
      this.setData({
        'regionModule.cityModule': citys,
        selectType: 1,
        'regionLabel.province': e.currentTarget.dataset.label,
        'regionIdShow.provinceId': e.currentTarget.dataset.id,
        'regionLabel.city': '市',
        'regionIdShow.cityId': null,
        'regionIdShow.districtId': null,
        'regionLabel.district': '',
        scrollTop: 0
      })
    }
  },
  selectCity(e) {
    this.setData({})
    let region = normalRegion
    let index = regionInfo.province.index
    let subIndex = e.currentTarget.dataset.index
    let district = region[index].subRegions[subIndex].subRegions
    let districts = []
    for (let i = 0; i < district.length; i++) {
      let item = {
        regionName: district[i].regionName,
        id: district[i].id
      }
      districts.push(item)
    }
    if (districts.length > 0) {
      regionInfo.city.id = e.currentTarget.dataset.id
      regionInfo.city.label = e.currentTarget.dataset.label
      regionInfo.city.index = e.currentTarget.dataset.index
      regionInfo.district.id = null
      regionInfo.district.label = '区县'
      regionInfo.district.index = null
      this.setData({
        'regionModule.districtModule': districts,
        selectType: 2,
        'regionLabel.city': e.currentTarget.dataset.label,
        'regionIdShow.cityId': e.currentTarget.dataset.id,
        'regionLabel.district': '区县',
        'regionIdShow.districtId': null,
        scrollTop: 0
      })
    }
  },
  selectDistrict(e) {
    this.setData({
      scrollTop: 0
    })
    regionInfo.district.id = e.currentTarget.dataset.id
    regionInfo.district.label = e.currentTarget.dataset.label
    regionInfo.district.index = e.currentTarget.dataset.index
    this.setData({
      'regionIdShow.districtId': e.currentTarget.dataset.id,
      'regionLabel.district': e.currentTarget.dataset.label
    })
    this.defineLocation()
  },
  initCitys() {
    let region = normalRegion
    let index = regionInfo.province.index
    let subRegions = region[index].subRegions
    let citys = []
    for (let i = 0; i < subRegions.length; i++) {
      let item = {
        regionName: subRegions[i].regionName,
        id: subRegions[i].id
      }
      citys.push(item)
    }
    if (citys.length > 0) {
      this.setData({
        'regionModule.cityModule': citys
      })
    }
  },
  initDistricts() {
    let region = normalRegion
    let index = regionInfo.province.index
    let subIndex = regionInfo.city.index
    let district = region[index].subRegions[subIndex].subRegions
    let districts = []
    for (let i = 0; i < district.length; i++) {
      let item = {
        regionName: district[i].regionName,
        id: district[i].id
      }
      districts.push(item)
    }
    if (districts.length > 0) {
      this.setData({
        'regionModule.districtModule': districts
      })
    }
  },
  defineLocation() {
    if (!this.data.editModule.additional) {
      this.setData({
        addressDef: addressDef
      })
    }
    if (regionInfo.district.id) {
      let region = [regionInfo.province.label, regionInfo.city.label, regionInfo.district.label]
      this.setData({
        region: region,
        regionInfo: regionInfo,
        'regionLabel.province': regionInfo.province.label,
        'regionLabel.city': regionInfo.city.label,
        'regionLabel.district': regionInfo.district.label,
        addressAbled: false
      })
    } else {
      this.setData({
        'regionLabel.province': this.data.regionInfo.province.label,
        'regionLabel.city': this.data.regionInfo.city.label,
        'regionLabel.district': this.data.regionInfo.district.label,
        'regionIdShow.provinceId': this.data.regionInfo.province.id,
        'regionIdShow.cityId': this.data.regionInfo.city.id,
        'regionIdShow.districtId': this.data.regionInfo.district.id
      })
      regionInfo = this.data.regionInfo
    }
    this.setData({
      pickShow: false
    })
  }
}
Component({
  /**
   * 组件的属性列表
   */
  properties: {
    editModule: {
      type: Object,
      value: {},
      observer: function (newVal, oldVal) {
        if (newVal && newVal.province) {
          let regionInfo1 = {
            province: {
              id: newVal.province.id,
              label: newVal.province.regionName,
              index: null
            },
            city: {
              id: newVal.city.id,
              label: newVal.city.regionName,
              index: null
            },
            district: {
              id: newVal.district.id,
              label: newVal.district.regionName,
              index: null
            }
          }
          regionInfo = regionInfo1
          this.setData({
            regionInfo: regionInfo1,
            edit: 1
          })
        }
      }
    },
    region: {
      type: Array
    },
    actType: {
      type: String
    },
    installmentId: {
      type: Number
    }
  },
  data,
  methods,
  ready() {
    if (this.editModule == '') {
      this.setData({
        region: []
      })
    }
    if (wx.getStorageSync('add') == '3') {
      this.setData({
        editModule: [],
        region: []
      })
    }
    this.initProvince()
  }
})