import {
  WGCOMMON,
  WGIMAGE,
  WGROUTER,
  WGAUTH,
  WGSUBSCRIBE,
  Page
} from '../../../../wgUtils/index'
import API from '../../api/index'

const app = getApp()

Page({
  data: {
    tags: [],
    evaluationImages: [], // 评价图片
    evaluationText: '', // 评价文本
    pIds: [], // 选择的产品pid集合
    products: [], // 产品集合
    selectedProLen: 0, // 选择了几款产品
    selectedTagId: -1, // 选择笔记分类的id
    hasNickName: 0, // 是否有头像和昵称
    curTextLen: 0,
    isGray: false,
    isTrial: false, // 是否是试用报告 0正常评价 1试用评价 2谷粉说
    trialData: null, // 试用信息
    trialId: null, // 试用活动id
    canIUseGetUserProfile: false,
    showSubscribeTip: false,
  },
  delImage(e) { // 删除图片
    let index = e.currentTarget.dataset.index
    let tmp = this.data.evaluationImages
    tmp.splice(index, 1)
    this.setData({
      evaluationImages: tmp
    })
  },
  addImgs() { // 添加图片
    let resetLen = 9 - this.data.evaluationImages.length
    if (resetLen == 0) {
      WGCOMMON.toast('最多上传9张图片')
      return
    }
    wx.showNavigationBarLoading()
    WGIMAGE.chooseImageAndUpload(resetLen).then(res => {
      let currentImgs = this.data.evaluationImages,
        sortNum = 0
      if (currentImgs.length > 0) {
        sortNum = currentImgs[currentImgs.length - 1].sortingOrder
      }
      for (let i = 0; i < res.length; i++) {
        currentImgs.push({
          imgUrl: res[i],
          sortingOrder: sortNum + 1 + i
        })
      }
      this.setData({
        evaluationImages: currentImgs
      })
      wx.hideNavigationBarLoading()
    })
  },
  bindinput(e) {
    this.setData({
      curTextLen: e.detail.value.length
    })
  },
  bindconfirm(e) { // 文本内容
    this.setData({
      evaluationText: e.detail.value
    })
  },
  addProduct() { // 添加商品
    if(this.data.isTrial) return
    WGCOMMON.navigateTo('/pages/Search/Search?selectFlag=1')
  },
  resetProductLen() {
    let num = 0
    for (let i = 0; i < this.data.products.length; i++) {
      if (this.data.products[i].selected == 1) {
        num++
      }
    }
    this.setData({
      selectedProLen: num
    })
  },
  toggleProduct(e) { // 切换选择产品
    if(this.data.isTrial) return
    let key = 'products[' + parseInt(e.currentTarget.dataset.index) + '].selected',
      val = e.currentTarget.dataset.selected
    this.setData({
      [key]: val == 1 ? 0 : 1
    })
    this.resetProductLen()
  },
  initTag() { // 初始化笔记分类
    API.getTagListByDisplayArea(0,0,1).then(res => {
      for(let i=0;i<res.length;i++) {
        res[i]['selected'] = false
      }
      this.setData({
        tags: res
      })
    })
  },
  selectedTag(e) { // 选择笔记分类
    let item = e.currentTarget.dataset.item
    let index = e.currentTarget.dataset.index
    let key = `tags[${index}].selected`
    this.setData({
      [key]: !item.selected
    })
    if(!item.selected) {
      this.setData({
        selectedTagId: item.id
      })
    }
  },
  bindgetuserinfo(e) { // 发布帖子需要头像昵称
    WGAUTH.getUserInfo(e).then(res => {
      this.postComment()
      this.setData({
        hasNickName: 1
      })
    })
  },
  getUserProfile() {
    WGAUTH.getUserProfile().then(res => {
      this.postComment()
      this.setData({
        hasNickName: 1
      })
    })
  },
  getSelectedTags() {
    let arr = []
    for(let i=0;i<this.data.tags.length;i++) {
      if(this.data.tags[i].selected) {
        arr.push({
          evaluationTagId: this.data.tags[i].id
        })
      }
    }
    return arr
  },
  postComment() { // 发布帖子
    let _self = this
    if (this.data.isGray) return
    if (this.data.evaluationImages.length <= 0) {
      WGCOMMON.toast('请至少上传一张图片')
      return
    }
    if (this.data.evaluationText.trim().length <= 0) {
      WGCOMMON.toast('请输入文字描述')
      return
    }
    // if (this.data.selectedProLen <= 0) {
    //   WGCOMMON.toast('请至少选择一款产品')
    //   return
    // }
    if (this.getSelectedTags().length === 0) {
      WGCOMMON.toast('请选择笔记分类')
      return
    }
    let products = [],
      pId = -1,
      skuId = -1
    if(this.data.isTrial) { // 试用
      pId = this.data.trialData.activity.trial.productTemplateId
      skuId = this.data.trialData.activity.trial.skuId
    } else { // 非试用
      for (let i = 0; i < this.data.products.length; i++) {
        if (this.data.products[i].selected == 1) {
          products.push(this.data.products[i].pId)
          pId = this.data.products[i].pId
          skuId = this.data.products[i].skuId
        }
      }
    }
    let evaluationObj = {
      cusId: wx.getStorageSync('cusId'),
      cusServiceScore: 5,
      customerId: wx.getStorageSync('openId'),
      deliveryScore: 5,
      evaluationImages: this.data.evaluationImages,
      evaluationTag: this.data.selectedTagId, // 谷粉说笔记分类 
      evaluationTags: this.getSelectedTags(),
      evaluatorHeadImgUrl: wx.getStorageSync('avatarUrl'),
      evaluatorName: wx.getStorageSync('nickName'),
      experienceFlag: this.data.isTrial?1:2, // 谷粉说评价
      productTemplates: products.join(','), //  谷粉说产品（产品id以英文逗号分隔） ,
      ratingDesc: this.data.evaluationText, // 评价说明 
      ratingScore: 5, // 评价分数
      vipCusStatus: wx.getStorageSync('vipCusStatus'),
      productId: skuId,
      productTemplateId: pId,
      isDelete: 0,
      virtualBrowseNumber: 0, //  (integer, optional): 虚拟粉丝说浏览个数 ,
      virtualShareCount: 0, //  (integer, optional): 虚拟分享数 ,
      virtualThumbUpNumber: 0,
      shareCount: 0,
      getThroughFlag: 0,
      stickFlag: 0,
    }
    if(this.data.isTrial) {
      evaluationObj['orderId'] = this.data.trialData.order.id
      evaluationObj['trialId'] = Number(this.data.trialId)
      evaluationObj['orderDetailId'] = this.data.trialData.order.orderDetails[0].id
      if(this.data.trialData.report) {
        evaluationObj['id'] = this.data.trialData.report.id
      }
    }
    console.log(evaluationObj)
    // return
    this.setData({
      isGray: true
    })
    API.postComment([evaluationObj]).then(res => {
      if (res) {
        app.globalData.selectProduct = null
        wx.showModal({
          title: '提示',
          content: this.data.isTrial?'亲爱的谷粉，您的试用报告已提交审核，报告审核通过即可全额退款哦～':'亲爱的谷粉，您的分享已提交成功，若无问题，24小时内就能看到您的分享哦～',
          confirmColor: "#ff491d",
          showCancel: true,
          confirmText: '我知道了',
          success(res) {
            _self.setData({
              isGray: false,
              showSubscribeTip: true,
            })
            WGSUBSCRIBE('postComment').then((res) => {
              console.log(res)
              _self.setData({
                showSubscribeTip: false
              })
              setTimeout(()=>{
                WGROUTER.navigateBack()
              },3000)
            }).catch(() => {
              _self.setData({
                showSubscribeTip: false
              })
              setTimeout(()=>{
                WGROUTER.navigateBack()
              },3000)
            })
            app.globalData.selectProduct = null
          }
        })
      } else {
        _self.setData({
          isGray: false
        })
      }
    }).catch(e => {
      _self.setData({
        isGray: false
      })
    })
  },
  initTrial() {
    let tmp = app.globalData.trialData
    console.log(tmp)
    this.data.trialData = tmp
    this.setData({
      isTrial: true,
      products: [{
        pId: tmp.activity.trial.productTemplateId,
        name: tmp.activity.trial.productTemplateName,
        imgUrl: tmp.order.orderDetails[0].productTemplate.groupedImages.icon?tmp.order.orderDetails[0].productTemplate.groupedImages.icon[0].imageUrl:tmp.activity.trial.imgUrl,
        skuId: tmp.activity.trial.skuId,
        selected: 1,
      }]
    })
    if(tmp.report) {
      this.setData({
        evaluationText: tmp.report.ratingDesc,
        selectedTagId: tmp.report.evaluationTag,
        evaluationImages: tmp.report.evaluationImages
      })
    }
  },
  watchBack(showSubscribeGif) {
    console.log('showSubscribeGif--------', showSubscribeGif)
    this.setData({
      showSubscribeTip: showSubscribeGif
    })
  },
  onLoad(option) {
    wx.hideShareMenu()
    this.initTag()
    if (wx.getStorageSync('nickName') && wx.getStorageSync('avatarUrl')) {
      this.setData({
        hasNickName: 1
      })
    }
    if(option.isTrial) { // 试用报告
      this.setData({
        trialId: option.trialId
      })
      this.initTrial()
    }
    if (wx.getUserProfile) {
      this.setData({
        canIUseGetUserProfile: true
      })
    }
  },
  onUnload() {
    app.globalData.selectProduct = null
  },
  onShow() {
    let pros = this.data.products,
      pIds = this.data.pIds,
      selectProduct = app.globalData.selectProduct
    getApp().watch(this.watchBack)
    if (selectProduct && pIds.indexOf(selectProduct.pId) == -1) {
      selectProduct['selected'] = 1
      pros.push(selectProduct)
      pIds.push(selectProduct.pId)
      this.setData({
        products: pros,
        pIds: pIds,
        selectedProLen: pros.length
      })
    }
    this.resetProductLen()
  },
})