// pages/search/search.js
import {
  WGHTTP,
  Page,
  WGENV,
  WGFORMAT
} from '../../../../wgUtils/index'
import API from '../../api/index'
import {
  TOAST,
  REQUEST
} from '../../../../utils/index'
import HELPER from '../../utils/helper'

Page({
  /**
   * 页面的初始数据
   */
  data: {
    rencentSearchArray: [],
    hotSearchArray: [],
    inputValue: '',
    currentPage: 1,
    searchResults: [],
    recommendResults: [],
    isInputing: false,
    showingResults: false,
    noMoreData: false,
    isLoading: false,
    noRecommendResultData: {
      imgUrl: "https://img.wgmf.com/contentmp/img_biji.png",
      message: "没有相关的内容哦~",
    },
    noSearchResultData: {
      imgUrl: "https://img.wgmf.com/contentmp/img_sousuokong.png",
      message: "没有找到相关内容，换个词试试吧～",
    },
  },
  //输入
  bindKeyInput: function (e) {
    this.setData({
      inputValue: e.detail.value,
    });
  },
  //聚焦
  inputFocus: function (e) {
    const isInputing = true;
    this.setData({
      isInputing
    });
  },
  //失去焦点
  inputBlur: function (e) {
    const isInputing = false;
    this.setData({
      isInputing
    });
  },
  //点击键盘'搜索'键
  confirmToSearch(e) {
    this.setData({
      inputValue: e.detail.value,
    });
    this.tapToSearch();
  },
  //点击'搜索'按钮
  tapToSearch() {
    if (!this.data.inputValue || this.data.inputValue.length === 0) {
      TOAST.error('请输入要搜索的内容!');
      return;
    }
    this.setData({
      searchResults: [],
      currentPage: 1,
      noMoreData: false,
      showingResults: true,
    });
    this.searchKeywords(false);
    this.setRencentWordsToStorage();
  },
  //把'最近的搜索记录'存入本地
  setRencentWordsToStorage() {
    let rencentSearchArray = wx.getStorageSync("rencentSearchArray");
    if (!rencentSearchArray) {
      rencentSearchArray = [this.data.inputValue];
    } else {
      let tempArray = rencentSearchArray,
        i = 0,
        repeatFlag = false;
      for (const keyword in rencentSearchArray) {
        if (rencentSearchArray[keyword] === this.data.inputValue) {
          repeatFlag = true;
          i = keyword;
          break;
        }
      }
      //有重复词
      if (repeatFlag) {
        tempArray.splice(i, 1);
        tempArray.unshift(this.data.inputValue);
      } else {
        if (rencentSearchArray.length < 10) {
          tempArray.unshift(this.data.inputValue);
        } else {
          tempArray.splice(rencentSearchArray.length - 1, 1);
          tempArray.unshift(this.data.inputValue);
        }
      }
      rencentSearchArray = tempArray;
    }
    this.setData({
      rencentSearchArray
    });
    wx.setStorage({
      key: "rencentSearchArray",
      data: rencentSearchArray,
    });
  },
  hotSearch() {
    // WGHTTP.get(API.get_miniAppContentHotWords).then((res) => {
    //     const hotSearchArray = res;
    //     this.setData({ hotSearchArray });
    // });
  },
  //搜索功能
  searchKeywords(isLoadingMore) {
    this.setData({
      isLoading: true
    })
    REQUEST.get(WGENV.baseUrl + 'wechat-shop-back/evaluation/search', {
      data: {
        ratingDesc: this.data.inputValue,
        curPage: this.data.currentPage,
        pageSize: 10,
      }
    }).then(res => {
      wx.hideLoading()
      const isLoading = false;
      this.setData({
        isLoading
      });
      if (res.data.status == 0) {
        let list = res.data.data
        if (list.length > 0) {
          for (let i = 0; i < list.length; i++) {
            list[i]['isLike'] = false
            list[i]['browseNumberCn'] = WGFORMAT.formatNumber(list[i].browseNumber + list[i].virtualBrowseNumber)
            list[i]['thumbUpNumberCn'] = WGFORMAT.formatNumber(list[i].thumbUpNumber + list[i].virtualThumbUpNumber)
            if ((list[i].contentFrontUrl == null || list[i].contentFrontUrl == "") && list[i].evaluationImages.length != 0) {
              list[i].contentFrontUrl = list[i].evaluationImages[0].imgUrl
            }
          }
          let commentModule = this.data.searchResults
          this.setData({
            curPage: this.data.currentPage + 1,
            searchResults: [...commentModule, ...list]
          })
        }
        if (list.length < 10) {
          this.setData({
            moreTxt: '别拖啦，到底啦~',
            noMoreData: true
          })
        }
      } else {
        this.setData({
          moreTxt: '别拖啦，到底啦~',
          noMoreData: true
        })
      }
      this.setData({
        isLoading: false
      })
    }).catch(() => {
      this.setData({
        isLoading: false
      })
    })
  },
  //点击 历史搜索 标签
  tapHistoryWordsToSearch(e) {
    this.setData({
      inputValue: e.currentTarget.dataset.selectedKeyword
    });
    this.tapToSearch();
  },
  //点击 热门搜索 标签
  tapHotWordsToSearch(e) {
    const keyWord = e.currentTarget.dataset.selectedKeyword;
    const inputValue = HELPER.removeEmoji(keyWord);
    this.setData({
      inputValue
    });
    this.tapToSearch();
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    // this.hotSearch();
    let rencentSearchArray = wx.getStorageSync("rencentSearchArray");
    this.setData({
      rencentSearchArray
    });
    // this.getRecommendContentList();
  },
  pullUpToLoadMore: function () {
    if (this.data.noMoreData || this.data.isLoading) {
      return;
    }
    let currentPage = this.data.currentPage + 1;
    this.setData({
      currentPage
    });
    if (this.data.showingResults === true) {
      this.searchKeywords(true);
    } else {
      // this.getRecommendContentList(true);
    }
  },
  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (this.data.isLoading) return; //正在加载时, 不触发加载更多
    this.pullUpToLoadMore();
  },

  //获取'大家都在看'内容列表内容
  getRecommendContentList(isLoadingMore) {
    const isLoading = true;
    this.setData({
      isLoading
    });
    const myOpenId = wx.getStorageSync("openId");
    // WGHTTP.get(API.get_everybodyWatching, {
    //   curPage: this.data.currentPage,
    //   pageSize: 10,
    //   openId: myOpenId,
    // }).then((res) => {
    //   const isLoading = false;
    //   this.setData({
    //     isLoading
    //   });
    //   //if (res.status === 0) {
    //   let recommendResults = this.data.recommendResults;
    //   const dataArray = res;
    //   if (isLoadingMore === true) {
    //     recommendResults.push(...dataArray);
    //   } else {
    //     recommendResults = dataArray;
    //   }
    //   let noMoreData = false;
    //   if (dataArray.length < 10) {
    //     noMoreData = true;
    //   }
    //   this.setData({
    //     recommendResults,
    //     noMoreData
    //   });
    // }).catch((error) => {
    //   console.log(error);
    // })
  },

  /**
   * 用户点击右上角分享
   */
  // onShareAppMessage: function () {
  //   return {
  //     title: '超赞的营养百科知识，快点来看！',
  //     path: 'modules/FanCommunity/pages/Search/Search'
  //   }
  // },
});