import {WGROUTER, WGFORMAT, WGAUTH, WGHTTP, Page} from "../../../../wgUtils/index"
import API from '../../api/fanCommunityApi'
import ROUTER from "../../utils/fanCommunityRouter"
import { LOADING, TOAST } from '../../../../utils/index'


Page({
  data: {
    contentId: null,  // 笔记id
    comment: null,  // 谷粉说内容
    bannerHeight: 350,  // 轮播图高度
    currentIndex: 1, // 轮播图的指示点index
    totalImgsLen: 1, // 轮播图指示点数量
    products: [], // 产品 
    isLike: false, // 是否点赞了这条谷粉说
    needLogin: false,  // 是否需要用户信息授权
    currentStatus: 1, //1表示查看别人的笔记, 2表示查看自己的笔记
    deletingNote: false, //删除笔记
  },
  loadImg(e) {  // 轮播图加载，获取图片高度，设置banner高度
      var imgh = e.detail.height;　　　　　　　　　　　　　　　　 //图片高度
      var imgw = e.detail.width;
      let index = e.currentTarget.dataset.index
      if(this.data.bannerHeight == 350 && index == 0) {
        this.setData({
            bannerHeight: (imgh / imgw) * 750 > 1000 ? 1000:(imgh / imgw) * 750
        })
      }
  },
  changeSwiper(e) { // 切换轮播图的index
    this.setData({
      currentIndex: e.detail.current + 1
    })
  },
  preview(e) { // 预览轮播图图片
    let index = e.currentTarget.dataset.index
    let originImgs = this.data.comment.evaluationImages
    if(originImgs) {
      let imgs = []
      for(let i=0;i<originImgs.length;i++) {
        imgs.push(originImgs[i].imgUrl)
      }
      wx.previewImage({
        current: imgs[index], // 当前显示图片的http链接
        urls: imgs // 需要预览的图片http链接列表
      })
    }
  },
  //点击 去购买商品
  tapToBuyProduct(e) {
    const pId = e.currentTarget.dataset.productId;
    WGROUTER.navigateTo(`/pages/ProductDetail/ProductDetail?pId=${pId}&_campaign=WGContentMp_${this.data.contentId}`);
    WGHTTP.post(API.post_sendContentUserProMsg, {
      customerId: wx.getStorageSync('openId'),
      templateId: pId
    }).then(res => {
    });
  },
  initTrialReport(id) { // 初始化谷粉说内容
    LOADING.show()
    const currentOpenId = wx.getStorageSync('openId');
    WGHTTP.get(API.get_userNotesDetail, {
      'contentId':id,
      'openId': currentOpenId
    }).then(r => {
      let res = r
      let imgs = res.miniAppContentImageList;
      res.createdDate = WGFORMAT.formatDate(res.createdDate, 'yyyy-MM-dd');
      this.setData({
        totalImgsLen: imgs.length
      })
      imgs.sort(function (a, b) { 
        if(a.sortingOrder - b.sortingOrder == 0) {
          return a.id - b.id
        }
        return a.sortingOrder - b.sortingOrder
      })
      res['miniAppContentImageList'] = imgs
      const isLike = res.likesFlag === 1 ? true : false;
      this.setData({
        comment: res,
        isLike
      })
      LOADING.hide()
    })
  },

  onLoad(option) {
    // 如果已登录则获取点赞信息
    if(!wx.getStorageSync('phone')) {
      this.setData({
        needLogin: true
      })
    }
    if (option.currentStatus) {
      this.setData({
        currentStatus: option.currentStatus
      })
    }
    this.setData({
      contentId: option.contentId
    })
    this.recordBrowseNumbers();
  },
  onShow: function () {
    console.log(this.data.contentId);
    this.initTrialReport(this.data.contentId) // 初始化谷粉说内容
  },
  onShareAppMessage: function() { // 自定义点击右上角转发内容
    this.saveContentShare();
    return {
      title: '我发现了一篇超赞的笔记，分享给你，快点来看！',
      imageUrl: this.data.comment.miniAppContentImageList[0].imgUrl,
      path: 'modules/FanCommunity/pages/UserNoteDetail/UserNoteDetail?contentId=' + this.data.contentId
    }
  },
  saveContentShare() {
    const currentOpenId = wx.getStorageSync('openId');
    WGHTTP.post(API.post_saveMiniAppContentShare, {
      'contentId': this.data.contentId,
      'openId': currentOpenId
    }).then(res => {

    })
  },
  recordBrowseNumbers() {
    const currentOpenId = wx.getStorageSync('openId');
    WGHTTP.post(API.post_sendContentBrowseMsg, {
      'contentId': this.data.contentId,
      'openId': currentOpenId
    }).then(res => {
    })
  },
  getPhoneNumber(e) {
    let that = this
    WGAUTH.getPhoneNumber(e).then((res) => {
      this.setData({needLogin: false}); 
      this.clickThump();
    });
  },
  //点赞功能
  clickThump() {
    const isLike = !this.data.isLike;
    this.setData({isLike});  
    if (!this.data.needLogin) {
      const currentOpenId = wx.getStorageSync('openId');
      WGHTTP.post(API.post_saveMiniAppContentLikes, {
        'contentId': this.data.contentId,
        'openId': currentOpenId
      }).then(res => {
      });
    }
  },
  //准备删除笔记
  clickToDeleteNoto() {
    this.setData({deletingNote: true});
  },
  //重新编辑
  clickToReEdite() {
    const comment = encodeURIComponent(JSON.stringify(this.data.comment));//函数可把字符串作为 URI 组件进行编码
    const urlRouter = ROUTER.router_post_comment + `?contentId=${this.data.contentId}&comment=${comment}&type=1`
    WGROUTER.navigateTo(urlRouter);
  },
  //确认删除
  confirmToDelete() {
    WGHTTP.post(API.post_deleteUserNotes, {
      'contentId': this.data.contentId
    }).then(res => {
      if (res.status === 0) {
        TOAST.success(res.msg);
        WGROUTER.navigateBack();
      }
    });
    this.setData({deletingNote: false});
  },

  //放弃删除
  abandonToDelete() {
    this.setData({deletingNote: false});
  }
})