// modules/LivePlay/pages/Playback/Playback.js
import { TOAST, } from "../../../../utils/index";
import LIVEPLAYAPI from "../../api/livePlayApi";
import { WGSUBSCRIBE, Page, WGHTTP, WGFORMAT } from "../../../../wgUtils/index";
Page({
  /**
   * 页面的初始数据
   */
  data: {
    livingInfo: {},
    isLiving: false,
    trailerData: [],
    playbackData: [],
    isLoading: false,
    currentPage: 1,
    pageSize: 10,
    noMoreData: false,
  },
  getLiveRoomInfoByStatus(liveStatus, isLoadingMore) {
    let params;
    switch (liveStatus) {
      case 101:
      case 102:
        {
          params = { liveStatus: liveStatus };
        }
        break;
      case 103:
        {
          params = {
            liveStatus: liveStatus,
            pageIndex: this.data.currentPage,
            pageSize: this.data.pageSize,
          };
          const isLoading = true;
          this.setData({ isLoading });
        }
        break;
      default:
        break;
    }
    WGHTTP.get(LIVEPLAYAPI.listMiniLiveRoomInfoByLiveStatus, params)
      .then((res) => {
        switch (liveStatus) {
          case 101:
            {
              const livingInfo = res[0];
              if (livingInfo) {
                const isLiving = Object.keys(livingInfo).length > 0;
                this.setData({ livingInfo, isLiving });
              }
            }
            break;
          case 102:
            {
              let data = res;
              for (const key in data) {
                let itemObject = data[key];
                let endIndex = itemObject.startTime.length - 3;
                itemObject.startTime = (itemObject.startTime.substring(0, endIndex)).replace(/\-/g, '.');
              }
              const trailerData = data;
              this.setData({ trailerData });
            }
            break;
          case 103:
            {
              const isLoading = false;
              this.setData({ isLoading });
              let playbackData = this.data.playbackData;
              const dataArray = res;
              for (const key in dataArray) {
                let itemObject = dataArray[key];
                itemObject.startTime = itemObject.startTime.replace(new RegExp('-','g'), '/');
                itemObject.startTime = WGFORMAT.formatDate(itemObject.startTime, 'yyyy-MM-dd');
              }
              if (isLoadingMore === true) {
                playbackData.push(...dataArray);
              } else {
                playbackData = dataArray;
              }
              let noMoreData = false;
              if (dataArray.length < this.data.pageSize) {
                noMoreData = true;
              }
              this.setData({ playbackData, noMoreData });
            }
            break;
          default:
            break;
        }
      })
      .catch((error) => {
        console.log(error);
      });
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.getLiveRoomInfoByStatus(101, false);
    this.getLiveRoomInfoByStatus(102, false);
    this.getLiveRoomInfoByStatus(103, false);

    try {   
      wx.onCopyUrl(() => {
        return { query: WGFORMAT.formatQueryByOptions(options) }
      })
    } catch (error) {
      console.warn('暂不支持wx.onCopyUrl')
    }
  },
  //进入 直播中直播间
  goToLivingRoom() {
    const router = `${LIVEPLAYAPI.WXLiveRoomRouter}?room_id=${this.data.livingInfo.roomId}`;
    wx.navigateTo({
      //跳转直播间
      url: router
    });
  },
  //进入 预告直播间
  goToTrailerRoom(event) {
    const roomId = event.currentTarget.dataset.currentItem.roomId;
    const router = `/modules/LivePlay/pages/LiveRoom/LiveRoom?roomId=${roomId}`;
    wx.navigateTo({
      //跳转直播间
      url: router
    });
  },
  //进入 回访直播间
  goToPlaybackRoom(event) {
    const roomId = event.currentTarget.dataset.currentItem.roomId;
    const router = `${LIVEPLAYAPI.WXLiveRoomRouter}?room_id=${roomId}`;
    wx.navigateTo({
      //跳转直播间
      url: router
    });
  },
  subscibeNotification(event) {
    const roomId = event.currentTarget.dataset.currentItem.roomId;
    WGSUBSCRIBE('remindLiveRoom').then(r => {
      if (r == 1) {
        TOAST.success('订阅成功!');
      }
    });
  },
  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {},

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {},

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (this.data.isLoading) return; //正在加载时, 不触发加载更多
    this.pullUpToLoadMore();
  },
  pullUpToLoadMore: function () {
    if (this.data.noMoreData === true) {
      return;
    }
    let currentPage = this.data.currentPage + 1;
    this.setData({ currentPage });
    this.getLiveRoomInfoByStatus(103, true);
  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function (res) {
    if (res.from == "button") {
      if (res.target.id == 1) {
        return {
          title: '我发现了一个超多福利的直播！快一起来围观~',
          imageUrl: this.data.livingInfo.miniLiveShareInfo.shareUrl,
          path: `/modules/LivePlay/pages/LiveRoom/LiveRoom?roomId=${this.data.livingInfo.roomId}`
        }
      }
    }
    return {
      title: '看直播，拿福利！海量钜惠尽在五谷磨房直播间',
      imageUrl: 'https://img.wgmf.com/wgmall/share_playback_room.jpg'
    }
  },
  onShareTimeline() {
    return {
      title: '看直播，拿福利！海量钜惠尽在五谷磨房直播间',
      imageUrl: 'https://img.wgmf.com/wgmall/share_playback_room.jpg'
    }
  },
});
