import { Page, WGAUTH, WGCOMMON, WGSUBSCRIBE, WGENV, WGFORMAT } from '../../../../wgUtils/index'
import API from '../../api/index'
import ROOTAPI from '../../../../api/index'
Page({
  data: {
    showAuth: false,  // 是否需要授权登录，没有cusId则需要
    cards: [],
    activeIndex: -1, // 当前展示的卡片
    isRemind: false, // 是否已经预约明天提醒
    isComposited: 0, // 是否已经合成卡片。是否已合成0-否，1-是 ,
    cardCounts: 0, // 当前收集的卡片数
    collectionId: null, // 集卡活动id
    showCompositePopup: false, // 显示合成弹窗
    isCompositing: false, // 正在进行合成请求中
  },
  closeModal() {
    this.setData({
      showCompositePopup: false
    })
  },
  toHome() {
    wx.switchTab({
      url: '/pages/Home/Home'
    })
  },
  fillForentZero(num) {
    if(num < 10) {
      num = '0' + num.toString()
    }
    return num
  },
  initData() {
    if(wx.getStorageSync('cusId')) {
      this.setData({
        showAuth: false
      })
      WGCOMMON.showLoading()
      API.cardCollection(wx.getStorageSync('cusId')).then(r => {
        if(r.status != 0) {
          WGCOMMON.hideLoading()
          wx.showModal({
            title: '提示',
            content: '活动已结束',
            confirmText: '返回首页',
            showCancel: false,
            success (res) {
              wx.switchTab({
                url: '/pages/Home/Home'
              })
            }
          })
          return
        }
        let res = r.data
        if(res) {
          let arr = res.cardCollectionOrderDetailResultList
          for(let i=0;i<arr.length;i++) {
            let date = new Date(arr[i].cardCollectionLine.startTime)
            arr[i].cardCollectionLine['startTimeCn'] = `${this.fillForentZero(date.getMonth() + 1)}.${this.fillForentZero(date.getDate())}`
            let needReceive = WGFORMAT.targetDateInDateBetwen(arr[i].cardCollectionLine.startTime, arr[i].cardCollectionLine.endTime, new Date())  // 是否显示前往领取按钮：未领取且卡片处于活动时间内
            arr[i].cardCollectionLine['cardImage'] = arr[i].cardCollectionLine.grayCardImgUrl // 卡片未获得为灰色，已获得为彩色
            if(JSON.stringify(arr[i].cardCollectionOrderDetail) != '{}' && arr[i].cardCollectionOrderDetail.cardStatus == 1) { // 卡片状态0-漏卡，1-已领取，2-未领取 ,
              needReceive = false
              arr[i].cardCollectionLine['cardImage'] = arr[i].cardCollectionLine.cardImgUrl
            }
            arr[i].cardCollectionLine['needReceive'] = needReceive
          }
          this.setData({
            cards: arr,
            activeIndex: arr.length > 0?0:-1,
            isComposited: res.isComposited,
            cardCounts: res.cardCounts,
            collectionId: res.collectionId
          })
        }
        WGCOMMON.hideLoading()
      })
    } else {
      this.setData({
        showAuth: true
      })
    }
    if(wx.getStorageSync('collectCardRemind')) {
      let date = new Date().toLocaleDateString()
      if(wx.getStorageSync('collectCardRemind') == date) {
        this.setData({
          isRemind: true
        })
      }
    }
  },
  authSuccess() {
    this.initData()
  },
  authFail() {
    WGCOMMON.toast('授权失败，请重试')
    wx.clearStorage()
    WGAUTH.wxLogin()
  },
  combinateCard() { // 点击合成卡片
    if(this.data.cardCounts < 8 || !this.data.collectionId) {
      WGCOMMON.toast('您还未收集到全部宝卡，暂时无法合成哦~~~')
      return
    } 
    if(this.data.isCompositing) {
      return
    }
    this.data.isCompositing = true // 正在进行合成请求中
    WGCOMMON.showLoading('合成中')
    API.composeCard(wx.getStorageSync('cusId'), this.data.collectionId).then(res => {
      if(res) {
        this.setData({
          showCompositePopup: true,
          isComposited: 1
        })
        this.initData()
      }
      this.data.isCompositing = false
      WGCOMMON.hideLoading()
    }).catch(() => {
      this.data.isCompositing = false
      WGCOMMON.hideLoading()
    })
  },
  remind() { // 提醒我明天领卡
    if(!this.data.isRemind) {
      WGSUBSCRIBE('remindPromotion').then(res => {
        if(res != 0 && res != 1) {
          WGCOMMON.toast("您已关闭订阅消息权限，请前往右上角设置开启权限", 3000)
        } else {
          if(res == 1) {
            let data = {
              msgType: 2,
              appId: WGENV.env == 'TEST'?'wx6d33fa16e7a26c3a':'wx29d1ac1fcd50aeb6'
            }
            if(wx.getStorageSync('cusId')) { data['cusId'] = wx.getStorageSync('cusId') }
            if(wx.getStorageSync('openId')) { data['openId'] = wx.getStorageSync('openId') }
            ROOTAPI.promotion.remindPromotion(data).then(r => {
              if(r) {
                WGCOMMON.toast('预约成功！')
                this.setData({
                  isRemind: true
                })
                let date = new Date().toLocaleDateString()
                wx.setStorageSync('collectCardRemind', date)
              }
            })
          }
        }
      })
    }
  },
  clickCard(e) {
    this.setData({
      activeIndex: e.target.dataset.index
    })
  },
  onShareAppMessage: function() { // 自定义点击右上角转发内容
    return {
      title: '66元粥料免费送？集福卡，9大福利等你拿！',
      imageUrl: 'https://img.wgmf.com/wgmall/collect-card/CollectCardCover.jpg?imageslim',
      path: 'modules/MallPromotion/pages/CollectCard/CollectCard',
    }
  },
  onShareTimeline() { // 分享朋友圈
    return {
      title: '66元粥料免费送？集福卡，9大福利等你拿！',
      imageUrl: 'https://img.wgmf.com/wgmall/collect-card/CollectCardCover.jpg?imageslim',
      path: 'modules/MallPromotion/pages/CollectCard/CollectCard',
    }
  },
  onLoad() {
    this.initData()
  },
})