import WGAPI from '../../api/index'
import {
  WGENV,
  Page,
  WGCOMMON,
  WGFORMAT
} from '../../../../wgUtils/index'
import { REQUEST } from '../../../../utils/index';

const app = getApp()

Page({
  data: {
    activity: null,
    id: null, // 试用活动id
    form: { // 申请表单
      addressId: null, // (integer, optional): 地址id ,
      applyResc: '', // (string, optional): 申请理由 ,
      customerId: wx.getStorageSync('cusId'), // (integer, optional): 客户id ,
      isSvipCustomer: wx.getStorageSync('vipCusStatus') == 1?1:0, // (integer, optional): 是否超级会员0否1是 ,
      miniOpenId: wx.getStorageSync('openId'), // (string, optional): 小程序openId ,
      trialId: null, // (integer, optional): 新品试用活动Id ,
      unionid: wx.getStorageSync('unionId'), // (string, optional): 用户unionid ,
      wechatHeadImgUrl: wx.getStorageSync('avatarUrl'), // (string, optional): 微信头像地址 ,
      wechatName: wx.getStorageSync('nickName'), // (string, optional): 新品试用人昵称
      deliveFee: 0, // 运费
    },
    focusTextarea: false, // 文本框聚焦
    hideTextarea: true, // 隐藏文本框输入面板
    hideModal1: true,
    hideModal2: true,
    applying: false,
  },
  closeModal() {
    this.setData({
      hideModal1: true,
      hideModal2: true
    })
  },
  bindblur(e) {
    this.setData({
      ['form.applyResc']: e.detail.value
    })
  },
  pullUpKeyBoard() { // 拉起申请理由的输入键盘
    this.setData({
      hideTextarea: false
    }, () => {
      this.setData({
        focusTextarea: true
      })
    })
  },
  hideKeyboard() { // 隐藏申请理由的输入键盘
    this.setData({
      hideTextarea: true,
      focusTextarea: false,
    })
  },
  submitForm() { // 提交申请表单
    console.log(this.data.form)
    let that = this
    if(!this.data.form.addressId) {
      WGCOMMON.toast('请填写收货地址')
      return
    }
    if(this.data.form.applyResc.trim().length < 30) {
      // WGCOMMON.toast('申请理由至少输入30个字')
      this.setData({
        hideModal1: false
      })
      return
    }
    this.data.form.wechatHeadImgUrl = wx.getStorageSync('avatarUrl')
    this.data.form.wechatName = wx.getStorageSync('nickName')
    this.data.form.unionid = wx.getStorageSync('unionId')
    this.data.form.miniOpenId = wx.getStorageSync('openId')
    this.data.form.customerId = wx.getStorageSync('cusId')
    if(!this.data.applying) { // 没有正在申请中
      this.setData({ // 锁启动，用户重新点击不会重复下单
        applying: true
      })
      WGCOMMON.showLoading()
      REQUEST.post(WGENV.baseUrl + 'wechat-shop-back/trial/confirmTrial', {
        header: {
          'content-type': 'application/json'
        },
        data: this.data.form
      }).then(r => {
        if(r.data.status == 0) {
          let res = r.data.data
          let item = {
            trial: this.data.activity.trial,
            trialOrder: res
          }
          item.trial['startTimeEn'] = WGFORMAT.formatDate(item.trial.startTime, 'yyyy.MM.dd hh:mm')
          item.trial['endTimeEn'] = WGFORMAT.formatDate(item.trial.endTime, 'yyyy.MM.dd hh:mm')
          app.globalData['myApplyDetail'] = item
          console.log('myApplyDetail----------', item)
          if(res) {
            let orderId = res.orderId
            WGAPI.orderDetail(res.orderId).then(res => {
              if(res) {
                wx.request({
                  url: WGENV.baseUrl + 'wechat-pay/pay/bill/ma' + res.orderCode,
                  method: 'POST',
                  header: {
                    'content-type': 'application/x-www-form-urlencoded'
                  },
                  data: {
                    openId: wx.getStorageSync('openId')
                  },
                  success(res) {
                    if(res) {
                      let data = res.data
                      // 支付
                      wx.requestPayment({
                        'timeStamp': data.timeStamp,
                        'nonceStr': data.nonceStr,
                        'package': data.packageStr,
                        'signType': data.signType || 'MD5',
                        'paySign': data.paySign,
                        'success': function(res) { // 支付成功跳转到申请详情页
                          // app.globalData['myApplyDetail'] = item
                          WGCOMMON.hideLoading()
                          that.setData({
                            applying: false
                          })
                          wx.redirectTo({
                            url: `/modules/ProductTrial/pages/ApplyDetail/ApplyDetail?trialId=${that.data.id}&orderId=${orderId}`
                          })
                        },
                        'fail': function (res) { // 未支付or支付失败，跳转到订单详情页
                          WGCOMMON.hideLoading()
                          that.setData({
                            applying: false
                          })
                          wx.redirectTo({
                            url: '/pages/OrderDetail/OrderDetail?billId=' + orderId
                          })
                        }
                      })
                    } else {
                      this.setData({
                        applying: false
                      })
                    }
                  },
                  fail(err) {
                    WGCOMMON.toast(err)
                    that.setData({
                      applying: false
                    })
                    WGCOMMON.hideLoading()
                  }
                })
              } else {
                that.setData({
                  applying: false
                })
                WGCOMMON.hideLoading()
              }
            })
          } else {
            that.setData({
              applying: false
            })
            WGCOMMON.hideLoading()
          }
        } else if (r.data.status == -2) {
          that.setData({
            hideModal2: false,
            applying: false
          })
          WGCOMMON.hideLoading()
        } else {
          that.setData({
            applying: false
          })
          WGCOMMON.toast(r.data.msg)
          WGCOMMON.hideLoading()
        }
      }).catch(e => {
        that.setData({
          applying: false
        })
        WGCOMMON.hideLoading()
      })
    }
  },
  getAddress (args) {
    this.setData({
      ['form.addressId']: args.detail.address.id,
      ['form.deliveFee']: args.detail.deliveFee
    })
  },
  initActivity (id) {
    WGCOMMON.showLoading()
    WGAPI.detail(id).then(res => {
      let now = new Date().getTime()
      if(now > res.trial.endTime) { // 活动已结束
        WGCOMMON.toast('活动已结束，无法申请！', 3500)
        setTimeout(function() { wx.navigateBack() }, 3500)
        return
      }
      if(now < res.trial.startTime) { // 活动还未开始
        WGCOMMON.toast('活动还未开始，无法申请！', 3500)
        setTimeout(function() { wx.navigateBack() }, 3500)
        return
      }
      this.setData({
        activity: res
      })
      WGCOMMON.hideLoading()
    }).catch(() => {
      WGCOMMON.hideLoading()
    })
  },
  onLoad (option) {
    this.initActivity(option.id)
    this.setData({
      id: option.id,
      ['form.trialId']: option.id
    })
  }
})