import {
  SHOPCARTSERVER,
  UTIL,
  COUPON,
} from '../../utils/index'
import API from '../../api/index'
import {
  Page,
  WGCOMMON,
  WGFORMAT,
} from '../../wgUtils/index';

const app = getApp()
let isInitCarting = false // 是否正在初始化购物车
let isComputingSave = false // 是否正在计算优惠明细中
let lastRequestSaveTime = null // 上一次请求优惠明细的时间
let couponSaveTempResult = null // 缓存上一次优惠的计算结果
let initTotalTicker = null // 计算防抖的定时器
Page({
  data: {
    isLogin: false, // 是否已经登录
    cartModule: [], // 购物车里的商品信息列表
    intProsNum: 0, // 积分兑换的商品数量
    checkedIntProsNum: 0, // 选中的积分兑换商品数量
    proNum: 0, // 选择要结算的总商品数量
    price: {
      originTotal: 0, // 商品原价合计
      saveTotal: 0, // 优惠合计
      actualTotal: 0, // 实付合计
      activitySave: 0, // 特价活动优惠
      svipSave: 0, // 超会95折优惠
      couponSave1: 0, // 全场优惠券
      couponSave2: 0, // 专享优惠券
    },
    overTime: false, // 优惠计算接口超时或者报错
    isAllChecked: false, // 是否选择了全部商品
    showSaveDetial: false, // 是否显示优惠明细面板
    showFreightAddOn: false, // 是否显示"积分商品凑单免运费"提示
    showFreightAddOnPopup: false, // 是否显示"积分商品凑单免运费"提醒弹窗
    addOnTips: "", // 凑单提示
    minTicket: null, // 凑单提示的最小面额优惠券
    maxTicket: null, // 凑单提示的最大面额优惠券
    tickets: [], // 用户的优惠券列表
    ticketFlag: false, // 是否已经请求过优惠券列表了----用于防止重复请求
    totalOriginPrice: 0,
    satisfyCoupon: { status: -1, content: '' }, // 已满足的优惠券文案
  },
  initCart() { // 初始化购物车
    if(!isInitCarting) {
      WGCOMMON.showLoading()
      isInitCarting = true
      let cartModule = SHOPCARTSERVER.initCart() // 获取全部的购物车数据
      let isAllChecked = (SHOPCARTSERVER.getCartNum() == SHOPCARTSERVER.getCheckedQuantity())
      let intProsNum = SHOPCARTSERVER.getIntegralProsNum() // 积分商品数量
      let checkedIntProsNum = SHOPCARTSERVER.getCheckedInteQuantity()
      let proNum = SHOPCARTSERVER.getCheckedQuantity() // 选中的商品数量
      let vipCusStatus = parseInt(wx.getStorageSync('vipCusStatus'))
      for(let i=0;i<cartModule.length;i++) {
        cartModule[i]['isPromotion'] = false // 是否在促销中：特价/限时折扣（非原价的时候）
        if(cartModule[i].endTime) {
          let nowPrice = WGFORMAT.formatCurrency(vipCusStatus == 1?cartModule[i].price/0.95:cartModule[i].price)
          cartModule[i]['endTimeText'] = WGFORMAT.formatDate2EndText(cartModule[i].endTime)
          cartModule[i]['isPromotion'] = (nowPrice !== cartModule[i].originPrice) // 是否是原价
        }
      }
      this.setData({
        cartModule,
        isAllChecked,
        intProsNum,
        checkedIntProsNum,
        proNum
      }, () => {
        console.log('初始化购物车cart', cartModule)
        this.initTotal1() // 计算商品总价
        // this.initAddOnTips() // 凑单提示
        this.checkIntegralAddOnPop() // 积分商品凑单免运费提示
        isInitCarting = false
        WGCOMMON.hideLoading()
      })
    }
  },
  initTotal(operateFromIntPro) { // 计算购物车总价
    console.log('引起重新计算总价的操作是否来自积分商品', operateFromIntPro)
    if(operateFromIntPro) { // 操作是否来自积分商品，如果是的话，不进行计算逻辑
      this.checkIntegralAddOnPop() // 积分商品凑单免运费提示
      return
    } 
    
    this.checkIntegralAddOnPop() // 积分商品凑单免运费提示
    if(new Date().getTime() - lastRequestSaveTime >= 2000) { // 距离上次请求结束大于2秒，直接进行请求，否则进行防抖处理
      this.initTotal1()
      return
    }
    /** 防抖处理 */
    let that = this 
    clearTimeout(initTotalTicker)
    initTotalTicker = setTimeout(function() {
      that.initTotal1()
    }, 1500)
  },
  initTotal1() { // 计算购物车总价
    if(!isComputingSave) {
      isComputingSave = true
      Promise.all([
        this.getCouponSave(), // 获取优惠明细
        this.getProductSave() // 获取产品特价明细
      ]).then(res => {
        let vipCusStatus = parseInt(wx.getStorageSync('vipCusStatus'))
        let actualPay = WGFORMAT.formatCurrency(res[1].payOriginPrice - res[0].discountMoney - res[0].vipDiscountMoney) // 实付价
        let save = WGFORMAT.formatCurrency(res[1].originTotal - actualPay) // 优惠合计
        let couponSave1 = res[0].discountMoney // 全场优惠
        let svipSave = 0
        if(actualPay < 0) { // 算出实付价是负数的情况怎么办呢
          actualPay = 0.01
          save = res[1].originTotal - 0.01
          couponSave1 = save - res[1].svipSave - res[0].vipDiscountMoney - res[1].activitySave
        }
        if(vipCusStatus == 1) { // 超会的95折优惠
          svipSave = WGFORMAT.formatCurrency(save - res[0].discountMoney - res[0].vipDiscountMoney - res[1].activitySave)
        }
        this.setData({
          price: {
            originTotal: res[1].originTotal, // 商品原价合计
            saveTotal: WGFORMAT.formatCurrency(save), // 优惠合计
            actualTotal: actualPay, // 实付合计
            activitySave: WGFORMAT.formatCurrency(res[1].activitySave), // 特价活动优惠
            svipSave: svipSave, // 超会95折优惠
            couponSave1: WGFORMAT.formatCurrency(couponSave1), // 全场优惠券
            couponSave2: res[0].vipDiscountMoney, // 专享优惠券
          },
        })
        this.initAddOnTips() // 凑单提示
        WGCOMMON.hideLoading()
        isComputingSave = false
      })
    }
  },
  computedPurePatTotal() { // 前端纯计算合计 --- 在后端失败的情况下的计算备胎
    this.getProductSave().then(res => {
      this.setData({
        'price.actualTotal': WGFORMAT.formatCurrency(res.originTotal - res.svipSave - res.activitySave)
      })
    })
  },
  toggleSelectAll() { // 全选商品 & 取消全选商品
    let cartModule = this.data.cartModule
    let isAllChecked = !this.data.isAllChecked
    let proNum = isAllChecked?SHOPCARTSERVER.getCartNum():0
    for(let i=0;i<cartModule.length;i++) {
      cartModule[i]['isChecked'] = isAllChecked
    }
    this.setData({
      cartModule,
      isAllChecked,
      proNum
    }, () => {
      SHOPCARTSERVER.setAllChecked(isAllChecked)
      let checkedIntProsNum = SHOPCARTSERVER.getCheckedInteQuantity()
      this.setData({ checkedIntProsNum })
      this.initTotal()
    })
  },
  toggleCheck(e) { // 选择/取消选中  购物车商品
    let index = e.currentTarget.dataset.index
    let product = this.data.cartModule[index]
    let proNum = this.data.proNum
    let lastestVal = !product.isChecked
    this.setData({
      [ 'cartModule[' + index + ']isChecked' ]: lastestVal,
      proNum: lastestVal?proNum+product.quantity:proNum-product.quantity
    }, () => {
      SHOPCARTSERVER.setSingleProductCheck(product.id, lastestVal)
      this.setData({ 
        isAllChecked: SHOPCARTSERVER.getCartNum() == this.data.proNum, 
        checkedIntProsNum: SHOPCARTSERVER.getCheckedInteQuantity()
      })
      this.initTotal(product.isRedeem == 1)
    })
  },
  decrease(e) { // 商品-1
    let index = e.currentTarget.dataset.index
    this.operateQuantity(index, -1)
  },
  increase(e) { // 商品+1
    let index = e.currentTarget.dataset.index
    this.operateQuantity(index, 1)
  },
  operateQuantity(index, addNum) {
    let item = this.data.cartModule[index]
    let isChecked = item.isChecked
    let quantity = parseInt(item.quantity) + addNum
    // console.error(quantity,item.stock)
    if((quantity > item.stock) && addNum > 1) {
      WGCOMMON.toast('超过商品库存，不能再添加了', 1500)
      return
    } else if(quantity > item.limitQuantity) {
      WGCOMMON.toast(`此商品每人限购${item.limitQuantity}件`, 1500)
      return
    } else if(quantity <= 0) {
      WGCOMMON.showModal('提示', '您确定要删除这款产品？').then(res => { 
        SHOPCARTSERVER.delCartItem(item.id)
        this.data.cartModule.splice(index, 1)
        this.setData({
          cartModule: this.data.cartModule,
          proNum: SHOPCARTSERVER.getCheckedQuantity(),
          checkedIntProsNum: SHOPCARTSERVER.getCheckedInteQuantity(),
          intProsNum: SHOPCARTSERVER.getIntegralProsNum()
        })
        UTIL.setCartNum()
        if(isChecked) {
          this.initTotal()
        }
        return
      }).catch(() => {
        return
      })
    } else {
      SHOPCARTSERVER.setProductQuantity(item.id, addNum)
      UTIL.setCartNum()
      this.setData({
        [ 'cartModule[' + index + ']quantity' ]: quantity,
      })
      if(item.isChecked) {
        this.setData({
          proNum: this.data.proNum + addNum,
          checkedIntProsNum: SHOPCARTSERVER.getCheckedInteQuantity()
        })
      }
    }
    if(item.isChecked) {
      this.initTotal(item.isRedeem == 1)
    }
  },
  addInterPro(e) { // 将积分兑换产品加入购物车
    this.setData({
      cartModule: SHOPCARTSERVER.initCart(), // 重置购物车数据
      proNum: SHOPCARTSERVER.getCheckedQuantity(), // 选中要结算的商品数量
      intProsNum: SHOPCARTSERVER.getIntegralProsNum() // 购物车里的积分商品数量
    })
    this.checkIntegralAddOnPop() // 检查积分商品免运费的搭配提示
    UTIL.setCartNum()
  },
  checkedProPoints() { // 选中要兑换的总积分数
    let points = 0
    for(let i=0;i<this.data.cartModule.length;i++) {
      if(this.data.cartModule[i].isRedeem == 1 && this.data.cartModule[i].isChecked) {
        points += (this.data.cartModule[i].redeemPrice * this.data.cartModule[i].quantity)
      }
    }
    return points
  },
  checkValidPoints(cartPoints = 0) { // 校验会员有效积分
    return new Promise((resolve, reject) => {
      API.user.getValidPoints(wx.getStorageSync('cusId')).then(res => {
        const {
          ret,
          datalist
        } = res.data
        if (ret == 0) {
          let validPoints = datalist[0].validPoints
          if(validPoints < cartPoints) {
            WGCOMMON.toast(`积分不足，还差${cartPoints - validPoints}积分,请减少兑换产品！`)
            reject()
          }
        }
        resolve()
      })
    })
  },
  fliterRedeemProduct(pros) { // 过滤掉积分兑换产品
    let newVal = []
    for (let i = 0; i < pros.length; i++) {
      if (pros[i].isRedeem == 0) {
        newVal.push(pros[i])
      }
    }
    return newVal
  },
  initAddOnTips() { // 获取“优惠券凑单提示”
    let cartModule = this.fliterRedeemProduct(this.data.cartModule)
    let self = this
    return new Promise((resolve, reject) => {
      var n = cartModule.filter(function (item) {
        return item.isChecked;
      })
      if (n && n.length > 0) {
        if (self.data.ticketFlag) {
          var tip = COUPON.getMinMaxTicket(self.data.tickets, n);
          if (tip) {
            self.data.minTicket = tip.min
            self.data.maxTicket = tip.max
            self.setAddOnTipText()
          }
        } else {
          let cusId = wx.getStorageSync('cusId')
          let vipCusStatus = wx.getStorageSync('vipCusStatus')
          if(cusId) {
            API.coupons.validCoupon(cusId, vipCusStatus).then(res => {
              self.data.ticketFlag = true
              let list = res
              if (list && list.length > 0) {
                this.data.tickets = list
                var tip = COUPON.getMinMaxTicket(list, n);
                if (tip) {
                  self.data.minTicket = tip.min
                  self.data.maxTicket = tip.max
                  self.setAddOnTipText()
                }
              }
            })
          }
        }
      } else {
        self.data.minTicket = null
        self.data.maxTicket = null
        self.setAddOnTipText()
      }
    })
  },
  setAddOnTipText() { // 设置“优惠券凑单提示”的文字
    let self = this
    let min = self.data.minTicket
    let max = self.data.maxTicket
    let addOnTips = ''
    console.log('minTicket', min)
    console.log('maxTicket', max)
    if(this.data.satisfyCoupon && this.data.satisfyCoupon.status == 1) {
      addOnTips = this.data.satisfyCoupon.content
    } else if (min) {
      addOnTips = '已满足';
      var rule = min.rule && min.rule.money;
      var gift = min.giftRule;
      if (gift) {
        if (gift.giftMoney) {
          addOnTips += '满' + rule + '减' + gift.giftMoney;
        } else if (gift.addOnMoney > 0 && gift.giftProduaddOnMoneyctInfo && gift.giftProductInfo[0]) {
          addOnTips += '满' + rule + '可换购' + gift.giftProductInfo[0].name;
        } else if (gift.addOnMoney <= 0 && gift.giftProductInfo && gift.giftProductInfo[0]) {
          addOnTips += '满' + rule + '赠' + gift.giftProductInfo[0].name;
        } else {
          addOnTips += min.name;
        }
      } else {
        addOnTips += min.name;
      }
    }
    if (max) {
      var rule = max.rule.money;
      var total = this.data.totalOriginPrice;
      addOnTips = addOnTips ? addOnTips + ',' : '';
      var last = Math.round((rule - total) * 100) / 100;
      var gift = max.giftRule;
      if (gift) {
        if (gift.giftMoney) {
          addOnTips += '凑够' + last + '元可减' + gift.giftMoney;
        } else if (gift.giftProductInfo && gift.giftProductInfo[0] && gift.addOnMoney) {
          addOnTips += '凑够' + last + '元可换购' + gift.giftProductInfo[0].name;
        } else if (gift.giftProductInfo && gift.giftProductInfo[0]) {
          addOnTips += '凑够' + last + '元可赠' + gift.giftProductInfo[0].name;
        } else {
          addOnTips += '凑够' + last + '元可' + max.name;
        }
      } else {
        addOnTips += '凑够' + last + '元可' + max.name;
      }
    }
    self.setData({ addOnTips })
  },
  closeDialog() { // 关闭“积分商品与自营商品凑单免运费”的弹窗
    this.setData({
      showFreightAddOnPopup: false
    })
  },
  checkIntegralAddOnPop() { // 是否显示 “积分商品凑单免运费” 提醒
    let shopModule = this.data.cartModule
    let res = false
    let jifenLen = 0
    let feiJifenLen = 0
    for (let i = 0; i < shopModule.length; i++) {
      if (shopModule[i].isChecked && shopModule[i].isRedeem == 1) {
        jifenLen++ // 积分兑换产品+1 // productCategory产品大类：1电商产品、2会员产品、4代销产品
      } else if (shopModule[i].isChecked && shopModule[i].isRedeem == 0 && shopModule[i].productCategory != 4) {
        feiJifenLen++ // 自营产品+1 // productCategory产品大类：1电商产品、2会员产品、4代销产品
      }
    }
    if (jifenLen > 0 && feiJifenLen == 0) res = true
    this.setData({
      showFreightAddOn: res
    })
    return res
  },
  closeSaveDetail() { // 关闭优惠明细弹窗
    this.setData({ showSaveDetial: false })
  },
  openSaveDetail() { // 打开优惠明细弹窗
    this.setData({ showSaveDetial: !this.data.showSaveDetial })
  },
  getUserCoupon() { // 获取用户的专享优惠券
    if(wx.getStorageSync('cusId')) {
      API.coupons.queryValidTicketActivitys(wx.getStorageSync('cusId')).then(res => {
        app.globalData.userCoupons = res
      })
    }
  },
  getCouponSave() { // 获取优惠金额
    return new Promise((resolve, reject) => {
      if(this.data.proNum === 0) { // 没有选择要结算的商品
        resolve({ discountMoney: 0, vipDiscountMoney: 0})
      }
      let proList = []
      let data = this.data.cartModule
      let vipCusStatus = parseInt(wx.getStorageSync('vipCusStatus'))
      for (let i = 0; i < data.length; i++) {
        if(data[i].isChecked) {
          proList.push({
            num: data[i].quantity,
            name: data[i].name,
            price: data[i].redeemPrice ? 0 : (vipCusStatus == 1?WGFORMAT.formatCurrency(data[i].price/0.95):data[i].price), // 是否有积分兑换价格
            redeemPrice: data[i].redeemPrice ? data[i].redeemPrice : 0,
            specialPrice: 0,
            code: data[i].productId,
            proImage: data[i].icon,
            wareHouseCode: data[i].warehouseCode ? data[i].warehouseCode : data[i].wareHouseCode,
            templateId: data[i].productTemplateId,
            skuName: data[i].skuName,
            stock: data[i].stock
          })
        }
      }
      if(proList.length == 0) {
        resolve({ discountMoney: 0, vipDiscountMoney: 0})
        return
      }
      let params = {
        activityId: 0,
        phone: wx.getStorageSync('phone'),
        cusId: wx.getStorageSync('cusId'),
        openId: wx.getStorageSync('openId'),
        exchangeCode: '',
        orderContext: {
          proList: proList
        },
        vipCusStatus: wx.getStorageSync('vipCusStatus'),
        orderResultContext: null,
        vipActivityIds: app.globalData.userCoupons
      }
      lastRequestSaveTime = new Date().getTime()
      API.cart.getCouponSave(params).then(res => {
        if(res.data.msgCode == 0 && res.data.resultInfo) {
          couponSaveTempResult = res.data.resultInfo // 缓存上一次的接口计算结果
          this.setData({ overTime: false })  
          this.data.satisfyCoupon = { status: 1, content: res.data.resultInfo.content }
          resolve(res.data.resultInfo)
        } else if(res.data.msgCode == 1021) { // 请求过于频繁了
          this.setData({ overTime: couponSaveTempResult?false:true })  
          this.data.satisfyCoupon.status = -1
          resolve(couponSaveTempResult?couponSaveTempResult:{ discountMoney: 0, vipDiscountMoney: 0})
        } else { // 其他计算失败的情况
          this.setData({ overTime: couponSaveTempResult?false:true })  
          resolve({ discountMoney: 0, vipDiscountMoney: 0})
          this.data.satisfyCoupon.status = -1
        }
      }).catch(() => {
        this.setData({ overTime: true })  
        resolve({ discountMoney: 0, vipDiscountMoney: 0})
      })
    })
  },
  getProductSave() { // 获取产品的优惠金额
    let t = {
      originPrice: 0, // 原价，算上了限时折扣/阶梯价原价
      svipSave: 0,
      activitySave: 0,
      payOriginPrice: 0, // 原价，不算限时折扣/阶梯价原价，直接按照活动价计算
    }
    let data = SHOPCARTSERVER.getCheckedCart()
    for(let i=0;i<data.length;i++) {
      if(data[i].isRedeem == 0) {
        // 是否是超会
        let price = wx.getStorageSync('vipCusStatus') == 1?WGFORMAT.formatCurrency(data[i].price / 0.95):data[i].price
        t.originPrice += WGFORMAT.formatCurrency(data[i].originPrice * data[i].quantity)
        t.svipSave += WGFORMAT.formatCurrency(WGFORMAT.formatCurrency(price - data[i].price) * data[i].quantity)
        if(data[i].cartProTag) {
          t.activitySave += WGFORMAT.formatCurrency(WGFORMAT.formatCurrency(data[i].originPrice - price) * data[i].quantity)
        }
        t.payOriginPrice += WGFORMAT.formatCurrency(data[i].price * data[i].quantity)
      }
    }
    return new Promise((resolve, reject) => {
      if(this.data.proNum === 0) {
        resolve({ originTotal: 0, activitySave: 0, svipSave: 0})
      }
      resolve({ 
        originTotal: WGFORMAT.formatCurrency(t.originPrice),
        svipSave: wx.getStorageSync('vipCusStatus') == 1?t.svipSave:0,
        activitySave: t.activitySave, // 特价活动优惠
        payOriginPrice: WGFORMAT.formatCurrency(t.payOriginPrice)
      })
    })
  },
  toPay() { // 点击“结算”按钮
    if(this.data.proNum <= 0) {
      WGCOMMON.toast('请选择商品')
      return false
    }
    if(this.checkIntegralAddOnPop()) { // 显示"积分商品与自营商品凑单免运费"提示弹窗
      this.setData({ showFreightAddOnPopup: true })
      return false
    }
    let cartPoints = this.checkedProPoints()
    if(cartPoints > 0) { // 结算里有积分兑换商品
      this.checkValidPoints(cartPoints).then(() => {
        this.toPayPage()
      })
    } else {
      this.toPayPage()
    }
  },
  toPayPage() { // 跳转到结算页
    let moreQuery = ''
    let prolist = SHOPCARTSERVER.getCheckedCart()
    if (wx.getStorageSync('orderAttribution')) { // 主要是获取谷粉社区笔记来源
      let orderAttribution = JSON.parse(wx.getStorageSync('orderAttribution'))
      for (let i = 0; i < prolist.length; i++) {
        if (orderAttribution.hasOwnProperty(prolist[i].productTemplateId.toString())) {
          let obj = orderAttribution[prolist[i].productTemplateId.toString()]
          let expiresTime = Number(obj.expiresTime) // 过期时间
          let now = (new Date().getTime()) / 1000
          if (now > expiresTime) { // 已经过期了
            delete orderAttribution[prolist[i].productTemplateId.toString()]
            wx.setStorageSync('orderAttribution', JSON.stringify(orderAttribution))
          } else {
            moreQuery = `?orderAttribution=${obj.referer}`
          }
        }
      }
    }
    wx.navigateTo({
      url: '/pages/PayOrder/PayOrder' + moreQuery // orderOrigin=0 加购下单
    })
    return
  },
  goDetail(e) { // 去往产品详情页
    wx.navigateTo({
      url: '/pages/ProductDetail/ProductDetail?pId=' + e.currentTarget.dataset.id + '&from=shopcart',
    })
  },
  login() { // 登录成功的回调
    if(wx.getStorageSync('cusId')) {
      this.setData({
        isLogin: true
      }, () => {
        this.initCart()
      })
    }
  },
  onLoad() {
    // this.getUserCoupon() // 提前获取用户的专享优惠券并保存起来
    // SHOPCARTSERVER.refreshCartByServer()
  },
  onHide() {
    SHOPCARTSERVER.refreshCart()
    this.closeSaveDetail()
  },
  onShow() {
    isInitCarting = false
    this.closeSaveDetail()
    SHOPCARTSERVER.refreshCartByServer()
    this.getUserCoupon() // 提前获取用户的专享优惠券并保存起来
    this.setData({ isLogin: wx.getStorageSync('cusId')?true:false })
    UTIL.setCartNum()
    this.initCart() // 初始化购物车
    this.closeDialog()
  },
})