//Page Object
import api from '../../api/index'
import {
  LOADING,
  UTIL,
  FILTER,
  SHOPCARTSERVER
} from '../../utils/index'
import User from '../../store/index.js'
import {
  WGAUTH,
  WGFORMAT,
  Page
} from '../../wgUtils/index';

const app = getApp()

Page({
  data: {
    pIds: '', // 套餐id
    packageSku: [], // 套餐默认sku
    selectedSku: [], // 已选择的sku
    showModal: true, // 购买弹窗
    isLogin: false, // 是否已经登录
    isSoldOut: false, // 是否售罄
    vipStatus: 0 // 会员状态：非会员0，未过期会员1，已过期会员2 
  },
  initData(type) {
    let that = this
    if (this.data.isLogin) { // 已登录,获取会员状态
      try {
        User.getSvipStatus(wx.getStorageSync('cusId')).then(res => {
          that.setData({
            vipStatus: res.resultInfo.vipCusStatus
          })
          that.initPackage(type)
        }).catch(e => {
          console.error('getSvipStatus报错---------', e);
        })
      } catch (e) {
        console.log('catch', e)
      }
    } else { // 未登录
      that.initPackage(type)
    }
  },
  soldOut() {
    wx.showToast({
      title: '库存不足',
      icon: 'none'
    })
  },
  initPackage(type) { // 初始化
    api.package.list(this.data.pIds).then(res => {
      if(res) {        
        this.setData({
          pageName: res[0].name
        })
        wx.setNavigationBarTitle({
          title: '五谷磨房' + res[0].name
        })
        let sku = res[0].rule.productInfo
        let price = 0
        let needIcon = false
        let needIconIds = []
        let needIconIdsIndex = []
        for (let i = 0; i < sku.length; i++) {
          let num = parseInt(sku[i].num) // 数量
          sku[i]["min"] = num
          sku[i]["quantity"] = num
          let max = num
          if (sku[i].num[sku[i].num.length - 1] == '+') {
            max = (sku[i].stock < 100) ? sku[i].stock : 100
          }
          sku[i]["max"] = max
  
          sku[i]['cusPrice'] = (this.data.vipStatus == 1) ? FILTER.getPriceRange([sku[i].specialPrice], 0.95) : sku[i].specialPrice
          // sku[i]['cusPrice'] = (this.data.vipStatus == 1)?(sku[i].specialPrice*0.95).toFixed(2):sku[i].specialPrice
          price += (sku[i].specialPrice * num)
          if (sku[i].stock <= 0) {
            this.setData({
              isSoldOut: true
            })
          }
          if (!sku[i].proImage) {
            needIcon = true
            needIconIds.push({
              productId: sku[i].templateId
            })
            needIconIdsIndex.push(i)
          }
        }
        this.setData({
          activityId: res[0].activityId,
          banner: res[0].scrollUrl.split(','),
          detailUrl: res[0].detailUrl.split(','),
          product: {
            pIds: this.data.pIds,
            productTemplateName: res[0].name,
            isRedeem: false,
            integralStatus: 1,
            actType: 19,
            /** 19套餐搭配 */
            price: price,
            superPrice: WGFORMAT.formatCurrency(price * 0.95),
            products: sku,
            banner: res[0].scrollUrl.split(','),
            isLogin: (UTIL.getInfo('cusId').length != 0) && (UTIL.getInfo('openId').length != 0),
          },
          packageSku: sku,
          selectedSku: sku
        })
        this.computeTotal()
        if (type == 1) {
          this.buyNow()
        }
        if (needIcon) {
          this.initImg(needIconIds, needIconIdsIndex)
        }
      }
    })
  },
  initImg(ids, idsIndex) {
    api.product.list(ids).then(res => {
      let obj = {}
      for (let i = 0; i < res.length; i++) {
        let img1 = res[i].product.imgUrl
        let img2 = res[i].productTemplate.groupedImages.icon[0].imageUrl
        let img = img2 ? img2 : img1
        obj[res[i].product.id] = img
        let key = "selectedSku[" + idsIndex[i] + "].proImage"
        this.setData({
          [key]: img
        })
      }
    }).catch(e => {
      console.error('product/info/list报错', e)
    })
  },
  reduce(e) {
    let i = e.currentTarget.dataset.index
    let min = this.data.packageSku[i].min
    let quantity = this.data.selectedSku[i].quantity
    if (quantity - 1 < min) return false
    let key = "selectedSku[" + i + "].quantity"
    this.setData({
      [key]: quantity - 1
    })
    this.computeTotal()
  },
  add(e) {
    let i = e.currentTarget.dataset.index
    let max = this.data.packageSku[i].max
    let quantity = this.data.selectedSku[i].quantity
    if (quantity + 1 > max && max != -1) return false
    let key = "selectedSku[" + i + "].quantity"
    this.setData({
      [key]: quantity + 1
    })
    this.computeTotal()
  },
  computeTotal() {
    let total = 0
    let discount = 0
    let vipStatus = (this.data.vipStatus == 1) ? true : false // 会员状态
    let sku = this.data.selectedSku
    for (let i = 0; i < sku.length; i++) {

      total += ((vipStatus ? (FILTER.getPriceRange([sku[i].specialPrice], 0.95)) : sku[i].specialPrice) * sku[i].quantity)
      discount += ((sku[i].price - sku[i].cusPrice) * sku[i].quantity)
    }
    this.setData({
      total: total.toFixed(2),
      discount: discount.toFixed(2)
    })
  },
  getSvipLEvelOnline() {
    let _self = this
    User.getSvipStatus(wx.getStorageSync('cusId')).then((res) => {
      _self.setData({
        vipStatus: res.resultInfo.vipCusStatus
      })
      console.log('product.vipCusStatus---------', res.resultInfo.vipCusStatus)
    }).catch(e => {
      console.error('getSvipStatus报错---------', e);
    })
  },
  getPhoneNumber(e) {
    if (e.detail.errMsg === 'getPhoneNumber:ok') {
      LOADING.show({
        title: '登录中...'
      })
      WGAUTH.getPhoneNumber(e).then(res => {
        // AUTH.requestUsersecret(e.detail).then((res) => {
        LOADING.hide()
        this.setData({
          isLogin: true
        })
        this.initData(1)
      })
    }
  },
  closeModal() {
    this.setData({
      showModal: true
    })
  },
  buyNow() {
    this.setData({
      showModal: false
    })
  },
  goHome() {
    wx.switchTab({
      url: '/pages/Home/Home'
    })
  },
  goDetail(e) {
    wx.navigateTo({
      url: "/pages/ProductDetail/ProductDetail?pId=" + e.currentTarget.dataset.id
    })
  },
  submit() {
    let vipCusStatus = wx.getStorageSync('vipCusStatus')
    let selectedSku = this.data.selectedSku
    // selectedSku[0].quantity = 1
    for (let i = 0; i < selectedSku.length; i++) {
      selectedSku[i]["productTemplateId"] = parseInt(selectedSku[i].templateId)
      selectedSku[i]["productId"] = selectedSku[i].code
      selectedSku[i]["integralStatus"] = 1
      selectedSku[i]["icon"] = selectedSku[i].proImage
      selectedSku[i]["originPrice"] = selectedSku[i].specialPrice
      selectedSku[i].price = vipCusStatus == 1? FILTER.getPriceRange([selectedSku[i].specialPrice], 0.95) : selectedSku[i].specialPrice
      selectedSku[i]['noSvipPrice'] = selectedSku[i].specialPrice
      selectedSku[i]["isRedeem"] = 0
      selectedSku[i]["isChecked"] = true
      selectedSku[i]["packageId"] = this.data.activityId
      selectedSku[i]["warehouseCode"] = selectedSku[i].wareHouseCode
    }
    wx.setStorageSync('buyNowProduct', selectedSku)
    wx.navigateTo({
      url: "/pages/PayOrder/PayOrder?activityId=" + this.data.activityId + "&productId=" + this.data.pIds + "&type=19"
    })
  },
  onLoad: function (e) {
    let cusId = wx.getStorageSync('cusId')
    if (cusId) { // 已登录
      this.setData({
        isLogin: true,
        pIds: e.pIds
      })
    } else { // 未登录
      this.setData({
        isLogin: false,
        pIds: e.pIds
      })
    }

    try {   
      wx.onCopyUrl(() => {
        return { query: WGFORMAT.formatQueryByOptions(e) }
      })
    } catch (error) {
      console.warn('暂不支持wx.onCopyUrl')
    }
  },
  onHide() {},
  onShow: function () {
    this.initData()
  }
});