import {
  REQUEST,
  API,
  LOADING,
  FILTER,
  SHOPCARTSERVER,
  SRTRACK,
} from '../../utils/index'
import User from '../../store/index.js'
import staffShare from '../../utils/staffShare.js'
import api from '../../api/index'
import {
  Page
} from '../../wgUtils/index';

var app = getApp() // app可以调用全局的方法&全局的变量

const data = {
  listModule: null, // 普通商品数据
  productDetail: null, // “选择商品规格添加进购物车卡片” 的商品数据
  defaultIcon: 'http://img.wgmf.com/product/image/cover_loot_all_1.png', // “已抢光”图片
  pageShow: false, // 是否显示scroll-view。数据未加载完成前不显示
  chooseSkuShow: false, // 是否显示“选择商品规格添加进购物车卡片” 
  openId: '', // 用户openId
  userInfo: {}, // 用户数据信息
  productNum: 0, // 购物车商品数量
}
const methods = {
  getSvipStatus() { // 获取超级会员状态
    User.getSvipStatus(wx.getStorageSync('cusId')).then(res => {
      this.data.userInfo['vipCusStatus'] = res.resultInfo.vipCusStatus // 0非超级会员  1超级会员
    }).catch(function (e) {
      console.error('getSvipStatus报错----------还未登录，没有cusId', e);
    })
  },
  getProList() { // 产品列表
    LOADING.show()
    return new Promise((resolve, reject) => {
      REQUEST.get(API.get_proList).then((res) => {
        const {
          status,
          data
        } = res.data
        if (status == 0) {
          this.initProduct(data)
          resolve()
        }
      }).catch((e) => {
        reject(e)
      })
    })
  },
  goDetail(e) { // 跳转至商品详情页
    let item = e.currentTarget.dataset.item
    // SRTRACK.setTrackData('browse_sku_page', item, this.data.id, this.data.name)
    SRTRACK.setTrackData('trigger_sku_component', item, this.data.id, this.data.name)
    wx.navigateTo({
      url: '/pages/ProductDetail/ProductDetail?pId=' + e.currentTarget.dataset.id,
    })
  },
  closeSku(e) { // 关闭购物车弹框
    app.globalData.selectedData = null
    this.setData({
      chooseSkuShow: e.detail
    })
  },
  addCart(e) { // 点击+图标准备将商品加入购物车
    // 1、判断actType
    // 2、计算superPrice
    let info = e.currentTarget.dataset.item // 商品数据
    console.log(info)
    info.vipCusStatus = this.data.userInfo.vipCusStatus // 超级会员状态
    this.setData({
      chooseSkuShow: true,
      productDetail: info,
      'productDetail.operationType': 0,
      'productDetail.actType': info.actType
    })
  },
  watchCartNum(val) {
    console.log('watch back', val)
    this.setData({
      productNum: val
    })
  },
  initProduct(data) {
    for (let i = 0; i < data.length; i++) {
      if (!data[i].products) return false
      data[i].sold = 0
      data[i].stock = 0
      data[i].icon = ''
      data[i].price = 0
      data[i].actType = 0 // actType 0普通  actType 6预售  actType 8团购  actType 9积分兑换 
      /** 原有：0普通，1/2旧秒杀，3暂无，4旧限时折扣，5/6/7预售，8拼团，9积分兑换，10暂无，11购买优惠券，12阶梯价（暂无用）14购买超级会员*/
      /** 新增 16限时折扣，17秒杀，18分期发货 */
      if (data[i].hotWord) {
        data[i].hotWord = [data[i].hotWord]
      }
      if (data[i].groupPurchase && data[i].groupPurchase.length > 0) {
        data[i].actType = 8 // actType 0普通  actType 6预售  actType 8团购  actType 9积分兑换 
      }
      let _priceArr = []
      let redeemPrices = []
      let _isRedeemFlag = false
      for (let j = 0; j < data[i].products.length; j++) {
        if (data[i].products[j].enable === 0) {
          if (data[i].products[j].sold > 0) {
            data[i].sold += data[i].products[j].sold
          }
          if (data[i].products[j].stock > 0) {
            data[i].stock += data[i].products[j].stock
          }
          if (data[i].products[j].isRedeem == 1) { // 积分兑换
            _isRedeemFlag = true
          }
          _priceArr.push(data[i].products[j].price)
          redeemPrices.push(data[i].products[j].redeemPrice)
        }
      }
      data[i].icon = (data[i].groupedImages && data[i].groupedImages.icon)? data[i].groupedImages.icon[0].imageUrl : ''
      if (_priceArr.length == 0) {
        if (data[i].minPrice == data[i].maxPrice) {
          _priceArr.push(data[i].minPrice)
        } else {
          _priceArr.push(data[i].minPrice)
          _priceArr.push(data[i].maxPrice)
        }
      }
      data[i].price = FILTER.getPriceRange(_priceArr)
      data[i].superPrice = FILTER.getPriceRange(_priceArr, 0.95)
      data[i].redeemPrices = FILTER.getPriceRange(redeemPrices)
      if (_isRedeemFlag) {
        data[i].actType = 9 // actType 0普通  actType 6预售  actType 8团购  actType 9积分兑换 
      }
      // 库存为0
      if (data[i].stock <= 0) {
        data[i].displayPriority = -1 // 展示优先级为-1
      }
    }
    data.sort(function (a, b) {
      return b.displayPriority - a.displayPriority
    })
    this.setData({
      listModule: data,
      pageShow: true
    })
    LOADING.hide()
    SRTRACK.setTrackData('expose_sku_component', data, this.data.id, this.data.name)
  },
  getProductBySeries() {
    LOADING.show()
    api.product.productSeriesSpecial(this.data.id).then(res => {
      this.initProduct(res)
    })
  },
}
Page({
  data,
  ...methods,
  onHide() {},
  onLoad: function (options) {
    //拿到分享人工号,存入本地
    app.watch(this.watchCartNum)
    app.globalData.myCardNum = SHOPCARTSERVER.getCartNum()
    if (options.id) {
      this.setData({
        id: options.id,
        name: options.name,
      })
      this.getProductBySeries()
    } else {
      this.getProList()
    }
    wx.setNavigationBarTitle({
      title: options.name ? options.name : '产品列表页'
    })
    if (options.pageName) {
      wx.setNavigationBarTitle({
        title: options.pageName
      })
    }

    staffShare.setShareStaffIdByShare(options)
  },
  onShow: function () {
    // User.page_scan('产品列表').then(res => { })
    this.getSvipStatus()
  },
  onShareAppMessage: function (res) { // 自定义点击右上角转发内容
    return {
      title: '五谷磨房，创造精致生活的更多种选择',
      path: '/pages/ProductList/ProductList?' + staffShare.getShareParams() + '&id=' + this.data.id //分享人工号，此时分享人为登录者本人
    }
  }
})