import {
  REQUEST,
  API,
  LOADING,
  FILTER,
  UTIL
} from '../../utils/index'
import User from '../../store/index.js'
import staffShare from '../../utils/staffShare.js'
var app = getApp() // app可以调用全局的方法&全局的变量
import {
  Page
} from '../../wgUtils/index';

const data = {
  purchaseModule: null, // 团购商品数据
  purchaseConfig: { // 拼团信息
    actType: 2,
    title: '超值一起拼',
    subTitle: '分享给好友，一齐享优惠'
  },
  groupBConfig: { // 团购信息
    actType: 2,
    title: '超值团团赚',
    subTitle: '团内盒数越多，价格越低'
  },
  preSaleMoudule: null, // 预售商品数据
  preSaleConfig: { // 预售信息
    actType: 6,
    title: '预售抢先购',
    subTitle: '早买早收货'
  },
  productDetail: null, // “选择商品规格添加进购物车卡片” 的商品数据
  defaultIcon: 'http://img.wgmf.com/product/image/cover_loot_all_1.png', // “已抢光”图片
  pageShow: false, // 是否显示scroll-view。数据未加载完成前不显示
  chooseSkuShow: false, // 是否显示“选择商品规格添加进购物车卡片” 
  openId: '', // 用户openId
  userInfo: {}, // 用户数据信息
}
const methods = {
  clearStorage() {
    wx.clearStorage()
    this.onLoad()
  },
  getSvipStatus() { // 获取超级会员状态
    User.getSvipStatus(wx.getStorageSync('cusId')).then(res => {
      this.setData({
        'userInfo.vipCusStatus': res.resultInfo.vipCusStatus // 0非超级会员  1超级会员
      })
    }).catch(function (e) {
      console.error('getSvipStatus报错----------还未登录，没有cusId', e);
    })
  },
  getPurchaseList() { // 拼团列表
    let url = API.get_purchaseList + '-1'
    REQUEST.get(url, {
      header: {
        'cache-control': true
      }
    }).then((res) => {
      const {
        status,
        data
      } = res.data
      if (status === 0) {
        if (data.length != 0) {
          let groupALen = 0
          let groupBLen = 0
          for (let i = 0; i < data.length; i++) {
            let _originalPriceArr = []
            let _offerPriceArr = []
            for (let j = 0; j < data[i].groupPurchaseProductList.length; j++) {
              _originalPriceArr.push(data[i].groupPurchaseProductList[j].price)
              _offerPriceArr.push(data[i].groupPurchaseProductList[j].purchasePrice)
            }
            data[i].originalPrice = FILTER.getPriceRange(_originalPriceArr)
            data[i].superPrice = FILTER.getPriceRange(_offerPriceArr, 0.95)
            data[i].offerPrice = FILTER.getPriceRange(_offerPriceArr)
            // data[i].actType = 8  // actType 0普通  actType 6预售  actType 8拼团  actType 9积分兑换  16团购

            if (data[i].grouppurchaseType == 1) { // 团购
              data[i].actType = 16
              groupBLen++
            } else { // 拼团
              data[i].actType = 8
              groupALen++
            }
            // console.log(data[i].actType)
          }
          this.setData({
            purchaseModule: data,
            groupALen: groupALen,
            groupBLen: groupBLen
          })
        }
      }
      LOADING.hide()
    }).catch((e) => {})
  },
  getPresaleList() { // 预售列表
    REQUEST.get(API.get_presell_miniInfo).then((res) => {
      const {
        status,
        data
      } = res.data
      if (status == 0 && data.length > 0) {
        for (let i = 0; i < data.length; i++) {
          data[i].actType = 6 // actType 0普通  actType 6预售  actType 8团购  actType 9积分兑换 
          let _originalPriceArr = []
          let _offerPriceArr = []
          for (let j = 0; j < data[i].presellLines.length; j++) {
            _originalPriceArr.push(data[i].presellLines[j].presellProductMoney)
            _offerPriceArr.push(data[i].presellLines[j].presellMoney)
          }
          data[i].offerPrice = FILTER.getPriceRange(_offerPriceArr)
          data[i].superPrice = FILTER.getPriceRange(_originalPriceArr, 0.95)
          data[i].originalPrice = FILTER.getPriceRange(_originalPriceArr)
        }
        this.setData({
          preSaleMoudule: data
        })
      }
      LOADING.hide()
    })
  },
  goDetail(e) { // 跳转至商品详情页
    wx.navigateTo({
      url: '/pages/ProductDetail/ProductDetail?pId=' + e.currentTarget.dataset.id,
      // url: '/pages/ProductDetail/ProductDetail?pId=20&gdt_vid=wx151205fefef015&weixinadinfo=3262065626dedcma',
    })
  },
  closeSku(e) { // 关闭购物车弹框
    app.globalData.selectedData = null
    this.setData({
      chooseSkuShow: e.detail
    })
  },
  addCart(e) { // 点击+图标准备将商品加入购物车
    // 1、判断actType
    // 2、计算superPrice
    let info = e.currentTarget.dataset.item // 商品数据
    info.vipCusStatus = this.data.userInfo.vipCusStatus // 超级会员状态
    this.setData({
      chooseSkuShow: true,
      productDetail: info,
      'productDetail.operationType': 0,
      'productDetail.actType': info.actType
    })
  },
  getServerTime() { // 获取服务器时间
    return new Promise((resolve, reject) => {
      REQUEST.get(API.get_serverTime).then((res) => {
        const {
          status,
          data
        } = res.data
        if (status == 0 && data) {
          resolve(data)
        } else {
          reject()
        }
      }).catch(e => {
        console.error('get_serverTime报错-----------', e);
        reject(e)
      })
    })
  },
  getSystemInfo() { // 获取屏幕高度
    wx.getSystemInfo({
      success: (res) => {
        this.setData({
          windowHeight: res.windowHeight
        })
      }
    })
  },
  lower(e) { // scroll-view滚动到底部触发
  },
}
Page({
  data,
  ...methods,
  onHide() {},
  onLoad: function (options) {
    //拿到分享人工号,存入本地
    staffShare.setShareStaffIdByShare(options)
    app.globalData.actType = 0
    if (options.pageName) {
      wx.setNavigationBarTitle({
        title: options.pageName
      })
    }
    try {   
      wx.onCopyUrl(() => {
        return { query: WGFORMAT.formatQueryByOptions(options) }
      })
    } catch (error) {
      console.warn('暂不支持wx.onCopyUrl')
    }
  },
  onShow: function () {
    this.getSystemInfo()
    UTIL.setCartNum()
    LOADING.show()
    this.setData({
      openId: wx.getStorageSync('openId')
    })
    this.getPurchaseList()
    this.getPresaleList()
    // User.page_scan('拼团预售').then(res => { })
    this.getSvipStatus()
    this.setData({
      pageShow: true
    })
  },
  onShareAppMessage: function () { // 自定义点击右上角转发内容
    return {
      title: '五谷磨房，创造精致生活的更多种选择',
      path: '/pages/PromotionPage/PromotionPage?' + staffShare.getShareParams() //分享人工号，此时分享人为登录者本人
    }
  }
})