import {
  REQUEST,
  API,
  LOADING,
  TOAST
} from '../../utils/index.js'
import {
  WGAUTH,
  WGCOMMON,
  Page
} from '../../wgUtils/index.js';
const data = {
  userInfo: {
    customerMobile: '',
  },
  newMobile:'',
  guidelinesShow: false,
  newCustomerShow: false,
  virtualNum: '',
  cusId: wx.getStorageSync('cusId'),
  ysf: {
    title: '修改绑定手机号',
    config: JSON.stringify({
      "level": '', // vip等级
      "foreignid": wx.getStorageSync('cusId'),
      "data": JSON.stringify([{
        "index": 7,
        "type": "crm_param",
        "key": "partnerId",
        "value": 'cs' + wx.getStorageSync('cusId')
      }])
    })
  }
}
const methods = {
  initData() {
    if (!wx.getStorageSync('cusId') || !wx.getStorageSync('openId') || !wx.getStorageSync('unionId')) {
      this.setData({
        LoginShow: true,
      })
      return false
    }
    LOADING.show()
    this.setData({
      LoginShow: false,
    })
    let url = `${API.get_user_info}?openId=${wx.getStorageSync('openId')}&cusId=${wx.getStorageSync('cusId')}&unionId=${wx.getStorageSync('unionId')}`
    REQUEST.post(url).then((res) => {
      const {
        msgCode,
        resultInfo,
        msgInfo
      } = res.data
      if (msgCode == 0) {
        this.setData({
          'userInfo.customerMobile': resultInfo.customerMobile ? resultInfo.customerMobile : '',
        })
        LOADING.hide()
      } else {
        TOAST.warning({
          title: msgInfo
        }).then(() => {
          LOADING.hide()
        })
      }
    })
  },
  guidelinesBox(){
    this.setData({
      guidelinesShow: true,
      newCustomerShow: false
    })
  },
  changePhone(){
    let vm = this;
    vm.setData({
      guidelinesShow: true,
    })
  },
  bindgetphonenumber(e) {
    WGCOMMON.showLoading()
    WGAUTH.getPhoneNumber(e).then(() => {
      WGCOMMON.hideLoading()
      this.setData({
        guidelinesShow: false,
      })
      this.continue(wx.getStorageSync('phone'))
    }).catch(() => {
      WGCOMMON.toast('发生错误，请重试')
      WGAUTH.wxLogin()
      WGCOMMON.hideLoading()
    })
  },
  continue(phone){
    let vm = this;
    let url = `${API.getModifyInfoFromMiniApp}?oldMobile=${this.data.userInfo.customerMobile}&newMobile=${phone}`
    REQUEST.get(url).then((res) => {
      const {
        msgCode,
        resultInfo,
        msgInfo
      } = res.data
      if (msgCode == 0) {
        WGCOMMON.toast('登录成功，3s后将返回首页', 3000)
        setTimeout(function () {
          wx.switchTab({
            url: '/pages/Home/Home'
          })
        }, 3200)
        wx.setStorageSync('phone', phone)
      } else {
        // WGCOMMON.toast('更换失败')
        // setTimeout(function () {
        //   wx.switchTab({
        //     url: '/pages/Home/Home'
        //   })
        // }, 3200)
        //修改手机号失败
        let tel = phone
        let reg = /^(\d{3})\d{4}(\d{4})$/;
        tel = tel.replace(reg, "$1****$2");
        vm.setData({
          newCustomerShow: true,
          virtualNum: tel
        })
      }
    })
  },
  computedConfig() {
    if (this.data.cusId) return false;
    this.setData({
      cusId: wx.getStorageSync('cusId')
    })
    return {
      ysf: {
        title: '修改绑定手机号',
        config: JSON.stringify({
          "level": this.data.level == 1 ? 1 : '', // vip等级
          "foreignid": wx.getStorageSync('cusId'),
          "data": JSON.stringify([{
            "index": 7,
            "type": "crm_param",
            "key": "partnerId",
            "value": 'cs' + wx.getStorageSync('cusId')
          }])
        })
      }
    }
  },
  handleContact(e) {
    console.log('ysf.config前', this.data.ysf.config)
    let config = this.computedConfig()
    if (config) {
      this.setData({
        ysf: config.ysf
      })
    }

    console.log(e.detail.path)
    console.log(e.detail.query)
    var path = e.detail.path,
      query = e.detail.query,
      params = '';
    if (path) {
      for (var key in query) {
        params = key + '=' + query[key] + '&';
      }
      params = params.slice(0, params.length - 1);
      console.log('path, params------', path, params)
      if(path.indexOf('Home/Home') != -1 || path.indexOf('ProductIndex/ProductIndex') != -1 || path.indexOf('FanCommunity/pages/Index/Index') != -1 || path.indexOf('MyCart/MyCart') != -1 || path.indexOf('PersonalCenter/PersonalCenter') != -1) {
        wx.switchTab({
          url: path + '?' + params
        })
      } else {
        wx.navigateTo({
          url: path + '?' + params
        })
      }
    }
    console.log('ysf.config后', this.data.ysf.config)
  },
  releasePhone(){
    if(wx.getStorageSync('unionId')) {
      let url = `${API.postUnbindUnionId}?unionId=${wx.getStorageSync('unionId')}`
      REQUEST.post(url).then((res) => {
        const {
          msgCode,
          resultInfo,
          msgInfo
        } = res.data
        if (msgCode == 0) {
            WGCOMMON.toast('解绑成功，3s后将返回首页！')
            // wx.clearStorageSync()
            wx.removeStorageSync('phone')
            wx.removeStorageSync('cusId')
            wx.removeStorageSync('custChannel')
            setTimeout(function () {
              wx.switchTab({
                url: '/pages/Home/Home'
              })
            }, 3200)
        } else {
          TOAST.warning({
            title: msgInfo
          }).then(() => {
            LOADING.hide()
          })
        }
      })
    }else {
      TOAST.warning({
        title: '尚未绑定手机'
      }).then(() => {
      })
    }
  },
  closeGuidelines(){
    this.setData({
      guidelinesShow: false
    })
  },
}
Page({
  data,
  ...methods,
  onHide() {},
  onLoad(option) {
  },
  onShow: function () {
    this.initData()
  },
})

