// miniprogram/pages/search/search.js
import {
  API,
  REQUEST,
  LOADING,
  SRTRACK,
  FILTER
} from '../../utils/index.js'
import {
  Page
} from '../../wgUtils/index'
import api from '../../api/index';
const app = getApp()

Page({
  data: {
    goodData: [],
    hotData: [],
    pushModule: null,
    inputTxt: '',
    noData: false,
    recommandHeight: '88rpx',
    selectFlag: 0,
    canNavigateBack: true
  },
  onHide() {},
  onLoad(options) {
    if (options.selectFlag) {
      this.setData({
        selectFlag: 1
      })
    }
    this.hotSearch()
    this.getPushList()
    if (options.keyword) {
      this.search(options.keyword)
      this.setData({
        inputTxt: options.keyword
      })
    }
  },
  hotSearch: function () {
    //获取搜索推荐数据  get / product / hotSearch产品选择接口
    REQUEST.get(API.get_hotSearch).then(res => {
      const {
        status,
        data
      } = res.data
      this.setData({
        hotData: data
      })
    })
  },
  searchKeyInput(e) {
    this.setData({
      inputTxt: e.detail.value
    })
  },
  search: function (value) {
    console.log('搜索词', value)
    //get / product / search / { productName } / { displayArea }根据产品名称的模糊匹配 查询产品列表
    let url = API.get_goodSearch + `/${value}/3?channel=${wx.getStorageSync('custChannel')|| 0}&isSvipFlag=${wx.getStorageSync('vipCusStatus')|| 0}`
    var noData = true
    LOADING.show()
    REQUEST.get(url).then(res => {
      let likeIds = []
      const {
        status,
        data
      } = res.data
      if (status == 0) {
        if (data.length > 0) {
          for (let i = 0; i < data.length; i++) {
            if (!data[i].products) return false
            likeIds.push(data[i].id)
            data[i].sold = 0
            data[i].stock = 0
            data[i].icon = ''
            data[i].price = 0
            data[i].actType = 0 // actType 0普通  actType 6预售  actType 8团购  actType 9积分兑换 
            /** 原有：0普通，1/2旧秒杀，3暂无，4旧限时折扣，5/6/7预售，8拼团，9积分兑换，10暂无，11购买优惠券，12阶梯价（暂无用）14购买超级会员*/
            /** 新增 16限时折扣，17秒杀，18分期发货 */
            if (data[i].hotWord) {
              data[i].hotWord = [data[i].hotWord]
            }
            if (data[i].groupPurchase && data[i].groupPurchase.length > 0) {
              data[i].actType = 8 // actType 0普通  actType 6预售  actType 8团购  actType 9积分兑换 
            }
            let _priceArr = []
            let redeemPrices = []
            let _isRedeemFlag = false
            for (let j = 0; j < data[i].products.length; j++) {
              if (data[i].products[j].enable === 0) {
                if (data[i].products[j].sold > 0) {
                  data[i].sold += data[i].products[j].sold
                }
                if (data[i].products[j].stock > 0) {
                  data[i].stock += data[i].products[j].stock
                }
                if (data[i].products[j].isRedeem == 1) { // 积分兑换
                  _isRedeemFlag = true
                }
                _priceArr.push(data[i].products[j].price)
                redeemPrices.push(data[i].products[j].redeemPrice)
              }
            }
            if (data[i].groupedImages && data[i].groupedImages.icon) {
              data[i].icon = data[i].groupedImages.icon[0].imageUrl
            } else if (data[i].groupedImages && data[i].groupedImages.banner) {
              data[i].icon = data[i].groupedImages.banner[0].imageUrl
            } else if (data[i].products.length > 0 && data[i].products[0].imgUrl) {
              data[i].icon = data[i].products[0].imgUrl
            } else if (data[i].productImages.length > 0 && data[i].productImages[0].imageUrl) {
              data[i].icon = data[i].productImages[0].imageUrl
            }
            data[i].price = FILTER.getPriceRange(_priceArr)
            data[i].superPrice = FILTER.getPriceRange(_priceArr, 0.95)
            data[i].redeemPrices = FILTER.getPriceRange(redeemPrices)
            if (_isRedeemFlag) {
              data[i].actType = 9 // actType 0普通  actType 6预售  actType 8团购  actType 9积分兑换 
            }
          }
          noData = false
          this.setData({
            goodData: data
          })

        }
      } else {
        noData = true
      }
      this.getPushList(likeIds)
      wx.pageScrollTo({
        scrollTop: 0,
        duration: 300
      })
      this.setData({
        noData: noData
      })
      LOADING.hide()
    })
  },
  searchKey: function (e) {
    let value = e.currentTarget.dataset.text
    if (value != '') {
      SRTRACK.search(value)
      this.search(value);
      this.setData({
        inputTxt: value
      })
    }
  },
  searchGoods: function (e) {
    var value = e.detail.value;
    if (value != '') {
      this.search(value);
      this.setData({
        inputTxt: value
      })
    }
  },
  getPushList(likeIds) { //获取猜你喜欢列表
    if (!likeIds) likeIds = []
    REQUEST.post(API.post_product_info+`?channel=${wx.getStorageSync('custChannel')|| 0}&isSvipFlag=${wx.getStorageSync('vipCusStatus')|| 0}`, {
      header: {
        'content-type': 'application/json'
      },
      data: likeIds
    }).then((res) => {
      const {
        data,
        status
      } = res.data
      if (status == 0) {
        if (data && data.length > 1) {
          data.filter(item => {
            item.superPrice = FILTER.getPriceRange([item.minPrice], 0.95)
          })
        }
        this.setData({
          pushModule: data,
          // isAllRedeem: isAllRedeem
        })
      }
    })
  },
  goDetail(e) { // 跳转至商品详情页
    if (this.data.selectFlag == 1) {
      if (this.data.canNavigateBack) {
        this.setData({
          canNavigateBack: false
        })
        let item = e.currentTarget.dataset.item
        app.globalData.selectProduct = {
          pId: item.id ? item.id : item.productTemplateid,
          name: item.productTemplateName,
          imgUrl: item.icon ? item.icon : item.imageUrl,
          skuId: item.products ? item.products[0].id : -1
        }
        if (app.globalData.selectProduct.skuId == -1) {
          api.product.detail(item.id ? item.id : item.productTemplateid).then(res => {
            app.globalData.selectProduct.skuId = res.products[0].id
            this.setData({
              canNavigateBack: true
            })
            wx.navigateBack()
            return
          })
        } else {
          this.setData({
            canNavigateBack: true
          })
          wx.navigateBack()
          return
        }
      }
    } else {
      wx.navigateTo({
        url: '/pages/ProductDetail/ProductDetail?pId=' + e.currentTarget.dataset.id,
      })
    }
  },
  slideDown() { // 更多推荐
    this.setData({
      recommandHeight: 'auto'
    })
  },
  slideUp() { // 收起推荐
    this.setData({
      recommandHeight: '88rpx'
    })
  },
})