import {
  REQUEST,
  API,
  LOADING,
  TOAST,
} from '../../utils/index.js'
import User from '../../store/index.js'
import {
  Page
} from '../../wgUtils/index.js';

let ticketsData = []
const data = {
  reqParams: {
    cusid: wx.getStorageSync('cusId'),
    openid: '',
    vipCusStatus: 0 // 会员状态
    // channelType: 1, // 消费渠道（0.线下 1.线上 2.线上线下）
  },
  ticketsModule: [],
  noData: false,
  selectedStatus: 0, // 兑换码状态 0-未使用，1-已使用， 2-已过期
  curTime: null,
  LoginShow: false
}
const methods = {
  getSvipStatus() {
    User.getSvipStatus(wx.getStorageSync('cusId')).then(res => {
      this.data.reqParams.vipCusStatus = res.resultInfo.vipCusStatus
    })
  },
  initData() {
    if (!wx.getStorageSync('cusId') || !wx.getStorageSync('unionId')) {
      this.setData({
        LoginShow: true
      })
      return false
    }
    LOADING.show()
    this.getSvipStatus()
    let _self = this
    // REQUEST.post(API.get_coupon_detail, {
    //   data: {
    //     cusid: wx.getStorageSync('cusId'),
    //     openid: '',
    //     vipCusStatus: 1
    //   }
    // }).then(res => {

    // })
    let url = API.get_coupon_detail + '?cusid=' + wx.getStorageSync('cusId') + '&vipCusStatus=' + this.data.reqParams.vipCusStatus
    REQUEST.get(url, {
      header: {
        'content-type': 'application/json'
      }
    }).then((res) => {
      console.log(res.data)
      if (res.data.length > 0) {
        let ticketsModule = _self.filterData(res.data)
        ticketsData = ticketsModule.slice(0)
        setTimeout(function () {
          if (ticketsData.length > 0) {
            let newVal = []
            for (let i = 0; i < ticketsData.length; i++) {
              if (ticketsData[i].status == 0) {
                newVal.push(ticketsData[i])
              }
            }
            _self.setData({
              ticketsModule: newVal
            })
            console.log(newVal)
          }
        }, 0)
      } else {
        this.setData({
          noData: true
        })
      }
      LOADING.hide()
    })
  },
  getServerTime() {
    return new Promise((resolve, reject) => {
      REQUEST.get(API.get_serverTime).then((res) => {
        const {
          status,
          data
        } = res.data
        if (status == 0 && data) {
          this.data.curTime = data
          resolve()
        } else {}
      }).catch(() => {
        reject()
      })
    })
  },
  filterData(data) {
    let ticketsModule = data.map((item) => {
      if ([3].indexOf(item.codeStatus) != -1) { // 未使用
        item.status = 0
      }
      if ([2, 4].indexOf(item.codeStatus) != -1) { // 已使用
        item.status = 1
      }
      if (item.codeStatus == 1) { // 已过期
        item.status = 2
      }

      return {
        name: item.name,
        content: item.content,
        startTime: item.startTime,
        endTime: item.validTime ? item.validTime : item.endTime,
        status: item.status,
        codeStatus: item.codeStatus,
        isUsed: this.checkUsedStyle(item.status, item.startTime, item.endTime, item.validTime),
        isUsedLabel: this.checkUsedLabel(item.status),
        isMerchant: item.isMerchant,
        buyLink: item.buyLink,
        isExpried: [1, 2].indexOf(item.codeStatus) != -1 ? 1 : 0 // 1-已过期，0-未过期
      }
    })
    return ticketsModule
  },
  checkUsedLabel(status) {
    switch (status) {
      case 0:
        return '使用';
        break;
      case 1:
        return '已使用';
        break;
      case 2:
        return '已过期';
        break;
    }
  },
  checkUsedStyle(status, startTime, endTime, validTime) {
    let t0 = this.data.curTime
    let t1 = startTime.replace(/-/g, ':').replace(' ', ':')
    t1 = t1.split(':')
    let t11 = new Date(t1[0], (t1[1] - 1), t1[2], t1[3], t1[4], t1[5]).getTime()
    let t2, t22
    if (validTime) {
      t2 = validTime.replace(/-/g, ':').replace(' ', ':')
      t2 = t2.split(':')
      t22 = new Date(t2[0], (t2[1] - 1), t2[2], t2[3], t2[4], t2[5]).getTime()
    } else {
      t2 = endTime.replace(/-/g, ':').replace(' ', ':')
      t2 = t2.split(':')
      t22 = new Date(t2[0], (t2[1] - 1), t2[2], t2[3], t2[4], t2[5]).getTime()
    }
    if (status == 0) {
      if ((t0 >= t11) && (t0 <= t22)) {
        return 1;
      } else {
        return 0;
      }
    } else {
      return 0;
    }
  },
  toggleTickets(e) {
    if (e.detail == this.data.selectedStatus) return
    this.data.selectedStatus = e.detail
    if (ticketsData.length > 0) {
      let newVal = []
      for (let i = 0; i < ticketsData.length; i++) {
        if (ticketsData[i].status == e.detail) {
          newVal.push(ticketsData[i])
        }
      }
      this.setData({
        ticketsModule: newVal
      })
    }
  },
  goIndex(e) {
    let item = e.currentTarget.dataset.item
    console.log(item)
    if (item.isUsed) {
      if(item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink && item.buyLink.indexOf('ActivePage') != -1){
        // /pages/ActivePage/ActivePage?id=620
        // let i = item.buyLink.split('?')[1]
        wx.navigateTo({
          url: item.buyLink
        })
      }else if (item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink && item.buyLink.indexOf('productDetail') != -1) {
        let i = item.buyLink.split('?')[1]
        wx.navigateTo({
          url: '/pages/ProductDetail/ProductDetail?' + i
        })
      } else if (item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink && item.buyLink.indexOf('PersonalCenter') != -1) {
        wx.switchTab({
          url: item.buyLink
        })
      } else if (item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink && item.buyLink.indexOf('MyCart') != -1) {
        wx.switchTab({
          url: item.buyLink
        })
      } else if (item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink && item.buyLink.indexOf('WgFans') != -1) {
        wx.switchTab({
          url: item.buyLink
        })
      } else if (item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink && item.buyLink.indexOf('ProductIndex') != -1) {
        wx.switchTab({
          url: item.buyLink
        })
      } else if (item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink && item.buyLink.indexOf('Home') != -1) {
        wx.switchTab({
          url: item.buyLink
        })
      } else if (item.hasOwnProperty('buyLink') && typeof item.buyLink == 'string' && item.buyLink) {
        wx.navigateTo({
          url: item.buyLink
        })
      } else {
        wx.switchTab({
          url: '/pages/Home/Home'
        })
      }
    } else {
      if (item.status == 0) {
        TOAST.warning({
          title: '活动还未开始，不可使用'
        })
      }
    }
  },
  login() {
    this.setData({
      LoginShow: false
    }, () => {
      this.getServerTime().then((res) => {
        this.initData()
      })
    })
  }
}
Page({

  /**
   * 页面的初始数据
   */
  data,
  ...methods,
  onShow: function () {
    this.getSvipStatus()
    this.getServerTime().then((res) => {
      this.initData()
    })
  },
  onLoad(option) {
  },
  onHide() {},
  onShareAppMessage: function () {
    return {
      title: '五谷磨房个人中心'
    }
  }
})