import { Page, WGAUTH, WGCOMMON, WGENV, WGFORMAT, WGSUBSCRIBE, WGTRACK, WGUSER } from '../../wgUtils/index'
import { FILTER, LOADING } from '../../utils/index'
import SVIPRIGHTS from '../../assets/json/svipRights'
import WGAPI from '../..//api/index'
import MODULES from '../../utils/modules'
import STAFFSHARE from '../../utils/staffShare'

Page({
  data: {
    hidePulldow: false,
    svipRights: SVIPRIGHTS, // 超会权益
    moduleDatas: [ null, null, null, null ], // 页面配置信息
    swiperIndexs: [ 0, 0, 0, 0], 
    monthlyCoupons: [], // 当月券包
    monthlyCouponStatus: 1, // 1-预展示的，不能进行任何操作；0正常
    extension:[],//当月积分延期卡
    buyBtnType: 1, // /** 1:未开通超会的金谷以下￥199, 2:未开通超会金谷以上￥99,3:续费￥99；4非续费期内的有效超会 */
    saveMoney: { // 开通预计可节省多少钱
      total: 0,
      economicFee: 0,
      preEconomicFee: 0
    }, 
    userInfo: { // 用户信息
      avatarUrl: 'https://img.wgmf.com/img_default1.png'
    }, 
    isAgree: false, // 是否已同意购买规则

    willOverdue: false, // 我的超会是否一月内快过期
    hideSaveDetail1: true, // 隐藏节省弹窗
    hideSaveDetail2: true, // 隐藏30天内快过期的节省弹窗
    hideLeavePopUp: true, // 离开页面的提示弹窗
    hideQyPopup: true, // 企业微信二维码提示弹窗
    hidePowerDetail: true, // 权益说明弹窗
    hideFlopTip: true, // 可以翻牌提示弹窗
    flopGame: [], // 翻牌游戏
    isBirth: false, // 当天是否是生日
    shareId: null, // 超会的推荐人，推荐人是超会才算有效推荐
  },
  bindgetphonenumber(e) {
    LOADING.show()
    WGAUTH.getPhoneNumber(e).then(() => {
      this.initUserInfo()
      this.initPackageCoupon()
    })
  },
  goBack() { // 返回
    let pages = getCurrentPages() // 获取页面信息栈
    let prevPage = pages[pages.length - 2] // 获取上一个页面信息栈
    if(prevPage) {
      wx.navigateBack({})
    } else {
      wx.switchTab({ url: '/pages/Home/Home' })
    }
  },
  goDetail(e) { // 查看超会权益卡片详情
    let index = e.currentTarget.dataset.index
    let item = e.currentTarget.dataset.item
    wx.reportAnalytics('svip_benefits', {
      benefit_type: parseInt(index),
    });
    if(item) {
      WGTRACK.logCustomEvent('click_svipBenefits', { title: item.title, index: index + 1 })
    }
    wx.navigateTo({
      url: `/pages/MemberDetail/MemberDetail?types=${e.currentTarget.dataset.index}&buyBtnType=${this.data.buyBtnType}&saveTotal=${this.data.saveMoney.economicTotalFee}&vipCusStatus=${this.data.userInfo.vipCusStatus}`
    })
  },
  toggleAgreeBuyRule() { // 切换同意购买规则按钮
    let isAgree = !this.data.isAgree
    this.setData({ isAgree })
  },
  toggleLeavePopUp() { // 切换离开页面提示弹窗
    if(this.data.userInfo.vipCusStatus == 1) { // 已经是超会
      this.goBack()
      return
    }
    let pages = getCurrentPages() // 获取页面信息栈
    let prevPage = pages[pages.length - 2] // 获取上一个页面信息栈
    if(prevPage && prevPage.route.indexOf('/PayOrder/PayOrder') != -1) {
      this.goBack()
      return
    }
    let hideLeavePopUp = !this.data.hideLeavePopUp
    this.setData({ hideLeavePopUp })
  },
  toggleHideQyPopup() {
    this.setData({ hideQyPopup: !this.data.hideQyPopup })
  },
  toggleHidePowerDetail() {
    this.setData({ hidePowerDetail: !this.data.hidePowerDetail })
  },
  toggleHideSaveDetail1() {
    this.setData({ hideSaveDetail1: !this.data.hideSaveDetail1 })
  },
  toggleHideSaveDetail2() {
    this.setData({ hideSaveDetail2: !this.data.hideSaveDetail2 })
  },
  toggleHideFlopTip() {
    this.setData({ hideFlopTip: !this.data.hideFlopTip })
  },
  initModule(pageId, index) { // 加载页面模块
    WGAPI.modules.getById(pageId).then(r => {
      if(r) {
        let newpage = MODULES.formatModules(r)
        this.setData({
          ['moduleDatas[' + index + ']']: newpage,
          ['swiperIndexs[' + index + ']']: 0
        })
      }
    })
  },
  initUserInfo() { // 初始化用户信息
    let cusId = wx.getStorageSync('cusId')
    if(cusId) {
      let userInfo = {
        nickName: '匿名',
        avatarUrl: 'https://img.wgmf.com/img_default1.png',
        vipCusStatus: 0, // 0非超会，1有效超会，2过期超会
        svipYears: 0, // 超会年限标记
        isJinGu: 0, // 是否是金谷以上会员
        cusId: cusId,
      } 
      let buyBtnType = 1
      Promise.all([
        WGUSER.getCustomerInfo(),
        WGUSER.querySVipOnlineCusInfo(),
        WGAPI.user.isWillOverdue(cusId)
      ]).then(res => {
        let avatarUrl = wx.getStorageSync('avatarUrl')
        let nickName = wx.getStorageSync('nickName')
        userInfo.nickName = res[0].customerName?res[0].customerName:(res[0].nickName?res[0].nickName:(nickName?nickName:'匿名'))
        userInfo.avatarUrl = res[0].headImgUrl?res[0].headImgUrl:(avatarUrl?avatarUrl:'https://img.wgmf.com/img_default1.png')
        userInfo.isJinGu = (res[0].customerGrade == '金谷会员' ? 1 : (res[0].customerGrade == '钻谷会员' ? 1 : 0))
        userInfo.svipYears = res[1].term
        userInfo.vipCusStatus = res[1].vipCusStatus
        userInfo.vipInvalidTime = res[1].vipInvalidTime
        userInfo.vipInvalidTimeCn = WGFORMAT.formatDate(res[1].vipInvalidTime, 'yyyy.MM.dd')
        userInfo.packs = res[1].packs
        userInfo.vipBuyTime = res[1].vipBuyTime
        userInfo.vipBeginTime = res[1].vipBeginTime
        this.data.willOverdue = res[2].willOverdue
        this.data.payCustomer = res[2].payCustomer
        /** 1:未开通超会的金谷以下, 2:未开通超会金谷以上,3:续费；4非续费期内的有效超会 */
        if(res[1].vipCusStatus == 0 || (res[1].vipCusStatus == 2 && !this.data.payCustomer)) { // 非超会
          buyBtnType = userInfo.isJinGu?2:1
        } else if(res[1].vipCusStatus == 1 && this.data.payCustomer) { // 有效超会
          buyBtnType = FILTER.validTimestamp(userInfo.vipInvalidTime, 90)?3:4
        } else if(res[1].vipCusStatus == 2 && this.data.payCustomer) { // 过期超会
          buyBtnType = 3
        }
        this.setData({ userInfo, buyBtnType })
        this.getEconomicFee()
        this.initExtension()
        this.initBirthViewData(res[0].customerBirthday, res[1].vipCusStatus)
        if(res[1].vipCusStatus == 1 || res[1].vipCusStatus == 2) {
          this.getFlopChance(cusId)
        }
        this.initShareId() // 推荐人的cusId是否有效
      })

    }
  },
  initShareId() {
    if(this.data.shareId) {
      WGAPI.user.querySVipOnlineCusInfo(this.data.shareId).then(res => {
        if(res && res.vipCusStatus == 1 && this.data.buyBtnType == 1) {
          this.setData({ buyBtnType: 2 })
        }
      })
    }
  },
  getFlopChance(cusId) { // 检查是否有翻牌机会
    WGAPI.svip.flopCheck(cusId).then(res => {
      if(res && res.chanceNum > 0 && this.data.userInfo.vipCusStatus == 1) {
        this.setData({ hideFlopTip: false })
      }
    })
  },
  toFlipGame() {
    // WGCOMMON.toast('【翻盘赠礼】惊喜准备中，敬请期待')
    wx.navigateTo({
      url: '/modules/Svip/pages/FilpGame/FilpGame'
    })
  },
  initBirthViewData(birth, vipCusStatus) {
    if(birth && vipCusStatus == 1) {
      birth = birth.replace(/\-/g, '/')
      let date = new Date(birth)
      let now = new Date() 
      // console.error(date.getMonth(),now.getMonth(),date.getDate(),now.getDate())
      if((date.getMonth() == now.getMonth()) && (date.getDate() == now.getDate())) {
        this.setData({ isBirth: true })
      } else {
        this.setData({ isBirth: false })
      }
    } else {
      this.setData({ isBirth: false })
    }
  },
  initPackageCoupon() { // 初始化当月的券包
    if(wx.getStorageSync('cusId')) {
      WGAPI.coupons.querySVipMonthPackage(wx.getStorageSync('cusId')).then(res => {
        if(res.data.resultInfo && res.data.resultInfo.length > 0) {
          this.setData({ monthlyCoupons: res.data.resultInfo[0].packageDatas })
        }
        this.data.monthlyCouponStatus = res.data.msgCode
        this.data.errMsg = res.data.msgInfo
      })
    }
  },
  initExtension(){//初始化积分延期卡
    let that = this
    if(wx.getStorageSync('cusId')) {
      WGAPI.coupons.pointsDelayCard(wx.getStorageSync('cusId')).then(res => {
        console.log(that.data.userInfo.vipCusStatus)
        res.forEach((item)=>{
          if(that.data.userInfo.vipCusStatus !=1){
            item.url ='https://img.wgmf.com/img_svip_integral_delay_card_01.png';
            item.tips ='专属特权';
          }else {
            if(item.useStatus == '0'){
              item.url ='https://img.wgmf.com/img_svip_integral_delay_card_01.png';
              item.tips ='待使用';
            } else {
              item.url ='https://img.wgmf.com/img_svip_integral_delay_card_02.png';
              item.tips ='已使用';
              item.gray = true;
            }
          }
        })
        this.setData({ extension: res })
      })
    }
  },
  
  goExtension() { // 点击超会跳转积分延期卡
    wx.navigateTo({
      url: '/modules/Svip/pages/ExtensionCar/ExtensionCar'
    })
  },
  takeCoupon(e) { // 领取优惠券
    console.error(this.data.userInfo.vipCusStatus)
    if(this.data.monthlyCouponStatus != 0) {
      WGCOMMON.showModal('优惠券提示', this.data.errMsg)
      return
    }
    // if(this.data.monthlyCouponStatus == 1 && this.data.userInfo.vipCusStatus != 1) { // 非超会虚拟数据 & 过期超会虚拟数据
    //   WGCOMMON.showModal('优惠券提示', '点击开通超级会员后，才可领取优惠券哦~')
    //   return
    // }
    // if(this.data.monthlyCouponStatus == 1 && this.data.userInfo.vipCusStatus == 1) { // 超会虚拟数据
    //   WGCOMMON.showModal('优惠券提示', '开通后第3个月起才能领券包哦~')
    //   return
    // }
    let ticketDetailId = e.currentTarget.dataset.ticket
    let cusId = wx.getStorageSync('cusId')
    if(cusId) {
      WGSUBSCRIBE('remindCoupon').then(() => {
        WGAPI.coupons.receiveCurMonthTicket(cusId, ticketDetailId).then(res => {
          WGCOMMON.toastSuccess('领券成功！')
          this.initPackageCoupon()
        })
      })
    }
  },
  getEconomicFeeBySvipStatus(cusId) {
    if(this.data.userInfo.vipCusStatus == 1) {
      return WGAPI.svip.economizeNew(cusId) // 已节省金额计算
    } else {
      return WGAPI.svip.getNewEconomicFee() // 预计节省金额（非超会）
    }
  },
  getWillOverdueFee(cusId) {
    if(this.data.willOverdue) {
      return WGAPI.user.economize(cusId)
    } else {
      return Promise.resolve({})
    }
  },
  getEconomicFee() { // 加载超会节省信息
    let cusId = wx.getStorageSync('cusId')
    if(cusId) {
      Promise.all([
        this.getWillOverdueFee(cusId),
        this.getEconomicFeeBySvipStatus(cusId),
      ]).then(result => {
        this.setData({ 
          saveMoney: {
            ...result[0], // 45天内快过期的节省续费弹窗
            ...result[1], // 开通超会预计节省弹窗 & 开通超会后已节省的弹窗
          },
        })
        if(this.data.willOverdue) {
          this.toggleHideSaveDetail2()
          this.setData({ buyBtnType: 3 })
        }
        WGCOMMON.hideLoading()
      })
    }
  },
  buySvip() { // 点击购买超会
    if(!this.data.isAgree) {
      WGCOMMON.toast('请先阅读并同意《五谷磨房超级会员服务协议》', 2500)
      return false
    }
    wx.navigateTo({
      url: `/pages/PayOrder/PayOrder?isSvip=1${this.data.shareId?('&shareId='+this.data.shareId):''}` 
    })
  },
  initFlopGame() { // 初始化翻牌游戏
    WGAPI.svip.initFlop().then(res => {
      if(res) {
        res.sort((a, b) => {
          return b.worth - a.worth
        })
        this.setData({ flopGame: res })
      }
    })
  },
  toggleToast(e) { // homeModule 埋点
    this.data.moduleDatas[2].modules.forEach(item => {
      if(item.moduleType == 2){
        item.cells[0].forEach(i => {
          if(i.id == e.detail.id && i.link.indexOf("modules/ProductTrial/pages/TrialCenter/TrialCenter") != -1){
            WGTRACK.logCustomEvent('click_superMember_activity')
          }
        })
      }
    })
  },
  toSpecialOffer(){
    wx.createSelectorQuery().select('#special-offer').fields({
      scrollOffset: true,
      rect: true
    },
    function (res) {
      console.log(res)
      wx.pageScrollTo({
        scrollTop: res.top,
        duration: 300
      })
    }).exec()
  },
  distributedFn(){ //跳转每月券包
    wx.navigateTo({
      url: "/modules/Svip/pages/MonthlyCoupons/MonthlyCoupons"
    })
  },
  onLoad(options) {
    WGCOMMON.showLoading()
    if(WGENV.env == 'TEST') {
      this.initModule(697, 2)
      this.initModule(134, 1)
      this.initModule(135, 0)  
    } else {
      this.initModule(350, 2)
      this.initModule(349, 1)
      this.initModule(348, 0) 
      this.initModule(378, 3)  
    }
    this.initUserInfo()
    this.initPackageCoupon()
    this.initFlopGame()

    STAFFSHARE.setShareStaffIdByShare(options)
    if(options.showQy) {
      this.setData({ hideQyPopup: false })
    }
    this.setData({ navSize: WGCOMMON.getNavSize() })
    if(options.shareId) { // 超会的推荐人
      this.data.shareId = options.shareId
    }
    if(options.specialoffer){
      this.toSpecialOffer()
    }
  },
  onShow() {
    this.initUserInfo()
  },
  onShareAppMessage() {
    // console.log('/pages/superMember/superMember?shareId=' + wx.getStorageSync('cusId') + '&' + STAFFSHARE.getShareParams())
    return {
      title: '好友' + (this.data.userInfo.nickName ? this.data.userInfo.nickName : '') + '邀您开通五谷磨房超级会员',
      path: '/pages/superMember/superMember?shareId=' + wx.getStorageSync('cusId') + '&' + STAFFSHARE.getShareParams()
    }
  },
  onShareTimeline() {
    return {
      title: '好友' + (this.data.userInfo.nickName ? this.data.userInfo.nickName : '') + '邀您开通五谷磨房超级会员',
      path: '/pages/superMember/superMember?shareId=' + wx.getStorageSync('cusId') + '&' + STAFFSHARE.getShareParams()
    }
  },
  onPageScroll(e) {
    if(e.scrollTop > 660) {
      this.setData({
        hidePulldow: true
      })
    } else {
      this.setData({
        hidePulldow: false
      })
    }
  },
})