import routes from './routes'

// 传入的字符串路由
// 支持传入 name / url
function routerIsString(routeStr) {
  for (let {
      name,
      url
    } of routes) {
    if (name === routeStr || url === routeStr) {
      return url
    }
  }
  throw new Error('not found router ' + routeName)
}

// 传入的对象路由
function routerIsObject(routeObj) {
  const {
    name,
    url,
    search
  } = routeObj
  let generateFullUrl = ''
  let generateSearch = ''
  let searchRoutesResult = {}

  // 处理传入的 search参数
  if (search && search.toString() === '[object Object]') {
    generateSearch = []
    if (!Object.entries)
      Object.entries = function (obj) {
        var ownProps = Object.keys(obj),
          i = ownProps.length,
          resArray = new Array(i); // preallocate the Array
        while (i--)
          resArray[i] = [ownProps[i], obj[ownProps[i]]];
        return resArray;
      };
    for (let [key, val] of Object.entries(search)) {
      generateSearch.push(`${key}=${val}`)
    }
    generateSearch = generateSearch.join('&')
  }

  // 遍历路由
  if (name && typeof name === 'string') {
    searchRoutesResult = routes.filter(item => item.name === name)[0]
  } else if (url && typeof url === 'string') {
    searchRoutesResult = routes.filter(item => item.url === url)[0]
  }

  if (searchRoutesResult && searchRoutesResult.toString() === '[object Object]') {
    generateFullUrl = `${searchRoutesResult.url}?${generateSearch}`
  } else {
    throw new Error('not found router ' + `${name || url}`)
  }
  return generateFullUrl
}


/**
 * param {String} 'MyCard'
 * return {String} '/pages/MyCard/MyCard'
 * param {Object} {name: 'MyCard', search: {id: 123, ags: 234}}
 * return {String} '/pages/MyCard/MyCard?id=123&ags=234'
 */
const router = (routeInfo) => {
  if (!routeInfo) {
    throw new Error('router args is empty.')

  } else if (typeof routeInfo === 'string') {
    return routerIsString(routeInfo)

  } else if (typeof routeInfo === 'object' && routeInfo.toString() === '[object Object]') {
    return routerIsObject(routeInfo)

  } else {
    throw new Error('router is Error.')
  }
  return ''
}

export default router