/**
 * 观察者模式
 * 公共事件总线
 */
class Bus {
  constructor(store) {
    /**
     * this.store = {
     *  eventName: [
     *    {cb: callback, once: false}
     *  ]
     * }
     */
    this.store = store || {}
  }

  // 订阅事件
  on(eventName, callback, once = false) {
    const activeEventList = this.store[eventName] || []
    activeEventList.push({
      cb: callback,
      once: once
    })

    this.store[eventName] = activeEventList
  }

  // 发布事件
  trigger(eventName) {
    const activeEventList = this.store[eventName]
    if (!activeEventList || activeEventList.length === 0) {
      return false
    }

    activeEventList.forEach((item) => {
      item.cb()
    })
  }

  // 取消事件订阅
  off(eventName) {
    Reflect.deleteProperty(this.store, eventName)
  }
}

export default Bus