import baseUrl from './env'

function getHeader(type) {
  let t = 'application/json'
  if (type == 'formdata') {
    t = 'application/x-www-form-urlencoded'
  }
  if (wx.getStorageSync('token')) {
    return {
      'content-type': t,
      'token': wx.getStorageSync('token')
    }
  }
  return {
    'content-type': t
  }
}

function showErrToast(e, isShowError) {
  if (e && isShowError) {
    if (Object.prototype.toString.call(e) == '[object Object]') {
      e = JSON.stringify(e)
    }
    wx.showToast({
      title: e.toString(),
      icon: 'none',
      duration: 3500
    })
  }
}

/**
 * 
 * @param {*} url 接口地址
 * @param {*} data 请求数据
 * @param {*} method 请求方法'GET'/'POST'/'PUT'/'DELETE'
 * @param {*} paramsType 数据类型'json'/'formdata'，默认‘json’，
 * @param {*} isFliterResult 是否过滤返回结果，默认true/1过滤，传入false/0表示不过滤结果
 * @param {*} isShowError 是否显示错误信息，默认true/1显示，传入false/0表示不显示
 */
function getPromise(url, data, method = 'GET', paramsType = 'json', isFliterResult = true, isShowError = true) {
  return new Promise((resolve, reject) => {
    wx.request({
      url: `${baseUrl}${url}`,
      header: getHeader(paramsType),
      method: method,
      data: data,
      success: function (res) {
        if(isFliterResult) { // 对结果进行过滤
          if (res.statusCode == 200) {
            if (res.data.status != undefined) {
              if (res.data.status === 0) {
                if (res.data.hasOwnProperty('data')) {
                  resolve(res.data.data)
                }
                resolve(res.data)
              } else {
                reject(res.data.msg)
              }
            }
            if (res.data.msgCode != undefined) {
              if (res.data.msgCode === 0) {
                resolve(res.data.resultInfo)
              } else {
                reject(res.data.msgInfo)
              }
            }
            resolve(res.data)
          } else {
            reject(res.data || res.errMsg)
          }
        } else { // 不过滤结果
          resolve(res)
        }
      },
      fail: function (err) {
        reject(err)
      }
    })
  }).catch(function (e) {
    showErrToast(e, isShowError)
  })
}

const http = {
  get: function (url, data, paramsType, isFliterResult, isShowError) {
    return getPromise(url, data, 'GET', paramsType, isFliterResult, isShowError)
  },
  post: function (url, data, paramsType, isFliterResult, isShowError) {
    return getPromise(url, data, 'POST', paramsType, isFliterResult, isShowError)
  },
  put: function (url, data, paramsType, isFliterResult, isShowError) {
    return getPromise(url, data, 'PUT', paramsType, isFliterResult, isShowError)
  },
  delete: function (url, data, paramsType, isFliterResult, isShowError) {
    return getPromise(url, data, 'DELETE', paramsType, isFliterResult, isShowError)
  }
}

export default http