import UTIL from './util.js'
import CARTTRACK from './cartTrack'
import { WGCOMMON, WGDATATYPE, WGFORMAT } from '../wgUtils/index'
import { SRTRACK } from '../utils/index'
import API from '../api/index'
/**
 * skuName 
 * skuId / id / productId
 * pName / name
 * pId / productTemplateId
 * quantity 数量
 * price 现价
 * originPrice 原价
 * redeemPrice 积分兑换价
 * isChecked 是否选中
 * icon 产品图
 * stock 库存
 * limitQuantity 限购数
 * warehouseCode 仓库代码
 * isRedeem 是否是积分兑换商品
 * integralStatus 积分倍数
 * cartProTag 产品活动类型标签，如特价/限时折扣/积分兑换
 * endTime 活动结束时间
 * productCategory 产品类型，主要用于判断产品是不是自营产品
 */
class ShopCartServer {
  constructor(cart) {
    this.buyNow = {} // 立即购买
    this.cart = cart  // 购物车 -- 用对象键值对的方法管理购物车，方便查找对象
    wx.setStorageSync('addCart', cart)
  } 
  setBuyNow(product) { // 设置立即购买的商品
    this.buyNow = product
    wx.setStorageSync('buyNowProduct', [product])
  }
  getBuyNow() { // 获取立即购买的商品
    return wx.getStorageSync('buyNowProduct') || this.buyNow
  }
  refreshCart() { // 刷新本地缓存的购物车数据
    wx.setStorageSync('addCart', this.cart)
    UTIL.setCartNum()
  }
  refreshCartByServer() {
    let ids = []
    let vipCusStatus = wx.getStorageSync('vipCusStatus')
    for(let key in this.cart) {
      ids.push({ 'productId': parseInt(key)})
    }
    if(ids.length > 0) {
      API.cart.refresh(JSON.stringify(ids)).then(res => {
        console.log('刷新购物车里的数据', res)
        console.log('刷新前', this.cart)
        for(let i=0;i<res.length;i++) {
          let sku = res[i].product
          let skuId = sku.id 
          if(this.cart[skuId]) { // 刷新购物车里的产品数据
            if(sku.enable == 1) { // 如果商品下架了或商品被禁用
              delete this.cart[skuId]
            } else {
              this.cart[skuId].stock = sku.stock
              this.cart[skuId].purchaseLimitQuantity = sku.purchaseLimitQuantity?sku.purchaseLimitQuantity:sku.stock
              this.cart[skuId].price = vipCusStatus == 1?WGFORMAT.formatCurrency(sku.price * 0.95):WGFORMAT.formatCurrency(sku.price)
              this.cart[skuId].noSvipPrice = WGFORMAT.formatCurrency(sku.price)
              this.cart[skuId].redeemPrice = sku.redeemPrice
              this.cart[skuId].isRedeem = sku.isRedeem
              if(this.cart[skuId].endTime) {
                let now = new Date().getTime()
                if(now >= this.cart[skuId].endTime) { // 活动时间已经结束，产品价格要恢复原价
                  this.cart[skuId].endTime = null
                  this.cart[skuId].cartProTag = ''
                }
              }
            }
          }
        }
        console.log('刷新后', this.cart)
        this.refreshCart()
      })
    }
  }
  initCart() { // 获取购物车数据 --- 数组类型
    let tmp = this.cart
    let res = []
    for(let i in tmp) {
      res.push(tmp[i])
    }
    return res
  }
  getCart() { // 获取本地缓存里的购物车信息  ---- 对象类型
    return this.cart || wx.getStorageSync('addCart')
  }
  checkQuantityValid(product, currentNum, addNum) { // 检查购买数量是否合法
    if(!product.hasOwnProperty('limitQuantity')) {
      product['limitQuantity'] = product.stock
    }
    if(addNum > product.stock) {
      WGCOMMON.toast('加购数量超过库存啦~')
      return false
    }
    if(addNum > product.limitQuantity) {
      WGCOMMON.toast(`此商品每人限购${product.limitQuantity}件`)
      return false
    }
    if(currentNum > 0) {
      if(currentNum + addNum > product.stock) {
        WGCOMMON.toast(`加购数量超过库存，购物车里已经有${currentNum}件了`)
        return false
      }
      if(currentNum + addNum > product.limitQuantity) {
        WGCOMMON.toast(`此商品每人限购${product.limitQuantity}件，购物车里已经有${currentNum}件了`)
        return false
      }
    }
    return true
  }
  addCart(product) { // 添加商品至购物车
    if(this.checkQuantityValid(product, this.cart[product.id]?this.cart[product.id].quantity:0, product.quantity)) {
      if(this.cart[product.id]) {
        product.quantity += this.cart[product.id].quantity
        this.cart[product.id] = product
      } else {
        this.cart[product.id] = product
      }
      this.refreshCart()
    }
  }
  emptyCart() { // 清空购物车
    this.cart = {}
    this.refreshCart()
  }
  delCartItem(skuId) { // 删除购物车里的商品
    if(this.cart[skuId]) {
      CARTTRACK('deleteCart')
      SRTRACK.deleteCart(this.cart[skuId])
      delete this.cart[skuId]
      this.refreshCart()
    }
  }
  removeProducts(ids, isBuyNow) { // 下单结算后，需要清除购物车里下单的商品
    if(ids && ids.length == 0) return
    if(isBuyNow) {
      this.setBuyNow({})
      return
    }
    for(let i=0;i<ids.length;i++) {
      if(this.cart[ids[i]]) {
        delete this.cart[ids[i]]
      }
    }
    this.refreshCart()
  }
  setProductQuantity(skuId, quantity) { // 更改购物车里的商品数量
    if(this.cart[skuId]) {
      if(this.checkQuantityValid(this.cart[skuId], this.cart[skuId].quantity, quantity)) {
        this.cart[skuId].quantity += quantity
        if(this.cart[skuId].quantity <= 0) {
          this.delProduct(skuId)
        } else {
          SRTRACK.myCartAddCart(this.cart[skuId])
        }
        if(quantity > 0) {
          CARTTRACK('increase')
        } else if(quantity < 0) {
          CARTTRACK('decrease')
        }
        UTIL.setCartNum()
      }
    }
  }
  increaseProduct(skuId) { // 商品数量+1
    this.setProductQuantity(skuId, 1)
  }
  decreaseProduct(skuId) { // 商品数量-1
    this.setProductQuantity(skuId, -1)
  }
  getCartNum() { // 获取购物车里全部的商品数量
    let len = 0
    for(let i in this.cart) {
      len += this.cart[i].quantity
    }
    return len 
  }
  getIntegralProsNum() { // 获取购物车里全部的积分兑换商品数量
    let num = 0
    let addCartVal = this.cart
    for (let i in addCartVal) {
      if(addCartVal[i].isRedeem == 1) {
        num += addCartVal[i].quantity
      }
    }
    return num
  }
  getCheckedQuantity() { // 获取选中的商品的数量
    let quantity = 0
    for(let i in this.cart) {
      if(this.cart[i].isChecked) {
        quantity += this.cart[i].quantity
      }
    }
    return quantity
  }
  getCheckedInteQuantity() { // 获取选中的积分商品的数量
    let quantity = 0
    for(let i in this.cart) {
      if(this.cart[i].isChecked && this.cart[i].isRedeem == 1) {
        quantity += this.cart[i].quantity
      }
    }
    return quantity
  }
  getCartOneNum(skuId) { // 获取购物车里某个商品的数量
    if(this.cart[skuId]) {
      return this.cart[skuId].quantity
    } 
    return 0
  }
  getCheckedCart() { // 获取被选中的购物车数据 ----- 返回的是数组
    let res = []
    for(let i in this.cart) {
      if(this.cart[i].isChecked) {
        res.push(this.cart[i])
      }
    }
    return res
  }
  setSingleProductCheck(skuId, isChecked) { // 选中或取消某款商品
    if(this.cart[skuId]) {
      this.cart[skuId].isChecked = isChecked
    }
  }
  setAllChecked(isChecked) { // // 选中或取消全部商品
    for(let i in this.cart) {
      this.cart[i].isChecked = isChecked
    }
  }
}

let cartData = wx.getStorageSync('addCart')
let cartDataExit = {}
if(cartData && WGDATATYPE.isArray(cartData)) {
  for(let i=0;i<cartData.length;i++) {
    cartDataExit[cartData[i].id] = cartData[i]
  }
}
if(cartData && WGDATATYPE.isObject(cartData)) {
  cartDataExit = cartData
}
let instance = new ShopCartServer(cartDataExit)
export default instance