import { WGENV, WGCOMMON, WGUSER, WGTRACK } from './index'
import wgEnv from './wgEnv'

function clearSessionKey() {
  WGCOMMON.toast('网络异常，请重试', 1500)
  wx.removeStorageSync('sessionKey')
  wxLogin()
}

/** 检查微信的登录是否过期并获取登录的会话秘钥
 * 未过期：返回本地存储的sessionKey
 * 已过期或本地无sessionKey：抛出错误
 */
function getSessionKey() {
  return new Promise((resolve, reject) => {
    let sessionKey = wx.getStorageSync('sessionKey')
    if(sessionKey) {
      wx.checkSession({
        success() { //session_key 未过期，并且在本生命周期一直有效
          resolve(sessionKey)
        }, 
        fail() { // session_key 已经失效，需要重新执行登录流程
          wxLogin().then(key => {
            resolve(key)
          }).catch(e => {
            reject(e)
          })
        }
      })
    } else {
      wxLogin().then(key => {
        resolve(key)
      }).catch(e => {
        reject(e)
      })
    }
  })
}

/** 微信静默授权登录
 * 调用成功前置条件：无
 * 成功后：本地缓存新增 sessionKey + openId + [cusId] + [unionId]，Promise返回sessionKey
 * 失败后：Promise返回失败原因
 */
function wxLogin() {
  return new Promise((resolve, reject) => {
    wx.login({
      success(res) {
        if(res.code) {
          let baseUrl = WGENV.env == "TEST" ? 'https://newapitest.wgmf.com/' : 'https://newapi.wgmf.com/'
          wx.request({
            // url: WGENV.baseUrl + 'wechat-miniprogram-back/base/jscode2sessionPost',
            url: baseUrl+'wechat/mini/base/jscode2sessionPost',
            method: "POST",
            data: {
              appId: WGENV.appId,
              jsCode: res.code
            },
            success(res) {
              if(res.statusCode == 200 && res.data) {
                wx.setStorageSync('sessionKey', res.data.payload.sessionKey)
                wx.setStorageSync('openId', res.data.payload.openid)
                WGTRACK.setUserOpenId(res.data.payload.openid)
                if(Object.prototype.hasOwnProperty.call(res.data.payload, 'unionid')) {
                  wx.setStorageSync('unionId', res.data.payload.unionid)
                  WGTRACK.setLoginUser(res.data.payload.unionid)
                }
                if(Object.prototype.hasOwnProperty.call(res.data.payload, 'cusId')) {
                  wx.setStorageSync('cusId', res.data.payload.cusId)

                  WGUSER.querySVipOnlineCusInfo()
                  WGUSER.getCustomerInfo()
                  
                  WGTRACK.setRegisterUser(res.data.payload.cusId)
                }
                resolve(res.data.payload.sessionKey)
              } else {
                reject(res.errMsg || res.data)
              }
            },
            fail(err) {
              reject(err.errMsg || err)
            }
          })
        } else {
          reject(res.errMsg || res)
        }
      },
      fail(err) {
        reject(err.errMsg || err)
      }
    })
  })
}


/** 企业微信静默授权登录
 * 调用成功前置条件：无
 * 成功后：本地缓存新增staffId，弹窗显示staffId
 * 失败后：弹窗显示失败原因
 */
function qyLogin() {
  let env = wx.getSystemInfoSync()
  if (env.environment) { // 企业微信打开
    wx.qy.login({
      success(res) {
        if (res.code) {
          wx.request({
            url:  WGENV.baseUrl + 'wechat-miniprogram-service/qyMiniAppOAuth/microMallJscode2session',
            method: 'GET',
            data: {
              jsCode: res.code
            },
            success(res) {
              console.log('res-------------', res)
              if(res.statusCode == 200 && res.data) {
                wx.setStorageSync('staffId', res.data.data)
                WGCOMMON.toast('您的顾问ID为' + res.data.data, 5000)
              } else {
                WGCOMMON.toast(res.errMsg || res.data)
              }
            },
            fail(err) {
              WGCOMMON.toast(err.errMsg || err)
            }
          })
        } else {
          WGCOMMON.toast(res.errMsg || res)
        }
      },
      fail(err) {
        WGCOMMON.toast(err.errMsg || err)
      }
    })
  }
}


/** 微信授权用户信息
 * 调用成功前置条件：本地缓存有cusId
 * 成功后：本地缓存新增vipCusStatus，Promise返回vipCusStatus
 * 失败后：Promise返回失败原因
 */
function getUserInfo(e) {
  return new Promise((resolve, reject) => {
    if (e.detail.errMsg === 'getUserInfo:ok') {
      getSessionKey().then(key => {
        wx.request({
          url: WGENV.baseUrl + 'wechat-miniprogram-back/base/saveMiniAppUser',
          data: {
            encryptedData: e.detail.encryptedData,
            sessionKey: key,
            iv: e.detail.iv,
            appId: WGENV.appId
          },
          method: "POST",
          success(res) {
            if(res.statusCode == 200 && res.data && res.data.data) {
              let userInfoObj = res.data.data
              wx.setStorageSync('openId', userInfoObj.openId)
              wx.setStorageSync('nickName', userInfoObj.nickName)
              wx.setStorageSync('avatarUrl', userInfoObj.avatarUrl)
              WGTRACK.setUserOpenId(userInfoObj.openId)
              if(Object.prototype.hasOwnProperty.call(userInfoObj, 'unionId')) {
                wx.setStorageSync('unionId', userInfoObj.unionId)
                WGTRACK.setLoginUser(userInfoObj.unionId)
              }
              if(Object.prototype.hasOwnProperty.call(userInfoObj, 'cusId')) {
                wx.setStorageSync('cusId', userInfoObj.cusId)
                WGTRACK.setRegisterUser(userInfoObj.cusId)
              }
              WGUSER.querySVipOnlineCusInfo()
              WGUSER.getCustomerInfo()
              resolve(userInfoObj)
            } else {
              clearSessionKey()
            }
          },
          fail() {
            clearSessionKey()
          }
        })
      }).catch(e => {
        WGCOMMON.toast(e)
        reject(e)
      })
    } else {
      WGCOMMON.toast(e.detail.errMsg)
      reject(e.detail.errMsg)
    }
  })
}


/** 微信授权手机号
 * 调用成功前置条件：无
 * 成功后：本地缓存新增phone，Promise返回phone
 * 失败后：Promise返回失败原因且弹窗显示失败原因
 */
function getPhoneNumber(e) {  
  return new Promise((resolve, reject) => {
    if (e.detail.errMsg === "getPhoneNumber:ok") {
      getSessionKey().then(key => {
        wx.request({
          url:WGENV.baseUrl + 'wechat-miniprogram-back/base/getPhoneNumber',
          data: {
            appId: WGENV.appId,
            encryptedData: e.detail.encryptedData,
            sessionKey: key,
            iv: e.detail.iv
          },
          header: {
            "content-type": "application/json"
          },
          method: "POST",
          success(res) {
            if(res.statusCode == 200 && res.data && res.data.phoneNumber) {
              wx.setStorageSync('phone', res.data.phoneNumber)
              WGUSER.webLogin(res.data.phoneNumber).then(()=>{
                resolve(res.data.phoneNumber)
              })
            } else {
              clearSessionKey()
            }
          },
          fail() {
            clearSessionKey()
          },
        })
      }).catch(e => {
        WGCOMMON.toast(e)
        reject(e)
      })
    } else {
      WGCOMMON.toast(e.detail.errMsg)
      reject(e.detail.errMsg)
    }
  })
}

/**
 * 微信用户信息授权
 */
function getUserProfile(e) {
  // 推荐使用wx.getUserProfile获取用户信息，开发者每次通过该接口获取用户个人信息均需用户确认
  // 开发者妥善保管用户快速填写的头像昵称，避免重复弹窗
  return new Promise((resolve, reject) => {
    wx.getUserProfile({
      desc: '用于完善会员资料', // 声明获取用户个人信息后的用途，后续会展示在弹窗中，请谨慎填写
      success: (res) => {
        if(res.errMsg == "getUserProfile:ok") {
          let r = res.userInfo
          wx.setStorageSync('userInfo', r)
          wx.setStorageSync('nickName', r.nickName)
          wx.setStorageSync('avatarUrl', r.avatarUrl)
          resolve()
        } else {
          reject()
        }
      },
      fail() {
        reject()
      }
    })
  })
}


export default {
  wxLogin, // 微信静默授权
  qyLogin, // 企业微信静默授权
  getUserInfo, // 授权用户信息
  getPhoneNumber, // 授权用户手机号
  getUserProfile, // 授权用户信息
}