/*  **************************************  五谷网络请求通用方法 start  ****************************************** */

// 1. 已经封装好对请求状态的判断，当请求失败或服务端错误，会toast提示，无需开发者自己判断请求状态和返回数据是否成功
// 2. 使用方法如下：
//       import {http as wgHttp, newHttp as newWgHttp} from "/wgUtils/wgHttp"

//       wgHttp.get(url, data).then( res => {
//         console.log("请求成功的返回值", res)
//       })
//       wgHttp.post(url, data).then( res => {
//         console.log("请求成功的返回值", res)
//       })
//       wgHttp.delete(url, data).then( res => {
//         console.log("请求成功的返回值", res)
//       })
//       wgHttp.put(url, data).then( res => {
//         console.log("请求成功的返回值", res)
//       })
// 3. 请求头默认使用json，即 "application/json"
//    如果请求头需要使用formdata，即"application/x-www-form-urlencoded"
//    则使用方法如下：
//    wgHttp.put(url, data, "formdata").then( res => {
//     console.log("请求成功的返回值", res)
//    })

/*  **************************************  五谷网络请求通用方法 end  ****************************************** */

import env from "./wgEnv"

let baseUrl = env.baseUrl
let newBaseUrl = env.newBaseUrl

function getHeader(type) { // 设置请求头，默认为json，传递formdata则为formdata类型，如果请求头需求秘钥token，则取本地缓存token
  let t = "application/json"
  if (type == 'formdata') {
    t = "application/x-www-form-urlencoded"
  }
  if (wx.getStorageSync('token')) {
    return {
      'content-type': t,
      'token': wx.getStorageSync('token')
    }
  }
  return {
    'content-type': t
  }
}

function showErrToast(e) { // toast请求错误提示
  if (e) {
    wx.showToast({
      title: e,
      icon: 'none',
      duration: 3500
    })
  }
}
/**
 * 
 * @param {*} url 接口地址
 * @param {*} data 请求参数
 * @param {*} method 请求方法 GET/POST/PUT/DELETE
 * @param {*} requestType 请求头类型设置，默认json，需要formdata则传入formdata字符串
 * @param {*} directReturn 是否不经过处理直接返回请求结果，默认处理,传入1表示不处理直接返回结果
 */
function getPromise(url, data, method, requestType, directReturn, isNewBaseUrl) {
  return new Promise((resolve, reject) => {
    wx.request({
      url: `${isNewBaseUrl ? newBaseUrl : baseUrl}${url}`,
      header: getHeader(requestType),
      method: method,
      data: data,
      success: function (res) {
        if (res.statusCode == 200) {
          if (directReturn) {
            resolve(res.data)
          }
          if (res.data.hasOwnProperty('status')) {
            if (res.data.status === 0) {
              if (res.data.hasOwnProperty('data')) {
                resolve(res.data.data)
              }
              resolve(res.data)
            } else {
              reject(res.data.msg)
            }
          }
          if (res.data.hasOwnProperty('msgCode')) {
            if (res.data.msgCode === 0) {
              resolve(res.data.resultInfo)
            } else {
              reject(res.data.msgInfo)
            }
          }
          resolve(res.data)
        } else {
          reject(res.data)
        }
      },
      fail: function (err) {
        reject(err)
      }
    })
  }).catch(function (e) {
    showErrToast(e)
  })
}

const http = {
  /**
   * 
   * @param {*} url 接口地址
   * @param {*} data 请求参数
   * @param {*} requestType 请求头类型设置，默认json，需要formdata则传入formdata字符串
   * @param {*} directReturn 是否不经过处理直接返回请求结果，默认处理
   */
  get: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'GET', requestType, directReturn)
  },
  post: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'POST', requestType, directReturn)
  },
  put: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'PUT', requestType, directReturn)
  },
  delete: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'DELETE', requestType, directReturn)
  }
}
const newHttp = {
  /**
   * 
   * @param {*} url 接口地址
   * @param {*} data 请求参数
   * @param {*} requestType 请求头类型设置，默认json，需要formdata则传入formdata字符串
   * @param {*} directReturn 是否不经过处理直接返回请求结果，默认处理
   */
  get: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'GET', requestType, directReturn, true)
  },
  post: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'POST', requestType, directReturn, true)
  },
  put: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'PUT', requestType, directReturn, true)
  },
  delete: function (url, data, requestType, directReturn) {
    return getPromise(url, data, 'DELETE', requestType, directReturn, true)
  }
}
export {
  http,
  newHttp
}