/*  **************************************  五谷图片操作通用方法 start  ****************************************** */
// 1. 使用方法
// import wgImage from '/wgUtils/wgImage'
// wgImage.saveImage(imgUrl) // 保存图片到本地
// wgImage.chooseImageAndUpload(5)  // 选择图片并上传到七牛
// wgImage.uploadImage(imgUrl) // 上传图片到七牛

/*  **************************************  五谷图片操作通用方法 end  ****************************************** */



import wgEnv from './wgEnv'
import qiniuUploader from '../utils/qiniuUploader'

function uploadImage(filePath) { // 上传图片至七牛
  return new Promise((resolve, reject) => {
    wx.request({
      url: wgEnv.baseUrl + 'qiniu/getUploadToken?content',
      success(res) {
        let token = res.data.retInfo
        qiniuUploader.upload(filePath, (res) => {
          resolve('https://img.wgmf.com/' + res.retInfo)
        }, (error) => {
          reject(error)
          console.log('error: ' + error)
        }, {
          region: 'ECN',
          domain: 'https://img.wgmf.com/',
          uptoken: token // 由其他程序生成七牛 uptoken
        })
      }
    })
  })
}
/**
 * 
 * @param {*} maxLen 最多可以选择maxLen张图片上传
 * @return {*} imgsArr 图片url数组
 */
function chooseImageAndUpload(maxLen) { // 选择图片并上传至七牛
  maxLen = maxLen ? maxLen : 1
  return new Promise((resolve, reject) => {
    wx.chooseImage({
      count: maxLen,
      success(res) {
        let tempFilePaths = res.tempFilePaths,
          imgsArr = [],
          current = 0
        for (let i = 0; i < tempFilePaths.length; i++) {
          uploadImage(tempFilePaths[i]).then(url => {
            current++
            imgsArr.push(url)
            if (current == tempFilePaths.length) {
              resolve(imgsArr)
            }
          })
        }
      },
      fail(err) {
        wx.hideNavigationBarLoading()
      }
    })
  })
}

function saveImg1(url) { // 保存图片 - 2. 保存图片
  wx.getImageInfo({
    src: url,
    success: res => {
      let path = res.path;
      wx.saveImageToPhotosAlbum({
        filePath: path,
        success: res => {
          wx.showToast({
            icon: 'success',
            title: '图片保存成功！',
            duration: 2500
          })
        }
      })
    }
  })
}

function saveImage(url) { // 保存图片 - 1. 检查相册使用权限
  //用户需要授权
  wx.getSetting({
    success: (res) => {
      if (!res.authSetting['scope.writePhotosAlbum']) {
        wx.authorize({
          scope: 'scope.writePhotosAlbum',
          success: () => {
            saveImg1(url) // 同意授权
          },
          fail: (res) => {
            console.log('用户拒绝使用相册权限------', res)
          }
        })
      } else { // 已经授权了使用相册权限
        saveImg1(url)
      }
    },
    fail: (res) => {
      console.log('用户拒绝使用相册权限------', res)
    }
  })
}

/**
 * 预览图片
 * @param {*} imgsArr 图片数组
 * @param {*} currentIndex 当前图片index
 */
function previewImage(imgsArr, currentIndex) {
  if (Object.prototype.toString.call(imgsArr) != '[object Array]') {
    imgsArr = [imgsArr]
  }
  wx.previewImage({
    current: imgsArr[currentIndex ? currentIndex : 0], // 当前显示图片的http链接
    urls: imgsArr // 需要预览的图片http链接列表
  })
}

export default {
  chooseImageAndUpload,
  saveImage,
  uploadImage,
  previewImage
}