/*  **************************************  五谷内部埋点方法 start  ****************************************** */

// 五谷内部有自己的一套埋点系统，上报的数据主要用于BI统计商城销量，以及各种分享转发销量跟踪和顾问的提成计算等等
// 得根据实际业务需求决定是否是要接入埋点
// 接口由 zhaoxz/lankj 提供
// 目前只有浏览页面记录上报方法pageBrowse，暂无事件记录埋点
// 使用方式如下：
//  onLoad(option) {
//    wgTrack.pageBrowse(option, 'pages/Home/Home', '会员商城首页')
//  }
// 页面来源参数为 _campaign  
// 开发并不需要理会，主要用于运营推广转发时，生成自定义带参的二维码，带参可以添加 _campaign 表示页面来源，再散发到各个渠道让顾问转发这些带参的二维码

/*  **************************************  五谷内部埋点方法 end  ****************************************** */

import { http as wgHttp} from './wgHttp'
import WGDATATYPE from './wgDataType'
import WGENV from './wgEnv'
import sr from '../lib/sr-sdk-wxapp.js'

const appName = 'shop/' // appName标志哪个小程序，请根据小程序情况实际自定义
const appIdFlag = 'miniprogram' // 小程序标志，注意不同小程序的标志不一样，应该统一风格使用

/**
 *  1. 商城小程序
 *     const appName = 'shop/'
 *     const appIdFlag = 'miniprogram'   // 历史遗留问题，使用 “miniprogram”，本来统一规范应该为“miniprogram_shop”
 *  2. 礼品卡小程序
 *     const appName = 'giftCard/'
 *     const appIdFlag = 'miniprogram_giftCard'
 *  3. 抽奖小程序
 *     const appName = 'lottery/'
 *     const appIdFlag = 'miniprogram_lottery'
 *  4. 打卡小程序
 *     const appName = 'CourseClock/'
 *     const appIdFlag = 'miniprogram_CourseClock'
 *  5. 砍价小程序
 *     const appName = 'Bargain/'
 *     const appIdFlag = 'miniprogram_Bargain'
 *  
 *  后续其他小程序有埋点记录，请往下增加注释说明
 * 
 */

function setPageOption(option) { // 保存页面参数和页面来源
  let app = getApp()
  app.globalData.queryObj = option // 页面参数
  setCampaign(option)
}

function getQueryString(options) { // 页面参数
  const app = getApp()
  let queryObj = options ? options : app.globalData.queryObj // 页面参数，在各个需要上报的页面onLoad中注意将页面参数option存到全部变量app.globalData.queryObj中
  let str = ''
  for (let i in queryObj) {
    str += `${i}=${queryObj[i]}&`
  }
  if (str.length > 0) {
    str = '?' + str
    if (str[str.length - 1] == '&') {
      str = str.substr(0, str.length - 1);
    }
  }
  return str
}

function setCampaign(option) { // 设置页面来源缓存，24小时有效
  if (option._campaign) { // 链接带参有页面访问来源数据
    // 保存来源，设置一天过期, 从分享页面进来拿参数
    let valid = 1 * 24 * 60 * 60
    let now = (new Date().getTime()) / 1000
    wx.setStorageSync('campaign', option._campaign)
    wx.setStorageSync('campaignExpiresTime', valid + now)
  }
  if (option.chan_id) {
    let valid = 1 * 24 * 60 * 60
    let now = (new Date().getTime()) / 1000
    wx.setStorageSync('chanId', option.chan_id)
    wx.setStorageSync('chanIdExpiresTime', valid + now)
  }
}

function getChanId() {
  let chanId = wx.getStorageSync('chanId'),
    expiresTime = wx.getStorageSync('chanIdExpiresTime') // 过期时间
  if (chanId && expiresTime) {
    let now = (new Date().getTime()) / 1000 // 现在的时间
    if (now > expiresTime) { // 已经过期了
      wx.removeStorageSync('chanId')
      wx.removeStorageSync('chanIdExpiresTime')
      return getCampaign()
    } else {
      return chanId
    }
  } else {
    return getCampaign()
  }
}

function setChanId(data) {
  //如果本地有24小时未过期的chan_id则使用本地chan_id，否则覆盖新的chan_id
  if (!getChanId() && data) {
    wx.setStorageSync('chanId', data)
  }
  sr.setChan({
    'chan_id': wx.getStorageSync('chanId')
  })
}

function getCampaign() { // 获取访问来源
  let campaign = wx.getStorageSync('campaign'),
    expiresTime = wx.getStorageSync('campaignExpiresTime') // 过期时间
  if (campaign && expiresTime) {
    let now = (new Date().getTime()) / 1000 // 现在的时间
    if (now > expiresTime) { // 已经过期了
      wx.removeStorageSync('campaign')
      wx.removeStorageSync('campaignExpiresTime')
      return ''
    } else {
      return campaign
    }
  } else {
    return ''
  }
}
/**
 * 
 * @param {*} onLoadOption 生命周期函数onLoad里的参数
 * @param {*} pageUrl 当前页面链接
 * @param {*} pageName 当前页面的中文名称
 */
function pageBrowse(promotionType = '') { // 页面浏览记录上报
  
  let pages = getCurrentPages() // 获取页面信息栈
  let currentPage = pages[pages.length - 1]  // 获取当前访问页面的信息
  let prevPage = pages[pages.length - 2] // 获取上一个页面信息栈

  setPageOption(currentPage.options)
  // if(WGENV.env == 'TEST') return
  return wgHttp.get('webstat/api/logPv', {
    appId: appIdFlag, // 代表那个小程序
    customerId: wx.getStorageSync('cusId'),  // 用户id
    _campaign: getChanId(), // 访问来源
    referer: appName + currentPage.route + getQueryString(currentPage.options), // 当前浏览的页面路径
    _pageName: currentPage.data.title, // 当前浏览的页面名称
    _referer: prevPage?(appName + prevPage.route + getQueryString(prevPage.options)):'', // 上级页面路径
    _referer_name: prevPage?prevPage.data.title:'', // 上级页面名称
    unit_id: currentPage.options.unit_id?currentPage.options.unit_id:'',  // 首页组件的id 
    activity_type: promotionType // 产品的活动类型
    /**
     * activity_type 
     * 0 普通商品
     * 1 限时折扣
     * 2 秒杀
     * 3 分期购/分期发货
     * 4 购买优惠券
     * 5 阶梯价
     * 6 预售
     * 8 拼团
     * 9 积分兑换
     * 10 团购-返现金
     * 11 团购-返购物金
     */
  })
}
/**
 * 
 * @param {*} event 事件名
 * 事件名命名规范
 * 点击事件 click_functionName
 * 滑动事件 slide_functionName
 * 分享转发事件 share_functionName
 * 分享朋友圈事件 shareTimeline_functionName
 * 滚动事件 scroll_functionName
 * 长按事件 longpress_functionName
 * @param {*} vars 事件相关的数据
 * @returns 
 */
function logCustomEvent(event, vars = '') {
  let pages = getCurrentPages() // 获取页面信息栈
  let currentPage = pages[pages.length - 1]  // 获取当前访问页面的信息
  return wgHttp.get(`webstat/api/customEvent/${event}`, {
    appId: appIdFlag,
    pageName: currentPage.data.title,
    referer: appName + currentPage.route + getQueryString(currentPage.options),
    rnd: Math.random(),
    vars: JSON.stringify(vars),
    customerId: wx.getStorageSync('cusId'),
    _campaign: getChanId()
  })
}

function setEvent(page_name, page_url, element_id, params) { // 事件埋点
  wx.reportAnalytics(element_id, params)
  //上报事件之前,先设置用户openId
  setSRTrack('element', params)
}

function setLoginUser(unionId) { // 登录就是授权获取unionid
  if (unionId) {
    sr.setUser({
      union_id: unionId
    })
    setTrack('login_wxapp')
  }
}

function setRegisterUser(userId) { // 绑定手机号看成是注册
  if (userId) {
    if (!WGDATATYPE.isString(userId)) {
      userId = userId.toString()
    }
    sr.setUser({
      user_id: userId
    })
    setTrack('register_wxapp')
  }
}

function setUserTag() { // 运营想在行为上看下超级会员与非超级会员的区别。把超级会员当成一个tag加上去
  if (wx.getStorageSync('vipCusStatus') == 1) { // 1 未过期超级会员
    sr.setUser({
      tag: [{
        tag_id: "svip",
        tag_name: "超级会员"
      }]
    })
  } else {
    sr.setUser({
      tag: Object
    })
  }
}

function setUserOpenId(openId) { //补充每个上报都要求的用户openId
  if (openId) {
    sr.setUser({
      open_id: openId
    })
  }
}

function setUser() { //补充每个上报都要求的用户信息
  let that = this
  return new Promise((resolve, reject) => {
    setTimeout(function () {
      if (wx.getStorageSync('unionId')) {
        sr.setUser({
          union_id: wx.getStorageSync('unionId'),
        })
      }
      if (wx.getStorageSync('cusId')) {
        var userId = wx.getStorageSync('cusId')
        if (!WGDATATYPE.isString(userId)) {
          userId = userId.toString()
        }
        sr.setUser({
          user_id: userId
        })
      }
      if (wx.getStorageSync('openId')) {
        sr.setUser({
          open_id: wx.getStorageSync('openId'),
        })
        resolve()
      } else {
        reject()
      }
    }, 1000)
  })
}

/**
 * 腾讯有数获取引流渠道
 */
function getChan(query) { //获取引流渠道 chan_id，参考文档：https://mp.zhls.qq.com/youshu-docs/develop/event/channel/chan_id.html  
  let chan_id = query.chan_id
  if (chan_id) {
    return chan_id
  }

  let sceneInQuery = decodeURIComponent(query.scene)
  let match = sceneInQuery.split('&').map(m => m.match(/^chan_id=(.*)$/)).find(m => !!m)
  if (match) {
    return match[1]
  }
}

/**
 * 腾讯有数获取引流渠道
 */
function setChan(data) {
  console.log(data)
  if (data) {
    sr.setChan({
      'room_id': data
    })
  }
}

// 商品卡曝光 expose_sku_component
// 商品卡触发 trigger_sku_component
// 商品页浏览 browse_sku_page
// 商品加购 add_to_cart
// 订单状态变更 custom_order
// 搜索 search
function setSRTrack(trackKey, trackData) {
  setUser().then(() => {
    getChanInfo()
    sr.track(trackKey, trackData)
  }).catch(e => {
    console.log(e)
  })
}

/**
 * 腾讯有数埋点方法
 */
function setTrack(track) {
  setUser().then(() => {
    getChanInfo()
    sr.track(track)
  }).catch(e => {
    console.log(e)
  })
}

/**
 * 下单接口需要增加chan_refer_app_id、chan_wxapp_scene参数
 * chan_wxapp_scene 	int 	就是小程序场景值，可从 options.scene 获取
 * chan_refer_app_id 	string 	来源公众号或小程序appID，可从 options.referrerInfo.appId 获取
 */
function setChanInfo(options) { // 引流渠道
  if (options.scene) {
    var chan_wxapp_scene = options.scene
    wx.setStorageSync('chan_wxapp_scene', chan_wxapp_scene)
  }
  if (options.referrerInfo && options.referrerInfo.appId) {
    var chan_refer_app_id = options.referrerInfo.appId
    wx.setStorageSync('chan_refer_app_id', chan_refer_app_id)
  }
}
/**
 * 由于页面带参时，有数会自动从页面链接中读取渠道参数，所以每次上报之前将渠道参数设置到有数，
 * 避免因拿不到chan_wxapp_scene 场景值而导致上报失败
 * chan_id 	string 	自定义渠道的收集方法较复杂，详见有数官方文档
 * chan_wxapp_scene 	int 	就是小程序场景值，可从 options.scene 获取
 * chan_refer_app_id 	string 	来源公众号或小程序appID，可从 options.referrerInfo.appId 获取
 */
function getChanInfo() { // 引流渠道
  if (wx.getStorageSync('chan_id')) {
    sr.setChan({
      chan_id: wx.getStorageSync('chan_id'),
    })
  }
  if (wx.getStorageSync('chan_wxapp_scene')) {
    sr.setChan({
      chan_wxapp_scene: wx.getStorageSync('chan_wxapp_scene'),
    })
  }
  if (wx.getStorageSync('chan_refer_app_id')) {
    sr.setChan({
      chan_refer_app_id: wx.getStorageSync('chan_refer_app_id'),
    })
  }
}

export default {
  setChanInfo,
  getChanInfo,
  getChan,
  setChan,
  getChanId,
  setChanId,
  setCampaign,
  getCampaign,
  pageBrowse,
  setUser,
  setUserTag,
  setUserOpenId,
  setLoginUser,
  setRegisterUser,
  setTrack,
  setEvent,
  setSRTrack,
  logCustomEvent,
  getQueryString,
}