/**
 * C端用户通用的获取信息方法
 */



import { WGENV } from './index'

/** 查询超会状态
 * 调用成功前置条件：本地缓存有cusId
 * 成功后：本地缓存新增vipCusStatus，Promise返回vipCusStatus
 * 失败后：Promise返回失败原因
 */
function querySVipOnlineCusInfo() { 
  if(wx.getStorageSync('cusId')) {
    return new Promise((resolve, reject) => {
      wx.request({
        url: WGENV.baseUrl + 'app/information/querySVipOnlineCusInfo',
        method: "POST",
        header: {
          "content-type": 'application/x-www-form-urlencoded'
        },
        data: {
          cusId: wx.getStorageSync('cusId')
        },
        success(res) {
          if(res.statusCode == 200 && res.data.msgCode == 0 && res.data.resultInfo) {
            wx.setStorageSync('vipCusStatus', res.data.resultInfo.vipCusStatus)
            resolve(res.data.resultInfo)
          } else {
            reject(res.data.msgInfo || res.errMsg || res.data)
          }
        },
        fail(err) {
          reject(err.errMsg|| err)
        }
      })
    })
  } else {
    return Promise.reject()
  }
}


/** 获取用户基本信息
 * 调用成功前置条件：本地缓存有cusId或openId或unionId
 * 成功后：本地缓存新增[nickName] + [avatarUrl] + [h5openId] + [phone] + [unionId]，Promise返回用户信息对象
 * 失败后：Promise返回失败原因
 */
function getCustomerInfo() {
  let openId = wx.getStorageSync('openId'),
      cusId = wx.getStorageSync('cusId'),
      unionId = wx.getStorageSync('unionId')
  if(!openId && !cusId && !unionId) {
    return Promise.reject()
  }
  let query = '?'
  if(openId) { query += `openId=${openId}&` }
  if(cusId) { query += `cusId=${cusId}&` }
  if(unionId) { query += `unionId=${unionId}&` }
  return new Promise((resolve, reject) => {
    wx.request({
      url: WGENV.baseUrl + 'sygj-ewx/customerInformation/getCustomerInfo' + query,
      method: 'GET',
      success(res) {
        if(res.statusCode == 200 && res.data.msgCode == 0 && res.data.resultInfo) {
          let result = res.data.resultInfo
          if(result.customerMobile) { // 用户手机号码
            wx.setStorageSync('phone', result.customerMobile)
          }
          if(result.nickName) { // 用户昵称
            wx.setStorageSync('nickName', result.nickName)
          }
          if(result.headImgUrl) { // 用户头像
            wx.setStorageSync('avatarUrl', result.headImgUrl)
          }
          if(result.wechartNo) { // 公众号openId
            wx.setStorageSync('h5openId', result.wechartNo)
          }
          if(result.unionId) { // 用户unionId
            wx.setStorageSync('unionId', result.unionId)
          }
          if(result.customerGrade) {
            wx.setStorageSync('isJinGu', result.customerGrade == '金谷会员' ? 1 : (result.customerGrade == '钻谷会员' ? 1 : 0)) // 是否是金谷
          }
          resolve(result)
        } else {
          reject(res.data.msgInfo || res.errMsg || res.data)
        }
      },
      fail(err) {
        reject(err.errMsg || err)
      }
    })
  })
}


/** 用户登录
 * 调用成功前置条件：本地缓存有phone或调用函数手动传入phone
 * 成功后：本地缓存新增cusId，Promise返回cusId，并调用getCustomerInfo、querySVipOnlineCusInfo
 * 失败后：Promise返回失败原因
 */
function webLogin(phone) {
  phone = phone || wx.getStorageSync('phone')
  if(!phone) {
    return Promise.reject()
  }
  return new Promise((resolve, reject) => {
    wx.request({
      url: WGENV.baseUrl + 'app/information/webLogin',
      method: "POST",
      header: {
        "content-type": 'application/x-www-form-urlencoded'
      },
      data: {
        mobile: phone,
        checkCode: '###123',
        unionId: wx.getStorageSync('unionId') ? wx.getStorageSync('unionId') : null
      },
      success(res) {
        if(res.statusCode == 200 && res.data.msgCode == 0 && res.data.resultInfo && res.data.resultInfo.customerId) {
          wx.setStorageSync('cusId', res.data.resultInfo.customerId)
          querySVipOnlineCusInfo()
          getCustomerInfo()
          // 0-会员商超渠道;1-电商渠道
          wx.setStorageSync('custChannel', res.data.resultInfo.channel)
          resolve(res.data.resultInfo.customerId)
        } else {
          reject(res.data.msgInfo || res.errMsg || res.data)
        }
      },
      fail(err) {
        reject(err.errMsg || err)
      }
    })
  })
}
/** 用户登录
 * 调用成功前置条件：不一定有手机号，存在unionId
 * 成功后：本地缓存新增cusId，Promise返回cusId，并调用getCustomerInfo、querySVipOnlineCusInfo
 * 失败后：Promise返回失败原因
 */
function queryChannel() {
  return new Promise((resolve, reject) => {
    wx.request({
      url: WGENV.baseUrl + 'app/information/queryChannel',
      method: "POST",
      header: {
        "content-type": 'application/x-www-form-urlencoded'
      },
      data: {
        mobile: '',
        checkCode: '###123',
        unionId: wx.getStorageSync('unionId') ? wx.getStorageSync('unionId') : null
      },
      success(res) {
        if(res.data.msgCode == 0) {
          wx.setStorageSync('custChannel', res.data.resultInfo)
          resolve(res.data)
        } else {
          // 会员信息不存在
          resolve(res.data)
        }
      },
      fail(err) {
        reject(err.errMsg || err)
      }
    })
  })
}

export default {
  querySVipOnlineCusInfo,
  getCustomerInfo,
  webLogin,
  queryChannel
}