const hmacSha1 = require('/lib/crypto/hmac-sha1')
const base64 = require('/lib/crypto/enc-base64')

const init = (secretId, secretKey) => {
  if (secretId && secretKey) {
    try {
      wx.setStorageSync('secretId', secretId)
      wx.setStorageSync('secretKey', secretKey)
    } catch (e) {}
  } else {
    console.error('zj-signature init失败')
  }
}

const prefixParams = (data, prefix = "") => {
  let ret = {}
  for (let k in data) {
    if (data[k] === null) {
      continue
    }
    if (data[k] instanceof Array || data[k] instanceof Object) {
      Object.assign(ret, prefixParams(data[k], prefix + k + "."))
    } else {
      ret[prefix + k] = data[k]
    }
  }
  return ret
}

const xhr = ({
  Method = 'GET',
  ...other
}) => {
  const SECRET_ID = wx.getStorageSync('secretId')
  const SECRET_KEY = wx.getStorageSync('secretKey')

  if (!SECRET_ID || !SECRET_KEY) {
    console.error('zj-signature 未初始化或初始化存在异常')
  } else {
    const Timestamp = Math.round(new Date().getTime() / 1000).toString()
    let tempParams = {
      SecretId: SECRET_ID,
      Nonce: (Math.random() * 100000).toFixed(0),
      Region: 'ap-shanghai',
      Timestamp,
      ...other
    }
    tempParams = prefixParams(tempParams)
    console.info(tempParams)
    let rstParams = {}
    Object.keys(tempParams).sort().forEach((key) => {
      rstParams[key] = tempParams[key];
    })
    let rstStr = ''
    Object.keys(rstParams).map((v, i) => {
      if (i > 0) {
        rstStr += '&'
      }
      rstStr += `${v}=${rstParams[v]}`
    })
    const signStr = `${Method}zj.tencentcloudapi.com/?${rstStr}`
    const Signature = base64.stringify(hmacSha1(signStr, SECRET_KEY))
    return new Promise((resolve, reject) => {
      wx.request({
        url: 'https://zj.tencentcloudapi.com',
        data: {
          ...rstParams,
          Signature
        },
        header: {
          'content-type': 'application/x-www-form-urlencoded'
        },
        method: Method,
        ...other,
        complete: (res) => {
          if (res.statusCode >= 200 && res.statusCode < 300) {
            resolve(res)
          } else {
            reject(res)
          }
        }
      })
    })

  }
}

const get = (param) => {
  return xhr(param)
}

const post = (param) => {
  return xhr({
    ...param,
    Method: 'POST'
  })
}

export {
  init,
  get,
  post
}